#pragma rtGlobals=1		// Use modern global access method.
#include <FilterDialog> menus=0
#include <All IP Procedures>
#include <Image Saver>
#pragma ModuleName = tracesAnalyzer
// ************************************************************************************************    
// GUI of Traces analyzer program 
// The program is written by Marijonas Tutkus since 06-11  @ Bionanotechnology lab and
// further developed @ Department of Molecular Compound Physics in CPST Vilnius.
// ************************************************************************************************   
// adds the name of softwave to macros botton
menu "Macros"
	"Initialize Traces Analyzer/2",/Q , GUI_TA_MT( )
end
/// Making Structure for the whole program
Static constant TA_prefsVersion = 100
static strConstant TA_packageName = "TracesAnalyzer"
static strConstant TA_preferencesFileNAme = "TracesAnalyzerPreferences.bin"
Static Constant TA_preferecesRecord = 0 // number identifying record within the preferences file
// Structuring the variables
Structure TA_preferences
	uint32 version
	double paricleToggle  				// indicates, which particles are used in analysis
	double maxDeviation[ 2 ]     		// maximal deviation of Gaussian fit for a particle
	double lenghtLinkParticles  			// distance between particles used in co-localization procedure
	double threshold[ 4 ]				// intensity threshold for both channels: 0 - 1st ch particle probability; 1 - 2nd ch particle probability, 2 - 1st ch filtered thresh, 3 - 2nd ch filtered thresh
	double minArea[ 2 ]				// minimal area of a particle for both channels
	double levelsSM[ 4 ]				// 0: exclusion of multi-mlecule trajectories; 1 - max int ch1; 2 - max int  ch2; 3 -  # pnts above max int.
	double panelCoords[ 4 ]
	double imageCoords[ 12 ]  			// [ 0 - 3 ] - membrane ch, [ 4 - 7 ] - protein , [ 8 - 11 ] - threshold 
	double icpDetection[ 2 ]			// 0 - ICP detection type, 1 - parameter for ICP detection
	double radiusVariables		  		// crop size for 2D Gaus fitting
	double bckgSubtrVariables[ 4 ]		//  bg removing from images variables: 0 - toggle 1st ch, 1 - toggle 2nd ch, 2 - ball size 1st ch, 3 - ball size 2nd ch.
	double sizeImage[ 6 ]				// 0 - 1 :physical size; 2 - x0 , 3 - x1, 4 - y0 , 5 - y1
	double imageFiltering[ 10 ]			// 0 : filteringMembraneImage; 1 : filteringProteinImage; 2 : gaussianMembrane; 3 : gaussianProtein; 4: lpMembrane; 5: lpProtein; 6 : sizeGaussMembrane; 7: sizeGaussProtein 8: numImagesAccMemb; 9: numImagesAccProtein; 
	double particleFitting[ 2 ]			// toggle of 2D Gauss fitting: 0 - 1st ch, 1 - 2nd Ch.
	double tracesFilterVariables[ 2 ] 	 	// 0: method; 1: parameter1.
	double trajSelection				// selection of trajectories, value: 1 - manual slection, 2 - automatic selection
	double partsAnalysis[6]			// components: 0 - detection, 1 - trejectory extraction, 2 - traj filtering, 3 - ICP detection, 4 - charcterization of states, 5 - auto selection of traces
	double coefStepAmp[3]				// step amplitude : 0 - eFRET, 1- 1st ch, 2- 2nd ch..
	double variableGWidth				// variable width of Gaussian fit during intensity extraction: 1 - on , 2 - off.
	double variableGcoord				// variable center coordinates of Gaussian fit during intensity extraction: 1 - on , 2 - off.
	double manyMovVar[ 6 ]			// counters of table lenght,  for concatenation of icp tables
	double traceInt						// 1 - amplitude trace, 2 - gaussian integrated intensity trace
	double noChToggle					// 1 - single ch., 2 - two channels for signal extraction.
	double imageTypeTA[5]				// 0 -dual-view / dual-cam, 1 - 1st ch location, 2 - 2nd channel location, 3 - orientation of image splitter, 4 - num. of folders in the subdirectory
	double normaliseToggle			// 1 - normalise, 2 - do not normalise traces.
	double blStateToggle				// exlude partial states
	double blStateToggle2				// exclude bleaching state
	double normFolder					// indicator of folder for normalisation image
	double imageFileType				// indicator of image type: 0 - TIFF, 1 - signed 32-bit binary.
	double numImagesTA					// number of images to be loaded for traces extraction
	double regParams[ 10 ]			// registration params
	double antiCorToggleMain			// aticorr toggle - 0 - off, 1 - on.
	double groupingToggleMain			// grouping toggle - 0 - off, 1 - on.
	double minAmp					// minimum amplitude for state clustering
	double minDur					// minimal duration for state clustering
	double nSdevBleach				// number of standard deviations for bleaching state detection.
	double excType					// excitation type: 1-alex, 2-single laser.
	double IdTrName					// name of trace table to idealise
	double removeBleach			// before ICP detection remove bleach fraction of FRET trace
	double IdSelAllTrName			// detected ICP in selected or all traces
	double silentICPDetection	// show/ do not show result of detected ICPs
	double neverBleach[2]			// show/ do not show result of detected ICPs
	double clusterStates			// enable state clustering in ICP detection
	double minAmpTypeToggle		// amplitude criteria for AmpDur ICP detection: 1 - dependent of SD of signal, 2 - predefined.
	double expandTrace[2]			// 1 - toggle for trace expansion, 2 - factor of expansion.
	double alex_stLaser			// first laser exciting sample, for ALEX excitation
	double IdSelAllTrStateChar	// use selected / all signals state charc.	
endStructure
// sets preferences of main panel of structure to default values
static Function default1_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	TAPrefs.version = TA_prefsVersion 
	// panel coords
	TAPrefs.panelCoords[ 0 ] = 0  ; TAPrefs.panelCoords[ 1 ] = 470 ; TAPrefs.panelCoords[ 2 ] = 570 ; TAPrefs.panelCoords[ 3 ] = 880	// left, top , right , bottom
	// membrane image coords
	TAPrefs.imageCoords[ 0 ] = 0 ; TAPrefs.imageCoords[ 1 ] = 0; TAPrefs.imageCoords[ 2 ] = 300 ; TAPrefs.imageCoords[ 3 ] = 300		// left, top , right , bottom
	// protein image coords
	TAPrefs.imageCoords[ 4 ] = 320; TAPrefs.imageCoords[ 5 ] = 0; TAPrefs.imageCoords[ 6 ] = 620	; TAPrefs.imageCoords[ 7 ] = 300	// left, top , right , bottom
	// threshold image coordinates
	TAPrefs.imageCoords[ 8 ] = 640; TAPrefs.imageCoords[ 9 ] = 0; TAPrefs.imageCoords[ 10 ] = 940; TAPrefs.imageCoords[ 11 ] = 300	// left, top , right , bottom
	// other variables
	TAPrefs.paricleToggle = 1
	TAPrefs.lenghtLinkParticles = 5
	TAPrefs.icpDetection[1] = 1				// parameter for ICP detection
	TAPrefs.traceInt = 1
	TAPrefs.radiusVariables = 4				// crop size for 2D Gauss fitting
	variable aa = 0
	for( aa = 0 ; aa < 10 ; aa += 1 )
		if( aa < 2 )
			TAPrefs.minArea[ aa ] = 2
			TAPrefs.maxDeviation[ aa ] = 30
		endif
		if( aa < 4 )
			TAPrefs.threshold[ aa ] = 0
		endif
		if( aa < 6 )
			TAPrefs.manyMovVar[ aa ] = 0
			TAPrefs.partsAnalysis[ aa ] = 0
		endif
	endFor
	//
end
// sets preferences of additional settings panel of structure to default values
static Function default2_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	TAPrefs.version = TA_prefsVersion 
	variable aa = 0
	TAPrefs.icpDetection[0] = 1				// type of ICP detection
	TAPrefs.noChToggle = 1					// number of channels for signal extraction
	TAPrefs.bckgSubtrVariables[ 0 ] = 2		// remove bg ch1
	TAPrefs.bckgSubtrVariables[ 1 ] = 2		// remove bg ch2
	TAPrefs.bckgSubtrVariables[ 2 ] = 2		// ball size ch1
	TAPrefs.bckgSubtrVariables[ 3 ] = 2		// ball size ch2
	TAPrefs.normaliseToggle = 1			// traces normalisation toggle
	TAPrefs.blStateToggle = 1
	TAPrefs.normFolder = 1
	TAPrefs.imageFileType = 1 				// type of image file, 0 - TIFF, 1 - signed 32-bit binary.
	TAPrefs.numImagesTA = 1				// num of image to be loaded for signal extraction
	TAPrefs.variableGWidth = 1 			// variable width of Gaussian fit during intensity extraction: 1 - on , 2 - off.
	TAPrefs.variableGcoord = 1
	TAPrefs.antiCorToggleMain = 1
	TAPrefs.tracesFilterVariables[ 0 ] = 1
	TAPrefs.tracesFilterVariables[ 1 ] = 0
	TAPrefs.nSdevBleach = 2
	TAPrefs.excType = 1
	TAPrefs.IdTrName = 1
	TAPrefs.removeBleach = 1
	TAPrefs.IdSelAllTrName = 1
	TAPrefs.blStateToggle2 = 1
	TAPrefs.silentICPDetection = 1
	TAPrefs.neverBleach[0] = 1
	TAPrefs.neverBleach[1] = 1
	TAPrefs.clusterStates = 1
	TAPrefs.minDur = 6					// minimal duration for state clustering
	TAPrefs.minAmp = 0.1				// minimal amplitude for state clustering
	TAPrefs.minAmpTypeToggle	 = 1	// amplitude criteria for AmpDur ICP detection: 1 - dependent of SD of signal, 2 - predefined.
	TAPrefs.expandTrace[0] = 1		// toggle for trace expansion
	TAPrefs.expandTrace[1] = 1		// factor for trace expansion
	TAPrefs.alex_stLaser = 1			// first laser exciting sample, 1 - red, 2 - green.
	TAPrefs.IdSelAllTrStateChar = 1
	//
	for( aa = 0 ; aa < 11 ; aa += 1 )
		if( aa < 2 )
			TAPrefs.particleFitting[ aa ] = 1
			TAPrefs.tracesFilterVariables[ aa ] = 1
		endif
		if( aa < 3 )
			TAPrefs.coefStepAmp[ aa ] = 0.5
		endif
		if( aa < 4 )
			TAPrefs.levelsSM[ aa ] = 0
		endif
		if( aa < 5 )
			TAPrefs.imageTypeTA[ aa ] = 1				// 0 -dual-view / dual-cam, 1 - 1st ch location, 2 - 2nd channel location, 3 - orientation horiz / vertical, 4 - # of folders
		endif
		if( aa < 6 )
			TAPrefs.sizeImage[ aa ] = 81
		endif
		if( aa < 10 )
			TAPrefs.imageFiltering[ aa ] = 1
		endif
		if( aa < 11 )
			TAPrefs.regParams[ aa ] = 0
		endif
	endFor
	killVariables/z aa
end
//
static function getCoords_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	doWindow controlPanel_TA
	if( V_flag != 0 )
		getWindow  controlPanel_TA wsize
		TAPrefs.panelCoords[ 0 ] =  V_left ; TAPrefs.panelCoords[ 1 ] = V_top ; TAPrefs.panelCoords[ 2 ] = V_right ; TAPrefs.panelCoords[ 3 ] = V_bottom
	endif
	// 1st image coords
	doWindow stChannel
	if( V_flag != 0 )
		getWindow stChannel wsize
		TAPrefs.imageCoords[ 0 ] = V_left	; TAPrefs.imageCoords[ 1 ] = V_top	; TAPrefs.imageCoords[ 2 ] = V_right ; TAPrefs.imageCoords[ 3 ] = V_bottom
	endif
	// 2nd image coords
	doWindow ndChannel
	if( V_flag != 0 )
		getWindow ndChannel wsize
		TAPrefs.imageCoords[ 4 ] = V_left ; TAPrefs.imageCoords[ 5 ] = V_top ; TAPrefs.imageCoords[ 6 ] = V_right  ; TAPrefs.imageCoords[ 7 ] = V_bottom
	endif
	// threshold image coordinates
	doWindow thresholdChannel
	if( V_flag != 0 )
		getWindow thresholdChannel wsize
		TAPrefs.imageCoords[ 8 ] = V_left ; TAPrefs.imageCoords[ 9 ] = V_top ; TAPrefs.imageCoords[ 10 ] = V_right ; TAPrefs.imageCoords[ 11 ] = V_bottom
	endif
end
// synchronize preferences structure to match the state of the main panel
static function synch1_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	TAPrefs.version = TA_prefsVersion 
	getCoords_TA_MT( TAPrefs )
	// record values of setVariables windows
	ControlInfo/w=controlPanel_TA testSetting001; TAPrefs.minArea[ 0 ] = V_value					// min Area of a membrane particle
	ControlInfo/w=controlPanel_TA testSetting002; TAPrefs.minArea[ 1 ] = V_value					// min Area of a protein particle
	ControlInfo/w=controlPanel_TA testSetting003a; TAPrefs.maxDeviation[ 0 ] = V_value			// maximal deviation of 2D Gaussian fit itensity of a particle
	ControlInfo/w=controlPanel_TA testSetting003b; TAPrefs.maxDeviation[ 1 ] = V_value			// maximal deviation of 2D Gaussian fit itensity of a particle
	ControlInfo/w=controlPanel_TA testSetting004; TAPrefs.lenghtLinkParticles = V_value			// maximal co - localization distance
	ControlInfo/w=controlPanel_TA testSetting006; TAPrefs.threshold[ 1 ] = V_value					// prob. thresold of 2nd ch image
	ControlInfo/w=controlPanel_TA testSetting007; TAPrefs.threshold[ 0 ] = V_value					// prob. threshold of 1st ch image
	ControlInfo/w=controlPanel_TA testSetting006b; TAPrefs.threshold[ 3 ] = V_value				// filter. thresold of 2nd ch image
	ControlInfo/w=controlPanel_TA testSetting007b; TAPrefs.threshold[ 2 ] = V_value				// filter. threshold of 1st ch image
	ControlInfo/w=controlPanel_TA testSetting18; TAPrefs.radiusVariables  = V_value				// crop size for 2D Gauss fitting
	//
	ControlInfo/w=controlPanel_TA testSetting30; TAPrefs.imageFiltering[ 8 ] = V_value			// # images to acc. ch1
	ControlInfo/w=controlPanel_TA testSetting31; TAPrefs.imageFiltering[ 9 ] = V_value			// # images to acc. ch2
	ControlInfo/w=controlPanel_TA testSetting5;  TAPrefs.bckgSubtrVariables[ 0 ] = V_Value		// remove bg from ch1 checkbox
	ControlInfo/w=controlPanel_TA testSetting6; TAPrefs.bckgSubtrVariables[ 1 ] = V_Value		// remove bg from ch2 checkbox
	ControlInfo/w=controlPanel_TA testSetting7; TAPrefs.imageFiltering[ 0 ]  = V_Value			// gauss blur ch1 checkbox
	ControlInfo/w=controlPanel_TA testSetting8; TAPrefs.imageFiltering[ 1 ]  = V_Value			// gauss blur ch2 checkbox
	ControlInfo/w=controlPanel_TA testSetting9; TAPrefs.imageFiltering[ 2 ]  = V_Value			// low-pass filter ch1 checkbox
	ControlInfo/w=controlPanel_TA testSetting10; TAPrefs.imageFiltering[ 3 ]  = V_Value			// low-pass filter ch2 checkbox
	ControlInfo/w=controlPanel_TA testSetting11; TAPrefs.particleFitting[ 0 ] = V_Value			// fit spots to 2D Gauss checkbox ch1
	ControlInfo/w=controlPanel_TA testSetting12; TAPrefs.particleFitting[ 1 ] = V_Value			// fit spots to 2D Gauss checkbox ch2
	//
	ControlInfo/w=controlPanel_TA testSetting19; TAPrefs.bckgSubtrVariables[ 2 ] = V_value		// ball size ch1
	ControlInfo/w=controlPanel_TA testSetting20; TAPrefs.bckgSubtrVariables[ 3 ] = V_value		// ball size ch2
	ControlInfo/w=controlPanel_TA testSetting25; TAPrefs.imageFiltering[ 4 ] = V_value			// gaussian kernel size ch1
	ControlInfo/w=controlPanel_TA testSetting26; TAPrefs.imageFiltering[ 5 ] = V_value			// gaussian kernel size ch2
	ControlInfo/w=controlPanel_TA testSetting27; TAPrefs.imageFiltering[ 6 ] = V_value			// cut-off freq ch1
	ControlInfo/w=controlPanel_TA testSetting28; TAPrefs.imageFiltering[ 7 ] = V_value			// cut-off freq ch1
	//
	ControlInfo/w=controlPanel_TA partsAnalSet1; TAPrefs.partsAnalysis[0] = V_value				// spot detection and co-localization
	ControlInfo/w=controlPanel_TA partsAnalSet2; TAPrefs.partsAnalysis[1] = V_value				// trajectory extraction
	ControlInfo/w=controlPanel_TA partsAnalSet4; TAPrefs.partsAnalysis[3] = V_value				// ICP detection
	ControlInfo/w=controlPanel_TA partsAnalSet5; TAPrefs.partsAnalysis[4] = V_value				// trajectory selection
	//
end
// synchronize preferences structure to match the state of the additional panel
static function synch2_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	TAPrefs.version = TA_prefsVersion 
	// record values of popUp windows
	ControlInfo/w=controlPanel2_TA paricleTogglePopUp; TAPrefs.paricleToggle = V_Value				// type of spots for traces extraction
	ControlInfo/w=controlPanel2_TA noChPopUp; TAPrefs.noChToggle = V_Value								// index channel for signal extraction
	ControlInfo/w=controlPanel2_TA varGWidthPopUp; TAPrefs.variableGWidth = V_Value					// variable width of Gaussian fit during intensity extraction
	ControlInfo/w=controlPanel2_TA varGcoordPopUp; TAPrefs.variableGcoord = V_Value					// variable center corrdinates of Gaussian fit during intensity extraction
	ControlInfo/w=controlPanel2_TA traceIntPopUp; TAPrefs.traceInt = V_Value								// intensity for traces: amplitude / gausssian integral
	ControlInfo/w=controlPanel2_TA numImagesSetting; TAPrefs.numImagesTA = V_Value						// number of images to be loded for signal extraction
	//
	ControlInfo/w=controlPanel2_TA traceFiltPopUp; TAPrefs.tracesFilterVariables[ 0 ] = V_Value	// trace filtering method
	ControlInfo/w=controlPanel2_TA testSetting29; TAPrefs.tracesFilterVariables[ 1 ] = V_value		// traces filtering variable
	//
	ControlInfo/w=controlPanel2_TA normalisePopUp; TAPrefs.normaliseToggle = V_Value					// normalisation of traces
	//
	ControlInfo/w=controlPanel2_TA icpDetectionPopUp; TAPrefs.icpDetection[0] = V_Value				// type of ICP detection
	ControlInfo/w=controlPanel2_TA testSetting16d; TAPrefs.minAmp = V_value								// minimal amplitude for state clusting
	ControlInfo/w=controlPanel2_TA testSetting16e; TAPrefs.minDur = V_value								// minimal duration for state clusting
	ControlInfo/w=controlPanel2_TA clusterICPDet_ckeckBox; TAPrefs.clusterStates = V_Value			// cluster states in icp detection.
	ControlInfo/w=controlPanel2_TA ampTypeICPdet_popMenu; TAPrefs.minAmpTypeToggle = V_Value		// amplitude criteria for AmpDur ICP detection: 1 - dependent of SD of signal, 2 - predefined.
	ControlInfo/w=controlPanel2_TA expandTrICPdet_checkBox; TAPrefs.expandTrace[0] = V_Value		// toggle for trace expansion
	ControlInfo/w=controlPanel2_TA expandTrICPdet_setValue; TAPrefs.expandTrace[1] = V_Value		// factor for trace expansion
	//
	ControlInfo/w=controlPanel2_TA trToIdealpopUp; TAPrefs.IdTrName = V_Value							// trace table name to idealise
	ControlInfo/w=controlPanel2_TA selAllIdealpopUp; TAPrefs.IdSelAllTrName = V_Value					// idealise selected or all traces
	ControlInfo/w=controlPanel2_TA remBleachIdealpopUp; TAPrefs.removeBleach = V_Value				// remove bleached fraction before idealise
	//
	ControlInfo/w=controlPanel2_TA testSettingAntiCorr; TAPrefs.antiCorToggleMain = V_value
	ControlInfo/w=controlPanel2_TA testSettingAmpCoef1; TAPrefs.coefStepAmp[1] = V_value				// amplitude for anti-corr ch1
	ControlInfo/w=controlPanel2_TA testSettingAmpCoef2; TAPrefs.coefStepAmp[2] = V_value				// amplitude for anti-corr ch2
	//
	ControlInfo/w=controlPanel2_TA silentICPpopUp; TAPrefs.silentICPDetection = V_Value				// show/ do not show results of ICP detection.
	ControlInfo/w=controlPanel2_TA testSetting23; TAPrefs.sizeImage[ 2 ] = V_value						// x0
	ControlInfo/w=controlPanel2_TA testSetting24; TAPrefs.sizeImage[ 3 ] = V_value						// x1
	ControlInfo/w=controlPanel2_TA testSetting24a; TAPrefs.sizeImage[ 4 ] = V_value					// y0
	ControlInfo/w=controlPanel2_TA testSetting24b; TAPrefs.sizeImage[ 5 ] = V_value					// y1
	//
	ControlInfo/w=controlPanel2_TA testSetting4; TAPrefs.levelsSM[ 0 ] = V_value						// exclude MM
	ControlInfo/w=controlPanel2_TA testSetting16a; TAPrefs.levelsSM[ 1 ] = V_value						// MM intensity
	ControlInfo/w=controlPanel2_TA checkBox_empty; TAPrefs.neverBleach[ 0 ] = V_value					// Remove empty traj
	ControlInfo/w=controlPanel2_TA setVarCtrl_neverBleach; TAPrefs.neverBleach[ 1 ] = V_value		// # SD for remove empty traj
	ControlInfo/w=controlPanel2_TA testSetting16c; TAPrefs.levelsSM[ 3 ] = V_value						// # of pnts above MM int and emty traj.
	//
	ControlInfo/w=controlPanel2_TA remBleachState_ckeckBox; TAPrefs.blStateToggle2= V_value			// Remove bleach state from table
	ControlInfo/w=controlPanel2_TA testSettingNSDBleach; TAPrefs.nSdevBleach = V_value				// # of sdev for bleaching state detection.
	ControlInfo/w=controlPanel2_TA allORselected_stChar_PopUp; TAPrefs.IdSelAllTrStateChar = V_value	// use all or only selected traces for char. states.
	ControlInfo/w=controlPanel2_TA blStatePopUp; TAPrefs.blStateToggle = V_value						// Exclude partial states
	//
	ControlInfo/w=controlPanel2_TA imageTypePopUp; TAPrefs.imageTypeTA[0] = V_Value					// dual-view / dual-cam set-up
	ControlInfo/w=controlPanel2_TA stChLocPopUp; TAPrefs.imageTypeTA[1] = V_Value						// location of 1st channel
	ControlInfo/w=controlPanel2_TA ndChLocPopUp; TAPrefs.imageTypeTA[2] = V_Value						// location of 2nd channel
	ControlInfo/w=controlPanel2_TA orientImagePopUp; TAPrefs.imageTypeTA[3] = V_Value					// orientation of image splitter
	ControlInfo/w=controlPanel2_TA numFolderPopUp; TAPrefs.imageTypeTA[4] = V_Value					// folder with image series in subdirectory	
	ControlInfo/w=controlPanel2_TA normFolderPopUp; TAPrefs.normFolder = V_Value						// folder with normalisatio image in subdirectory
	ControlInfo/w=controlPanel2_TA excTypePopUp; TAPrefs.excType = V_Value								// excitation type
	ControlInfo/w=controlPanel2_TA stLaserPopUp; TAPrefs.alex_stLaser = V_Value							// first laser for ALEX excitation
	ControlInfo/w=controlPanel2_TA imageFileTypePopUp; TAPrefs.imageFileType = V_Value				// image file type.
	// 
	ControlInfo/w=controlPanel2_TA imRegSet1; TAPrefs.regParams[1] = V_value								// dx
	ControlInfo/w=controlPanel2_TA imRegSet2; TAPrefs.regParams[2] = V_value								// dy
	ControlInfo/w=controlPanel2_TA imRegSet3; TAPrefs.regParams[3] = V_value								// a11
	ControlInfo/w=controlPanel2_TA imRegSet4; TAPrefs.regParams[4] = V_value								// a12
	ControlInfo/w=controlPanel2_TA imRegSet5; TAPrefs.regParams[5] = V_value								// a21
	ControlInfo/w=controlPanel2_TA imRegSet6; TAPrefs.regParams[6] = V_value								// a22
	ControlInfo/w=controlPanel2_TA imRegSet7; TAPrefs.regParams[7] = V_value								// a33
	ControlInfo/w=controlPanel2_TA imRegSet8; TAPrefs.regParams[8] = V_value								// originX
	ControlInfo/w=controlPanel2_TA imRegSet9; TAPrefs.regParams[9] = V_value								// originY
	ControlInfo/w=controlPanel2_TA regImagesPopup; TAPrefs.regParams[ 0 ] = V_Value					// align second channel images.
	//
end
// initialize preferences
static function initialize_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	doWindow controlPanel_TA
	// if panel is non existing
	if( V_flag == 0)
		default1_preferences_TA_MT( TAPrefs )
	// else panel id existing
	else
		synch1_preferences_TA_MT( TAPrefs )
	endif
	//
	doWindow controlPanel2_TA
	// if panel is non existing
	if( V_flag == 0)
		default2_preferences_TA_MT( TAPrefs )
	// else panel id existing
	else
		synch2_preferences_TA_MT( TAPrefs )
	endif
	//
end
// loading package of preferences from data folder
function load_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	LoadPackagePreferences TA_packageName, TA_preferencesFileNAme, TA_preferecesRecord, TAPrefs
	// If error or prefs not found or not valid, initialize them.
	if (V_flag != 0 || V_bytesRead == 0 || TAPrefs.version != TA_prefsVersion)  // bytesRead = 0 if file does not exist, V_flag = 0 if error uccured during loading the file
		initialize_preferences_TA_MT( TAPrefs )					// Set based on panel if it exists or set to default values.
		save_preferences_TA_MT( TAPrefs )						// Create initial prefs record.
		print "Error in loading preferences. Therefore default preferences initialized"
	endif
end	
// saving package of preferences into data folder
function save_preferences_TA_MT( TAPrefs )
	Struct TA_preferences &TAPrefs
	SavePackagePreferences TA_packageName, TA_preferencesFileNAme, TA_preferecesRecord, TAPrefs
end
//********************   Makes the main window and image windows ( main GUI )     *************************
Function GUI_TA_MT()
	// clean enivronment
	killVariables/z/a;	killStrings/z/a;	killWaves/z/a
	// loading structure preferences
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	// setting structure values to  match local variables
	variable leftPanel = TAPrefs.panelCoords[ 0 ]
	variable topPanel = TAPrefs.panelCoords[ 1 ]
	variable rightPanel = TAPrefs.panelCoords[ 2 ]
	variable bottomPanel = TAPrefs.panelCoords[ 3 ]
	//
	string helpStr
	//**************************     makes main window   **************************
	doWindow/k controlPanel_TA
	NewPanel/K=2 /W=( leftPanel, topPanel, rightPanel, bottomPanel ) as "Trace Analyzer, v.1"
	doWindow/c controlPanel_TA
	MoveWindow /w = controlPanel_TA leftPanel, topPanel, rightPanel, bottomPanel
	//******************************************************  Makes setVariables boxes, which are placed in the control panel    **********************************************************************************
	// setting particle identification variables
	SetVariable testSetting001 disable = 0, fsize=12, limits={0, 1000, 0.1}, bodyWidth=0,frame=1,pos={40, 40}, size = {210, 0} ,value = _NUM:TAPrefs.minArea[ 0 ],  proc = tracesAnalyzer#setting01_TA_MT, title= "Min. area ch1 [pix]", win=controlPanel_TA
	SetVariable testSetting002 disable = 0, fsize=12, limits={0, 1000, 0.1}, bodyWidth=0,frame=1,pos={40, 60}, size = {210, 0} ,value = _NUM:TAPrefs.minArea[ 1 ], proc = tracesAnalyzer#setting01_TA_MT , title= "Min. area ch2 [pix]", win=controlPanel_TA
	SetVariable testSetting003a disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={40, 80}, size = {210, 0}, value = _NUM:TAPrefs.maxDeviation[0], proc = tracesAnalyzer#setting01_TA_MT ,title= "Dev. of fit ch1 [%]", win=controlPanel_TA
	SetVariable testSetting003b disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={40, 100}, size = {210, 0}, value = _NUM:TAPrefs.maxDeviation[1], proc = tracesAnalyzer#setting01_TA_MT ,title= "Dev. of fit ch2 [%]", win=controlPanel_TA
	SetVariable testSetting004 disable = 0, fsize=12, limits={0, 65000, 1}, pos={40, 120}, size = {210, 0}, value = _NUM:TAPrefs.lenghtLinkParticles, proc = tracesAnalyzer#setting01_TA_MT , title= "Co-loc. distance [pix]", win=controlPanel_TA
	// setting thresholds
	SetVariable testSetting007 disable = 0, fsize=12, limits={0, 65000, 0.01}, pos={40, 140}, size = {100, 0}, value = _NUM:TAPrefs.threshold[ 0 ],  proc = tracesAnalyzer#setting01_TA_MT, title= "P. Thr.", win=controlPanel_TA	
	SetVariable testSetting006 disable = 0, fsize=12, limits={0, 65000, 0.01}, pos={40, 160}, size = {100, 0}, value = _NUM:TAPrefs.threshold[ 1 ],  proc = tracesAnalyzer#setting01_TA_MT, title= "P. Thr.", win=controlPanel_TA		
	SetVariable testSetting007b disable = 0, fsize=12, limits={0, 65000, 0.01}, pos={145, 140}, size = {105, 0}, value = _NUM:TAPrefs.threshold[ 2 ],  proc = tracesAnalyzer#setting01_TA_MT, title= "Filt. ch1", win=controlPanel_TA	
	SetVariable testSetting006b disable = 0, fsize=12, limits={0, 65000, 0.01}, pos={145, 160}, size = {105, 0}, value = _NUM:TAPrefs.threshold[ 3 ],  proc = tracesAnalyzer#setting01_TA_MT,title= "Filt. ch2", win=controlPanel_TA	
	// crop size for Gaussian fit
	setVariable testSetting18 disable = 0, fsize=12, limits={1, 100, 1}, pos={40, 180}, size = {210, 0}, value = _NUM:TAPrefs.radiusVariables,  proc = tracesAnalyzer#setting01_TA_MT , title= "Crop size for fitting", win=controlPanel_TA
	// # of images to accumulate
	setVariable testSetting30 disable = 0, fsize=12, limits={0, 100, 0.01}, pos={40, 200}, size = {135, 0}, value = _NUM:TAPrefs.imageFiltering[ 8 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "# img. avg ch1", win=controlPanel_TA
	setVariable testSetting31 disable = 0, fsize=12, limits={0, 100, 0.01}, pos={180, 200}, size = {70, 0}, value = _NUM:TAPrefs.imageFiltering[ 9 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "ch2", win=controlPanel_TA
	//	rolling ball bckg removal
	if( TAPrefs.bckgSubtrVariables[ 0 ] == 1 ) //ch1
		CheckBox testSetting5 win = controlPanel_TA, size={100, 15}, value = 1, title="Remove bg. ch1", fsize=12, pos={ 40, 220}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting19 disable = 0, fsize=12, limits={0, 100, 1}, pos={150, 220}, size = {100, 0}, value = _NUM:TAPrefs.bckgSubtrVariables[ 2 ],  proc = tracesAnalyzer#setting3_TA_MT , title= ", radius", win=controlPanel_TA
	else
		CheckBox testSetting5 win = controlPanel_TA, size={100, 15}, value = 0, title="Remove bg. ch1", fsize=12, pos={ 40, 220}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting19 disable = 1, fsize=12, limits={0, 100, 1}, pos={150, 220}, size = {100, 0}, value = _NUM:TAPrefs.bckgSubtrVariables[ 2 ],  proc = tracesAnalyzer#setting3_TA_MT , title= ", radius", win=controlPanel_TA
	endif
	if( TAPrefs.bckgSubtrVariables[ 1 ] == 1 ) // ch2
		CheckBox testSetting6 win = controlPanel_TA, size={100,15}, value = 1, title="Remove bg. ch2", fsize=12, pos={ 40, 240}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting20 disable = 0, fsize=12, limits={0, 100, 1}, pos={150, 240}, size = {100, 0}, value = _NUM:TAPrefs.bckgSubtrVariables[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT , title= ", radius", win=controlPanel_TA
	else
		CheckBox testSetting6 win = controlPanel_TA, size={100,15}, value = 0, title="Remove bg. ch2", fsize=12, pos={ 40, 240}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting20 disable = 1, fsize=12, limits={0, 100, 1}, pos={150, 240}, size = {100, 0}, value = _NUM:TAPrefs.bckgSubtrVariables[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT , title= ", radius", win=controlPanel_TA
	endif
	//	image filtering gaussian blur
	if( TAPrefs.imageFiltering[ 0 ] == 1 )//ch1
		CheckBox testSetting7 win = controlPanel_TA, size={100, 15},value = 1, title="Blur ch1", fsize=12, pos={ 40, 260}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting25 disable = 0, fsize=12, limits={0, 10, 1}, pos={150, 260}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 4 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", size", win=controlPanel_TA
	else
		CheckBox testSetting7 win = controlPanel_TA, size={100, 15}, value = 0 , title="Blur ch1", fsize=12, pos={ 40, 260}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting25 disable = 1, fsize=12, limits={0, 10, 1}, pos={150, 260}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 4 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", size", win=controlPanel_TA
	endif
	if( TAPrefs.imageFiltering[ 0 ] == 1 )//ch2
		CheckBox testSetting8 win = controlPanel_TA, size={100, 15}, value = 1, title="Blur ch2", fsize=12, pos={ 40, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting26 disable = 0, fsize=12, limits={0, 10, 1}, pos={150, 280}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 5 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", size", win=controlPanel_TA	
	else
		CheckBox testSetting8 win = controlPanel_TA, size={100, 15}, value = 0 ,title="Blur ch2", fsize=12, pos={ 40, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting26 disable = 1, fsize=12, limits={0, 10, 1}, pos={150, 280}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 5 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", size", win=controlPanel_TA	
	endif
	//image filtering low-pass
	if( TAPrefs.imageFiltering[ 2 ] == 1 )//ch1
		CheckBox testSetting9 win = controlPanel_TA, size={100, 15}, value = 1, title="Low-pass ch1", fsize=12, pos={ 40, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting27 disable = 0, fsize=12, limits={0, 0.5, 0.01}, pos={150,300}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 6 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", freq.", win=controlPanel_TA
	else
		CheckBox testSetting9 win = controlPanel_TA, size={100, 15}, value = 0, title="Low-pass ch1", fsize=12, pos={ 40, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting27 disable = 1, fsize=12, limits={0, 0.5, 0.01}, pos={150,300}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 6 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", freq.", win=controlPanel_TA
	endif
	if( TAPrefs.imageFiltering[ 3 ] == 1 )//ch2
		CheckBox testSetting10 win = controlPanel_TA, size={100, 15}, value = 1, title="Low-pass ch2", fsize=12, pos={ 40, 320}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting28 disable = 0, fsize=12, limits={0, 0.5, 0.01}, pos={150, 320}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 7 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", freq.", win=controlPanel_TA
	else
		CheckBox testSetting10 win = controlPanel_TA, size={100, 15}, value = 0, title="Low-pass ch2", fsize=12, pos={ 40, 320}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		setVariable testSetting28 disable = 1, fsize=12, limits={0, 0.5, 0.01}, pos={150, 320}, size = {100, 0}, value = _NUM:TAPrefs.imageFiltering[ 7 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= ", freq.", win=controlPanel_TA
	endif
	// enable/ disable fiting 1st channel particle to 2D Gaussian
	if( TAPrefs.particleFitting[ 0 ] == 1 )
		CheckBox testSetting11 win = controlPanel_TA, title="2D Gauss fit ch1" , size={100, 15}, value = 1, fsize=12, pos={ 40, 340}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT 	
	else
		CheckBox testSetting11 win = controlPanel_TA, title="2D Gauss fit ch1" , size={100, 15}, value = 0, fsize=12, pos={ 40, 340}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	endif
	// enable/ disable fiting 2nd channel particle to 2D Gaussian
	if( TAPrefs.particleFitting[ 1 ] == 1 )
		CheckBox testSetting12 win = controlPanel_TA, title="ch2" , size={80, 15}, value = 1, fsize=12, pos={ 180, 340}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	else
		CheckBox testSetting12 win = controlPanel_TA, title="ch2" , size={80, 15}, value = 0, fsize=12, pos={ 180, 340}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	endif	
	//***********************************************************************   Makes buttons, which are placed on the control panel       **************************************************************
	helpStr = "Allows user to interactively define paths do image folders for analysis of single movie"
	Button LoadImages disable=0, fsize = 12, pos={280, 40}, valueColor=(0,40000,0),fstyle=1, size={ 120, 20 }, title="Analyze single", help={helpStr},win=controlPanel_TA, proc=tracesAnalyzer2#IL_TA_MT
	//
	Button thresholdMemButton disable = 0, fsize=12, pos={280, 70}, fstyle=0,size={120, 20}, title="Test detect. ch1", win=controlPanel_TA, proc = tracesAnalyzer2#ThM_TA_MT
	Button thresholdProteinButton disable = 0, fsize=12, pos={410, 70}, fstyle=0,size={120, 20}, title="Test detect. ch2", win=controlPanel_TA, proc =tracesAnalyzer2#ThP_TA_MT
	//
	helpStr = "Eecuting spot detection and co-localisation."
	Button processMembrData disable = 0, fsize=12, pos={295, 100}, fstyle=0,size={220, 20}, title="Detect and co-localise spots", help={helpStr},win=controlPanel_TA, proc = tracesAnalyzer3#CP_TA_MT
	helpStr = "Executing the intensity of fluorescent spot extraction over time."
	Button processData disable = 0 , fsize = 12, pos={295, 130},fstyle=0 ,size={220, 20}, title="Extract int. vs. time traces of spots", help={helpStr},win=controlPanel_TA, proc = tracesAnalyzer3#PM_TA_MT	
	helpStr = "Automatically examine and sort extracted traces."
	Button autoSelectProc disable = 0 , fsize=12, pos={280, 160}, fstyle=0,size={120, 20}, title="Auto sorting", help={helpStr}, win=controlPanel_TA, proc = tracesAnalyzer8#TEclusionAuto_TA_MT
	helpStr = "Manualy examine and sort extracted traces."
	Button manSelectButton disable = 0 , fsize=12, pos={410, 160}, fstyle=0,size={120, 20}, title="Manual sorting", help={helpStr}, win=controlPanel_TA, proc = tracesAnalyzer_visTrMol#main_visTrMol_ta_mt
	helpStr = "Executing intensity change point detection in the selected type of intensity over time traces."
	Button analizator disable = 0 , fsize=12, pos={295, 190}, fstyle=0,size={220, 20}, title="Detect ICPs", help={helpStr},win=controlPanel_TA, proc = tracesAnalyzer4#ICPdet_TA_MT
	helpStr = "Executes characterization and selection of detected states and traces"
	Button exclusionProc disable = 0 , fsize=12, pos={295, 220}, fstyle=0,size={220, 20}, title="Charaterize states", help={helpStr},win=controlPanel_TA, proc = tracesAnalyzer6#TEclusion_TA_MT
	//
	helpStr = "Executes analysis multiple movies placed in one folder. Based on analysis stages selected in the add. settings panel."
	Button button1 disable=0, fsize = 12, pos={280, 250}, valueColor=(0,40000,0),fstyle=1, size={ 120, 20 }, title="Analyze many",win=controlPanel_TA, proc=tracesAnalyzer10#manyMoviesAnalysis
	if( TAPrefs.partsAnalysis[0] == 0 )
		CheckBox partsAnalSet1 win = controlPanel_TA, title="Detect & Coloc." , size={100, 10}, value = 0 , fsize=12, pos={ 280, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT   
	else
		CheckBox partsAnalSet1 win = controlPanel_TA, title="Detect & Coloc." , size={100, 10}, value = 1 , fsize=12, pos={ 280, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT   
	endif
	if( TAPrefs.partsAnalysis[1] == 0 )
		CheckBox partsAnalSet2 win = controlPanel_TA, title="Extract signals" , size={100, 10}, value = 0 , fsize=12, pos={ 410, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT  
	else
		CheckBox partsAnalSet2 win = controlPanel_TA, title="Extract signals" , size={100, 10}, value = 1 , fsize=12, pos={ 410, 280}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT  
	endif
	If(TAPrefs.partsAnalysis[5]==0)		
		CheckBox partsAnalSet6 win = controlPanel_TA, title="Auto select" , size={100, 10}, value = 0 , fsize=12, pos={ 280, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	else
		CheckBox partsAnalSet6 win = controlPanel_TA, title="Auto select" , size={100, 10}, value = 1 , fsize=12, pos={ 280, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	endif
	if(TAPrefs.partsAnalysis[3]==0)
		CheckBox partsAnalSet4 win = controlPanel_TA, title="Detect ICP" , size={100, 10}, value = 0 , fsize=12, pos={ 370, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT  
	else
		CheckBox partsAnalSet4 win = controlPanel_TA, title="Detect ICP" , size={100, 10}, value = 1 , fsize=12, pos={ 370, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT  
	endif
	If(TAPrefs.partsAnalysis[4]==0)	
		CheckBox partsAnalSet5 win = controlPanel_TA, title="Char. states" , size={100, 10}, value = 0 , fsize=12, pos={ 450, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	else
		CheckBox partsAnalSet5 win = controlPanel_TA, title="Char. states" , size={100, 10}, value = 1 , fsize=12, pos={ 450, 300}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
	endif
	//
	Button button2 disable=0, fsize = 12, pos={280, 330},fstyle=0, size={ 120, 20 }, title="Combine tables",win=controlPanel_TA, proc=tracesAnalyzer10#manyMoviesAnalysis
	helpStr = "Converts tables in selected results folder from ibw to txt format."
	Button exportTxtButt disable = 0 , fsize=12, pos={410, 330}, fstyle=0,size={120, 20}, title = "Convert ibw-txt", win=controlPanel_TA, proc = tracesAnalyzer#exportTXT_TA_MT, help={helpStr}	
	//
	Button mapProc disable = 0 , fsize=12, pos={280, 360}, fstyle=0,size={120, 20}, title="Draw plots", help={"Makes 2D plots"},win=controlPanel_TA, proc = tracesAnalyzer15#fabricate2DHistPlots
	Button mapProc2 disable = 0 , fsize=12, pos={410, 360}, fstyle=0,size={120, 20}, title="Draw diff. plots", help={"Makes 2D differential plots"},win=controlPanel_TA, proc = tracesAnalyzer15#diffHist_ta_mt
	//
	TitleBox shoHide1_TB fColor=(0, 40000, 0 ), frame= 0, fsize = 12, fstyle = 1 , pos = {280,380 }, title = "Show/ hide", win = controlPanel_TA
	TitleBox shoHide2_TB fColor=(0, 40000, 0 ), frame= 0, fsize = 12, fstyle = 1 , pos = {410,380 }, title = "Show/ hide", win = controlPanel_TA
	helpStr = "Show / hide panel with additional settings"
	Button alternativeSettingsButt disable = 0 , fsize=12, pos={280, 395}, fstyle=0,size={120, 20}, title = "Add. settings", win=controlPanel_TA, proc = tracesAnalyzer#alternativeSett_TA_MT, help={helpStr}
	helpStr = "Show/hide other TA_MT related graph windows."
	Button winSysButt disable = 0 , fsize=12, pos={410, 395}, fstyle=0,size={120, 20}, title = "Other panels", win=controlPanel_TA, proc = tracesAnalyzer#sysWin_TA_MT, help={helpStr}
	// close program button
	Button close_Butt disable = 0 , fsize=12, fColor=( 40000, 0, 0 ), pos={410, 425}, fstyle=0,size={120, 20}, title = "Quit", win=controlPanel_TA, proc = tracesAnalyzer#quit_TA_MT, help={"Close program"}	
	//*************************************************      makes group box for simmilar objects          *******************************************************************************
	GroupBox parametersBox1  appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1,  pos={ 25 , 15 }, size={ 230, 345 }, title="Spot detection parameters", win=controlPanel_TA
	GroupBox buttonsBox1 appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 270 , 15 }, size={ 275, 405 }, title="Execution of procedures", win=controlPanel_TA
	GroupBox statusBox appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 25 , 360 }, size={ 230, 85 }, title="Status of the program", win=controlPanel_TA
	// ****** update the alternative settings
	alternativeSett_TA_MT( "ctrlName" )
	//**********  updates state of program on the controls panel   *********s
	State_GUI_TA_MT("Check parameters and options.")
	//*******************   makes graphs   ******************************
	// arbitrary images
	Make/o /d /n = ( 1,1) stChImage, ndChImage, thresholdImage
	// kills the windows if they are present
	dowindow/k stChannel
	dowindow/k ndChannel
	dowindow/k thresholdChannel
	// makes the windows
	newImage/k=2 /s=0 /n = stChannel stChImage
	newImage/k=2 /s=0 /n = ndChannel ndChImage
	newImage/k=2 /s=0 /n = thresholdChannel thresholdImage
	// position windows in the prefered locus, but without exceeding screen dimmension
	updateMCH_TAMT(  );		updatePCH_TAMT(  );		updateTrCH_TAMT(  )
	// release memory occupied by local variables
	killVariables/z/a
	killStrings/z/a
	killWaves/z/a
end
//
function updateMCH_TAMT(  )
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//update screen
	MoveWindow /w = stChannel TAPrefs.imageCoords[ 0 ], TAPrefs.imageCoords[ 1 ], TAPrefs.imageCoords[ 2 ], TAPrefs.imageCoords[ 3 ]
	//
	save_preferences_TA_MT( TAPrefs )
	//
end
//
function updatePCH_TAMT(  )
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//update screen
	MoveWindow /w = ndChannel TAPrefs.imageCoords[ 4 ], TAPrefs.imageCoords[ 5 ], TAPrefs.imageCoords[ 6 ], TAPrefs.imageCoords[ 7 ]
	//
	save_preferences_TA_MT( TAPrefs )
	//
end
//
function updateTrCH_TAMT(  )
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//update screen
	MoveWindow /w = thresholdChannel TAPrefs.imageCoords[ 8 ], TAPrefs.imageCoords[ 9 ], TAPrefs.imageCoords[ 10 ], TAPrefs.imageCoords[ 11 ]
	//
	save_preferences_TA_MT( TAPrefs )
	//
end
// ********
static function quit_TA_MT( ctrlName ) : buttonControl
	string ctrlName
	//
	dowindow /k stChannel;	dowindow /k ndChannel;		dowindow /k thresholdChannel
	dowindow /K controlPanel2_TA
	dowindow/K controlPanel_TA
	//
	doWindow/k cPan_visTrMol_ta_mt			// control panel visualise results
	doWindow/k gr1_visTrMol_ta_mt			// trajectory
	doWindow/k gr2_visTrMol_ta_mt			// 1st image
	doWindow/k gr3_visTrMol_ta_mt			// 2nd image
	//
	doWindow/k gr3_visTrMol_ta_mt			// ICP det and state sorting window.
	//
end
// show/hide system windows button
static function sysWin_TA_MT( ctrlName ) : buttonControl
	string ctrlName
	//
	dowindow stChannel
	if( V_flag == 2 || V_flag == 0 )			// show system windows
		//
		dowindow /Hide = 0 stChannel;	dowindow /Hide = 0 ndChannel;		dowindow /Hide = 0 thresholdChannel	
		//
	else			// hide system windows
		//
		dowindow /Hide = 1 stChannel;	dowindow /Hide = 1 ndChannel;		dowindow /Hide = 1 thresholdChannel
		//
	endif
	//
end
// show additional settings
static function alternativeSett_TA_MT( ctrlName ) : buttonControl
	string ctrlName
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//
	string helpStr
	// check whether panel is hidden or not.
	dowindow controlPanel2_TA
	if( V_flag == 2 || V_flag == 0  )  // panel hidden or non existing.
		// make new panel for additional settings
		dowindow/K controlPanel2_TA
		NewPanel/K=2/W=( 10 , 10 , 500, 675 )/N=controlPanel2_TA  as "Additional settings"
		AutoPositionWindow/R=controlPanel_TA  controlPanel2_TA
		// types of particles to extract trajectories from
		if( TAPrefs.paricleToggle == 1 )
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value = "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "non co-loc ch1"
		elseif( TAPrefs.paricleToggle == 2 )
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value =  "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT , popvalue = "non co-loc ch2"
		elseif(  TAPrefs.paricleToggle == 3 )
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value =  "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "co-localized"
		elseif(  TAPrefs.paricleToggle == 4 )
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value = "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "all ch1"
		elseif(  TAPrefs.paricleToggle == 5 )
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value =  "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "all ch2"
		else
			popupmenu paricleTogglePopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 30 }, size={ 210 , 20  }, mode = 1 ,value =  "non co-loc ch1;non co-loc ch2;co-localized;all ch1;all ch2;all;", title = "Make traces for",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "all"
		endif
		// switching extracting of signals
		if( TAPrefs.noChToggle == 1 )			// extracts traces for 1st channel
			popupmenu noChPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 55 }, size={ 210 , 20  }, mode = 1 ,value = "ch1;ch2;Two ch. (FRET);", title = "Extract traces from",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "ch1"
		elseif( TAPrefs.noChToggle == 2 )		// extracts traces for 2nd channel
			popupmenu noChPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 55 }, size={ 210 , 20  }, mode = 1 ,value = "ch1;ch2;Two ch. (FRET);", title = "Extract traces from",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "ch2"
		elseif( TAPrefs.noChToggle == 3 )		// extracts traces for two channels
			popupmenu noChPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 55 }, size={ 210 , 20  }, mode = 1 ,value = "ch1;ch2;Two ch. (FRET);", title = "Extract traces from",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Two ch. (FRET)"	
		endif
		// variable gaussian width during trace extraction
		if( TAPrefs.variableGWidth == 1 )
			popupmenu varGWidthPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 80 }, size={ 150 , 20  }, mode = 1 ,value = "on;off;", title = "Vary Gauss width",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "on"
		else
			popupmenu varGWidthPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 80 }, size={ 150 , 20  }, mode = 1 ,value = "on;off;", title = "Vary Gauss width",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "off"
		endif
		// variable gaussian center corrdinates during trace extraction
		if( TAPrefs.variableGcoord == 1 )
			popupmenu varGcoordPopUp font="Arial", fsize = 11, fstyle = 1, pos={165 , 80 }, size={ 100 , 20  }, mode = 1 ,value = "on;off;", title = "center",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "on"
		else
			popupmenu varGcoordPopUp font="Arial", fsize = 11, fstyle = 1, pos={165 , 80 }, size={ 100 , 20  }, mode = 1 ,value = "on;off;", title = "center",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "off"
		endif
		// SM trace intensity: amplitude / gauss integral
		if( TAPrefs.traceInt == 1 )
			popupmenu traceIntPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 105 }, size={ 210 , 20  }, mode = 1 ,value = "amplitude;gaussian integral", title = "Trace intensity",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "amplitude"
		else
			popupmenu traceIntPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 105 }, size={ 210 , 20  }, mode = 1 ,value = "amplitude;gaussian integral", title = "Trace intensity",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "gaussian integral"
		endif
		//   # of images to extract signal from
 		setVariable numImagesSetting disable = 0, fsize=12, limits={1, 10000, 1}, pos={10, 130}, size = {240, 20}, value = _NUM:TAPrefs.numImagesTA ,  proc = tracesAnalyzer#setting3_TA_MT , title= "# images for signal extraction", win=controlPanel2_TA
		//		
		GroupBox groupBox2 appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 5 , 5 }, size={ 255 , 150 }, win=controlPanel2_TA, title = "Trace extraction parameters"
		//****************************************   parameters for ICP detection part  *******************************************************************
		// traces filtering method and parameter value.
		if( TAPrefs.tracesFilterVariables[ 0 ] == 1 )
			popupmenu traceFiltPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 180 }, size={ 210 , 20  }, mode = 1 ,value = "Disabled;Smoothing;DWT;", title = "Filtering",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Disabled"
			setVariable testSetting29 disable = 1, fsize=12, limits={0,0,0}, pos={150, 180}, size = {100, 0}, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ], proc = tracesAnalyzer#setting01_TA_MT, win=controlPanel2_TA  // no signal filtering
		elseif( TAPrefs.tracesFilterVariables[ 0 ] == 2 )
			popupmenu traceFiltPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 180 }, size={ 210 , 20  }, mode = 1 ,value = "Disabled ;Smoothing;DWT;", title = "Filtering",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Smoothing"
			setVariable testSetting29 disable = 0, fsize=12, limits={0, inf , 1}, pos={150, 180}, size = {100, 0}, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ], proc = tracesAnalyzer#setting01_TA_MT, win=controlPanel2_TA , title = "size" // size of smoothig box.
		elseif( TAPrefs.tracesFilterVariables[ 0 ] == 3 )
			popupmenu traceFiltPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 180 }, size={ 210 , 20  }, mode = 1 ,value = "Disabled;Smoothing;DWT;", title = "Filtering",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "DWT"
			setVariable testSetting29 disable = 0, fsize=12, limits={0, 0.5, inf}, pos={150, 180}, size = {100, 0}, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ], proc = tracesAnalyzer#setting01_TA_MT, win=controlPanel2_TA, title = "freq."  // cut-off freq. for DWT.
		else
			TAPrefs.tracesFilterVariables[ 0 ] = 3
			popupmenu traceFiltPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 180 }, size={ 210 , 20  }, mode = 1 ,value = "Disabled;Smoothing;DWT;", title = "Filtering",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "DWT"
			setVariable testSetting29 disable = 0, fsize=12, limits={0, 0.5, inf}, pos={150, 180}, size = {100, 0}, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ], proc = tracesAnalyzer#setting01_TA_MT, win=controlPanel2_TA, title = "freq."  // cut-off freq. for DWT.
		endif
		//	normalisation of traces toggle
		if( TAPrefs.normaliseToggle == 1 )		// normalise to illumination image
			popupmenu normalisePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={10 , 205 }, size={ 210 , 20  }, mode = 1 ,value = "To illum. image;To begining;Disabled;", title = "Normalization",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "To illum. image"
		elseif( TAPrefs.normaliseToggle == 2 )	// normalise to begining of trace
			popupmenu normalisePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={10 , 205 }, size={ 210 , 20  }, mode = 1 ,value = "To illum. image;To begining;Disabled;", title = "Normalization",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "To begining"
		elseif( TAPrefs.normaliseToggle == 3 )	// do not normalise 
			popupmenu normalisePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={10 , 205 }, size={ 210 , 20  }, mode = 1 ,value = "To illum. image;To begining;Disabled;", title = "Normalization",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Disabled"		
		endif
		// ICP detection type
		if( TAPrefs.icpDetection[0] == 1 )		// AD ICP detection.
			popupmenu icpDetectionPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 230 }, size={ 210 , 20  }, mode = 1 ,value = "Amplitude and Duration;Hidden Markov Model;", title = "ICP detection",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Amplitude and Duration"	
			// amplitude type
			if( TAPrefs.minAmpTypeToggle == 1 )
				popupmenu ampTypeICPdet_popMenu disable = 0, font="Arial", fsize = 11, fstyle = 1, pos={10 , 255 }, size={ 210 , 20  }, mode = 1 ,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Dependent on SD"
			else
				popupmenu ampTypeICPdet_popMenu disable = 0, font="Arial", fsize = 11, fstyle = 1, pos={10 , 255 }, size={ 210 , 20  }, mode = 1 ,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Constant"						
			endif
			// minimal amplitude 
			setvariable testSetting16d disable = 0, fsize=12, limits={0, inf, 0.01}, pos={10, 280}, size = {80, 0}, value = _NUM:TAPrefs.minAmp,  proc = tracesAnalyzer#setting3_TA_MT , title= "Amp.", win=controlPanel2_TA
			// minimal duration 
			setvariable testSetting16e disable = 0, fsize=12, limits={0, inf, 1}, pos={100, 280}, size = {80, 0}, value = _NUM:TAPrefs.minDur,  proc = tracesAnalyzer#setting3_TA_MT , title= "Dur.", win=controlPanel2_TA
			// cluster states in ICP detection
			if( numtype(TAPrefs.clusterStates) != 0 )
				TAPrefs.clusterStates = 1
			endif
			if( TAPrefs.clusterStates == 1 )
				CheckBox clusterICPDet_ckeckBox disable = 0, win = controlPanel2_TA, title="Cluster" , size={80, 15}, value = 1, fsize=12, pos={ 190, 280 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
			else
				CheckBox clusterICPDet_ckeckBox disable = 0, win = controlPanel2_TA, title="Cluster" , size={80, 15}, value = 0, fsize=12, pos={ 190, 280 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
			endif
			//
		else			// HMM ICP detection
			TAPrefs.icpDetection[0] = 2
			popupmenu icpDetectionPopUp font="Arial", fsize = 11, fstyle = 1, pos={10 , 230 }, size={ 210 , 20  }, mode = 1 ,value = "Amplitude and Duration;Hidden Markov Model;", title = "ICP detection",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Hidden Markov Model"		
			// amplitude type
			popupmenu ampTypeICPdet_popMenu disable = 1, font="Arial", fsize = 11, fstyle = 1, pos={10 , 255 }, size={ 210 , 20  }, mode = 1 ,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Dependent on SD"
			// minimal amplitude 
			setvariable testSetting16d disable = 1, fsize=12, limits={0, inf, 0.01}, pos={10, 280}, size = {80, 0}, value = _NUM:TAPrefs.minAmp,  proc = tracesAnalyzer#setting3_TA_MT , title= "Amp.", win=controlPanel2_TA			
			// minimal duration 
			setvariable testSetting16e disable = 1, fsize=12, limits={0, inf, 1}, pos={100, 280}, size = {80, 0}, value = _NUM:TAPrefs.minDur,  proc = tracesAnalyzer#setting3_TA_MT , title= "Dur.", win=controlPanel2_TA
			// cluster states in ICP detection
			if( numtype(TAPrefs.clusterStates) != 0 )
				TAPrefs.clusterStates = 1
			endif
			if( TAPrefs.clusterStates == 1 )
				CheckBox clusterICPDet_ckeckBox disable = 1, win = controlPanel2_TA, title="Cluster" , size={80, 15}, value = 1, fsize=12, pos={ 190, 280 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
			else
				CheckBox clusterICPDet_ckeckBox disable = 1, win = controlPanel2_TA, title="Cluster" , size={80, 15}, value = 0, fsize=12, pos={ 190, 280 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
			endif
			//
		endif
		// expand trace
		if( TAPrefs.expandTrace[0] == 1 )
			CheckBox expandTrICPdet_checkBox disable = 0, win = controlPanel2_TA, title="Expand trace" , size={80, 15}, value = 1, fsize=12, pos={ 10, 305 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
			setvariable expandTrICPdet_setValue disable = 0, fsize=12, limits={0, inf, 1}, pos={120, 305}, size = {120, 15}, value = _NUM:TAPrefs.expandTrace[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "exp. factor", win=controlPanel2_TA
		else
			CheckBox expandTrICPdet_checkBox disable = 1, win = controlPanel2_TA, title="Expand trace" , size={80, 15}, value = 0, fsize=12, pos={ 10, 305 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
			setvariable expandTrICPdet_setValue disable = 0, fsize=12, limits={0, inf, 1}, pos={120, 305}, size = {120, 15}, value = _NUM:TAPrefs.expandTrace[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "exp. factor", win=controlPanel2_TA
		endif		
		// define states button
		helpStr = "Allows user to interactively define # of intensity groups and their intensity ranges."
		Button groupingTexButt disable = 0 , fsize=12, pos={10, 330}, fstyle=0,size={120, 20}, title = "Define groups", win=controlPanel2_TA, proc = tracesAnalyzer6#grouping_Tex_TA_MT, help={helpStr}
		//  unique fracion of table name to idealise.
		string namesIdTrTable = "\""+"030_0_;030_1_;030_2_;030_6_;030_7_;"+"\""
		string namesIdTrTable1 = "030_0_;030_1_;030_2_;030_6_;030_7_;"
		if( numtype(TAPrefs.IdTrName) != 0 )
			TAPrefs.IdTrName = 1
		endif
		variable indexIdTr = TAPrefs.IdTrName
		popupmenu trToIdealpopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={10, 355}, size={ 210 , 20  }, mode = 1, value = #namesIdTrTable, title = "Name of signal to idealise", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = stringFromList(indexIdTr-1, namesIdTrTable1, ";")
		//
		string IdSelAllTrStr = "\""+"Selected signals;All signals;"+"\""
		string IdSelAllTrStr1 = "Selected signals;All signals;"
		if( numtype(TAPrefs.IdSelAllTrName) != 0 )
			TAPrefs.IdSelAllTrName = 1
		endif
		popupmenu selAllIdealpopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={10, 380}, size={ 210 , 20  }, mode = 1, value = #IdSelAllTrStr, title = "Det. ICP & char. states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = stringFromList(TAPrefs.IdSelAllTrName-1, IdSelAllTrStr1, ";")
		// remove bleached fraction of trace before ICP detection
		if( numtype(TAPrefs.removeBleach) != 0 )
			TAPrefs.removeBleach = 1
		endif
		if( TAPrefs.removeBleach == 1 )
			CheckBox remBleachIdeal_ckeckBox win = controlPanel2_TA, title="Remove bleach FRET fr. prior ICP" , size={190, 15}, value = 1, fsize=12, pos={ 10, 405 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		else
			CheckBox remBleachIdeal_ckeckBox win = controlPanel2_TA, title="Remove bleach FRET fr. prior ICP" , size={190, 15}, value = 0, fsize=12, pos={ 10, 405 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
		endif
		//	anti-correlation checkbox
		if( TAPrefs.antiCorToggleMain == 1 )
			CheckBox testSettingAntiCorr win = controlPanel2_TA, title = "Anti-corr. test" , size={190, 15}, value = 1 , fsize=12, pos={ 10, 430}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
			SetVariable testSettingAmpCoef1 disable = 0, fsize=12, limits={0, inf, 0.01}, pos={10, 455}, size = {140, 0}, value = _NUM:TAPrefs.coefStepAmp[1], proc = tracesAnalyzer#setting3_TA_MT , title= "Amp. ch1",win=controlPanel2_TA
			SetVariable testSettingAmpCoef2 disable = 0, fsize=12, limits={0, inf, 0.01}, pos={160, 455}, size = {90, 0}, value = _NUM:TAPrefs.coefStepAmp[2], proc = tracesAnalyzer#setting3_TA_MT , title= "ch2",win=controlPanel2_TA
		else
			CheckBox testSettingAntiCorr win = controlPanel2_TA, title = "Anti-corr. test" , size={190, 15}, value = 0 , fsize=12, pos={ 10, 430}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
			SetVariable testSettingAmpCoef1 disable = 1, fsize=12, limits={0, inf, 0.01}, pos={10, 455}, size = {140, 0}, value = _NUM:TAPrefs.coefStepAmp[1], proc = tracesAnalyzer#setting3_TA_MT , title= "Amp. ch1",win=controlPanel2_TA
			SetVariable testSettingAmpCoef2 disable = 1, fsize=12, limits={0, inf, 0.01}, pos={160, 455}, size = {90, 0}, value = _NUM:TAPrefs.coefStepAmp[2], proc = tracesAnalyzer#setting3_TA_MT , title= "ch2",win=controlPanel2_TA
		endif
		// display results of ICP detection
		if( numtype(TAPrefs.silentICPDetection) != 0 )
			TAPrefs.silentICPDetection = 1
		endif
		if( TAPrefs.silentICPDetection == 1 )
			CheckBox silentICP_ckeckBox win = controlPanel2_TA, title="Display output ICP & state char." , size={190, 15}, value = 1, fsize=12, pos={ 10, 480 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
		else
			CheckBox silentICP_ckeckBox win = controlPanel2_TA, title="Display output ICP & state char." , size={190, 15}, value = 0, fsize=12, pos={ 10, 480 }, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
		endif
		//
		GroupBox groupBoxICP appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 5 , 155 }, size={ 255 , 345 }, win=controlPanel2_TA, title = "ICP detection parameters"
		//*********************************			  parameters for auto sort traces function				**************************************************
		setVariable testSetting23 disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={270, 30}, size = {130, 0}, value = _NUM:TAPrefs.sizeImage[ 2 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "Main ROI X0", win=controlPanel2_TA // x0
		setVariable testSetting24 disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={400, 30}, size = {80, 0}, value = _NUM:TAPrefs.sizeImage[ 3 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "X1", win=controlPanel2_TA // x1
		setVariable testSetting24a disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={270, 55}, size = {130, 0}, value = _NUM:TAPrefs.sizeImage[ 4 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "Main ROI Y0", win=controlPanel2_TA // y1
		setVariable testSetting24b disable = 0, fsize=12, limits={0, 2000, 0.1}, pos={400, 55}, size = {80, 0}, value = _NUM:TAPrefs.sizeImage[ 5 ] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "Y1", win=controlPanel2_TA // y2
		// exclude multi-molecule traces
		if( TAPrefs.levelsSM[ 0 ] == 1 )
			CheckBox testSetting4 win = controlPanel2_TA, title="Exclude MM" , size={100, 15}, value = 1 , fsize=12, pos={ 270, 80}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT     	  // Excluding MM trajectories on
			// MM level in trajectories
			setvariable testSetting16a disable = 0, fsize=12, limits={0, inf, inf}, pos={380, 80}, size = {100, 0}, value = _NUM:TAPrefs.levelsSM[ 1 ],  proc = tracesAnalyzer#setting3_TA_MT , title= "Int.", win=controlPanel2_TA	
		else
			CheckBox testSetting4 win = controlPanel2_TA, title="Exclude MM" , size={100, 15}, value = 0 , fsize=12, pos={ 270, 80}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT     	  // Excluding MM trajectories off
			// MM level in trajectories
			setvariable testSetting16a disable = 1, fsize=12, limits={0, inf, inf}, pos={380, 80}, size = {100, 0}, value = _NUM:TAPrefs.levelsSM[ 1 ],  proc = tracesAnalyzer#setting3_TA_MT , title= "Int.", win=controlPanel2_TA
		endif
		//
		// exclude empty traces
		if( TAPrefs.neverBleach[ 0 ] == 1 )
			CheckBox checkBox_empty win = controlPanel2_TA, title = "Remove empty", size={100, 15}, value = 1 , fsize=12, pos={ 270, 105}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT     	  // Excluding empty trajectories on
			// SD for empty traj exclusion
			setvariable setVarCtrl_neverBleach disable = 0, fsize=12, limits={0, inf, inf}, pos={400, 105}, size = {80, 0}, value = _NUM:TAPrefs.neverBleach[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA
		else
			CheckBox checkBox_empty win = controlPanel2_TA, title = "Remove empty", size={100, 15}, value = 0 , fsize=12, pos={ 270, 105}, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT     	  // Excluding empty trajectories off
			// SD for empty traj exclusion
			setvariable setVarCtrl_neverBleach disable = 1, fsize=12, limits={0, inf, inf}, pos={400, 105}, size = {80, 0}, value = _NUM:TAPrefs.neverBleach[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA
		endif
		// npnts above threshold for empty traj and MM traj.
		if( TAPrefs.levelsSM[ 0 ] == 1 || TAPrefs.neverBleach[ 0 ] == 1 )
			setvariable testSetting16c disable = 0, fsize=12, limits={0, inf, 1}, pos={270, 130}, size = {210, 0}, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT , title= "# pnts above thresholds", win=controlPanel2_TA
		else
			setvariable testSetting16c disable = 1, fsize=12, limits={0, inf, 1}, pos={270, 130}, size = {210, 0}, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT , title= "# pnts above thresholds", win=controlPanel2_TA
		endif
		// 
		GroupBox gBox_addSett2 appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 265 , 5 }, size={ 219 , 150 }, title = "Auto sorting parameters", win=controlPanel2_Ta
		//********************************    parameters for characterize states part      **********************************
		// remove bleached state from state info table.
		if( numtype(TAPrefs.blStateToggle2) != 0 )
			TAPrefs.blStateToggle2 = 1
		endif
		if( TAPrefs.blStateToggle2 == 1 )
			popupmenu remBleachState_popUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 180 }, size={ 190 , 15  }, mode = 1 ,value = "FRET;Not FRET;Disabled;", title = "Bleach.", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "FRET"
			// # SD for bleached state detection
			setvariable testSettingNSDBleach disable = 1, fsize=12, limits={0, inf, inf}, pos={390, 180}, size = {90, 0}, value = _NUM:TAPrefs.nSdevBleach,  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA
		elseif( TAPrefs.blStateToggle2 == 2 )
			popupmenu remBleachState_popUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 180 }, size={ 190 , 15  }, mode = 1 ,value = "FRET;Not FRET;Disabled;", title = "Bleach.", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Not FRET"
			// # SD for bleached state detection
			setvariable testSettingNSDBleach disable = 0, fsize=12, limits={0, inf, inf}, pos={390, 180}, size = {90, 0}, value = _NUM:TAPrefs.nSdevBleach,  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA
		else
			popupmenu remBleachState_popUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 180 }, size={ 190 , 15  }, mode = 1 ,value = "FRET;Not FRET;Disabled;", title = "Bleach.", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Disabled"	
			// # SD for bleached state detection
			setvariable testSettingNSDBleach disable = 1, fsize=12, limits={0, inf, inf}, pos={390, 180}, size = {90, 0}, value = _NUM:TAPrefs.nSdevBleach,  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA		
		endif
		//	use all or selected signals for state char.
		if( TAPrefs.IdSelAllTrStateChar == 1 )		// selected
			popupmenu allORselected_stChar_PopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 205 }, size={ 210 , 20  }, mode = 1 ,value = "Selectd signals;All signals;", title = "Use", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Selectd signals"
		elseif( TAPrefs.IdSelAllTrStateChar == 2 )	// all signals
			popupmenu allORselected_stChar_PopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 205 }, size={ 210 , 20  }, mode = 1 ,value = "Selectd signals;All signals;", title = "Use", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "All signals"
		else
			TAPrefs.IdSelAllTrStateChar = 1
			popupmenu allORselected_stChar_PopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 205 }, size={ 210 , 20  }, mode = 1 ,value = "Selectd signals;All signals;", title = "Use", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Selectd signals"
		endif
		//	exclude first/last state
		if( TAPrefs.blStateToggle == 1 )		// None
			popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 230 }, size={ 210 , 20  }, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "None"
		elseif( TAPrefs.blStateToggle == 2 )	// First
			popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 230 }, size={ 210 , 20  }, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "First"
		elseif( TAPrefs.blStateToggle == 3 )	// Last	
			popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 230 }, size={ 210 , 230  }, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Last"
		elseif( TAPrefs.blStateToggle == 4 )	// First & last	
			popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 230 }, size={ 210 , 230  }, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "First & last"		
		endif
		//
		GroupBox gBox_addSett_charState appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 265 , 155 }, size={ 219 , 100 }, title = "State char. parameters", win=controlPanel2_Ta
		//********************************    		parameters for image set-up							*************************************************************
		// Image type
		if( TAPrefs.imageTypeTA[0] == 1 )
			popupmenu imageTypePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 280} , size={ 210, 20  }, mode = 1 ,value = "dual-view;dual-cam;", title = "Camera set-up",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "dual-view"
		else
			popupmenu imageTypePopUp font="Arial", fsize = 11, fstyle = 1, pos={ 270, 280 }, size={ 210, 20  }, mode = 1 ,value = "dual-view;dual-cam;", title = "Camera set-up",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "dual-cam"
		endif	
		// Image type: 1st ch location
		if( TAPrefs.imageTypeTA[0] == 1 )
			if( TAPrefs.imageTypeTA[1] == 1 )
				popupmenu stChLocPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 305 }, size={ 210, 20  }, mode = 1 ,value = "top/left;bottom/right;", title = "ch1 (donor) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "top/left"
			else
				popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, pos={ 270, 305 }, size={ 210, 20  }, mode = 1 ,value = "top/left;bottom/right;", title = "ch1 (donor) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "bottom/right"
			endif
		else
			if( TAPrefs.imageTypeTA[1] == 1 )
				popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, pos={ 270, 305 }, size={ 210 , 20  }, mode = 1 ,value = "1st;2nd;", title = "ch1 (donor) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			else
				popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, pos={ 270, 305 }, size={ 210 , 20  }, mode = 1 ,value = "1st;2nd;", title = "ch1 (donor) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			endif	
		endif
		// Image type: 2nd ch location
		if( TAPrefs.imageTypeTA[0] == 1 )
			if( TAPrefs.imageTypeTA[2] == 1 )
				popupmenu ndChLocPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 330 }, size={ 210 , 20  }, mode = 1 ,value = "top/left;bottom/right;", title = "ch2 (acc) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "top/left"
			else
				popupmenu ndChLocPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 330 }, size={ 210 , 20  }, mode = 1 ,value = "top/left;bottom/right", title = "ch2 (acc) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "bottom/right"
			endif
		else
			if( TAPrefs.imageTypeTA[2] == 1 )
				popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, pos={ 270, 330 }, size={ 210 , 20  }, mode = 1 ,value = "1st;2nd;", title = "ch2 (acc) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			else
				popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, pos={ 270, 330 }, size={ 210 , 20  }, mode = 1 ,value = "1st;2nd;", title = "ch2 (acc) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			endif	
		endif
		// Image type: orientation of image splitter
		if( TAPrefs.imageTypeTA[0] == 1 )
			if( TAPrefs.imageTypeTA[3] == 1 )
				popupmenu orientImagePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 355 }, size={ 210 , 20  }, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "horizontal"
			else
				popupmenu orientImagePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 355 }, size={ 210 , 20  }, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "vertical"
			endif
		else
			if( TAPrefs.imageTypeTA[3] == 1 )
				popupmenu orientImagePopUp font="Arial", disable=1, fsize = 11, fstyle = 1, pos={ 270, 355 }, size={ 210 , 20  }, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "horizontal"
			else
				popupmenu orientImagePopUp font="Arial", disable=1, fsize = 11, fstyle = 1, pos= {270, 355 }, size={ 210 , 20  }, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "vertical"
			endif	
		endif
		// Image type: # of folders in directory
		if( TAPrefs.imageTypeTA[0] == 1 )
			if( TAPrefs.imageTypeTA[4] == 1 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			elseif( TAPrefs.imageTypeTA[4] == 2 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			elseif( TAPrefs.imageTypeTA[4] == 3 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "two"		
			endif
		else
			if( TAPrefs.imageTypeTA[4] == 1 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			elseif( TAPrefs.imageTypeTA[4] == 2 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			elseif( TAPrefs.imageTypeTA[4] == 3 )
				popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 380 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;two;", title = "Folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "two"
			endif
		endif
		// indicator of normalisation image folder
		if( TAPrefs.normaliseToggle == 1 ) // normalisation switched on
			if( TAPrefs.normFolder == 1 )
				popupmenu normFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "Folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			elseif( TAPrefs.normFolder == 2 )
				popupmenu normFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "Folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			else
				popupmenu normFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "Folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "3rd"
			endif
		else
			if( TAPrefs.normFolder == 1 )
				popupmenu normFolderPopUp font="Arial",disable=1, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
			elseif( TAPrefs.normFolder == 2 )
				popupmenu normFolderPopUp font="Arial",disable=1, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
			else
				popupmenu normFolderPopUp font="Arial",disable=1, fsize = 11, fstyle = 1, pos={ 270, 405 }, size={ 210, 20}, mode = 1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "3rd"
			endif
		endif
		// excitation type
		if( TAPrefs.excType == 1 )
			popupmenu excTypePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 430 }, size={ 150, 20}, mode = 1 ,value = "ALEX;Single laser;", title = "Excitation", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "ALEX"
			if( TAPrefs.alex_stLaser == 1 )
				popupmenu stLaserPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 390, 430 }, size={ 110, 20}, mode = 1 ,value = "Red;Green;", title = "Laser", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Red"		
			else
				popupmenu stLaserPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 390, 430 }, size={ 110, 20}, mode = 1 ,value = "Red;Green;", title = "Laser", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Green"		
			endif
		elseif( TAPrefs.excType == 2 )
			popupmenu excTypePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, pos={ 270, 430 }, size={ 150, 20}, mode = 1 ,value = "ALEX;Single laser;", title = "Excitation", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Single laser"
			popupmenu stLaserPopUp font="Arial",disable=1, fsize = 11, fstyle = 1, pos={ 390, 430 }, size={ 110, 20}, mode = 1 ,value = "Red;Green;", title = "Laser", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Red"		
		endif
		//	image type 
		if( TAPrefs.imageFileType == 1 )			// TIFF stack
			popupmenu imageFileTypePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={ 270 , 455 }, size={ 210 , 20  }, mode = 1 ,value = "TIFF stack;signed 32-bit binary;TIFF series;", title = "File type", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "TIFF stack"
		elseif( TAPrefs.imageFileType == 2 )		// signed 32-bit binary
			popupmenu imageFileTypePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={ 270 , 455 }, size={ 210 , 20  }, mode = 1 ,value = "TIFF stack;signed 32-bit binary;TIFF series;", title = "File type", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Signed 32-bit binary"
		elseif( TAPrefs.imageFileType == 3 )		// TIFF series
			popupmenu imageFileTypePopUp font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={ 270 , 455 }, size={ 210 , 20  }, mode = 1 ,value = "TIFF stack;signed 32-bit binary;TIFF series;", title = "File type", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "TIFF series"
		endif
		//
		GroupBox gBox_addSett4 appearance={default, Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 265 , 255 }, size={ 219 , 225 }, title = "Image set-up", win=controlPanel2_Ta
		//**************************************************		     aling channels parameters     						**************************************************************************************
		if( TAPrefs.regParams[ 0 ] == 1 ) // align
			//
			setVariable imRegSet1 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 505}, size = {100, 20}, value = _NUM:TAPrefs.regParams[1]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dx ", win=controlPanel2_TA
			setVariable imRegSet2 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 505}, size = {100, 20}, value = _NUM:TAPrefs.regParams[2]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dy ", win=controlPanel2_TA
			setVariable imRegSet3 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 530}, size = {100, 20}, value = _NUM:TAPrefs.regParams[3]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a11", win=controlPanel2_TA
			setVariable imRegSet4 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 530}, size = {100, 20}, value = _NUM:TAPrefs.regParams[4]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a12", win=controlPanel2_TA
			setVariable imRegSet5 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 555}, size = {100, 20}, value = _NUM:TAPrefs.regParams[5]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a21", win=controlPanel2_TA
			setVariable imRegSet6 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 555}, size = {100, 20}, value = _NUM:TAPrefs.regParams[6]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a22", win=controlPanel2_TA
			setVariable imRegSet7 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 580}, size = {100, 20}, value = _NUM:TAPrefs.regParams[7]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a33", win=controlPanel2_TA
			setVariable imRegSet8 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 580}, size = {100, 20}, value = _NUM:TAPrefs.regParams[8]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin X", win=controlPanel2_TA
			setVariable imRegSet9 disable = 0, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 605}, size = {100, 20}, value = _NUM:TAPrefs.regParams[9]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin Y", win=controlPanel2_TA
			//
			popupmenu regImagesPopup font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={ 380 , 605 }, size={ 110 , 20  }, mode = 1 ,value = "Yes;No;", title = "Align ch2", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Yes"
			//
		else		// don't align
			//
			setVariable imRegSet1 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 505}, size = {100, 20}, value = _NUM:TAPrefs.regParams[1] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dx ", win=controlPanel2_TA
			setVariable imRegSet2 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 505}, size = {100, 20}, value = _NUM:TAPrefs.regParams[2] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dy ", win=controlPanel2_TA
			setVariable imRegSet3 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 530}, size = {100, 20}, value = _NUM:TAPrefs.regParams[3] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a11", win=controlPanel2_TA
			setVariable imRegSet4 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 530}, size = {100, 20}, value = _NUM:TAPrefs.regParams[4] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a12", win=controlPanel2_TA
			setVariable imRegSet5 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 555}, size = {100, 20}, value = _NUM:TAPrefs.regParams[5] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a21", win=controlPanel2_TA
			setVariable imRegSet6 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 555}, size = {100, 20}, value = _NUM:TAPrefs.regParams[6] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a22", win=controlPanel2_TA
			setVariable imRegSet7 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 580}, size = {100, 20}, value = _NUM:TAPrefs.regParams[7] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a33", win=controlPanel2_TA
			setVariable imRegSet8 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={380, 580}, size = {100, 20}, value = _NUM:TAPrefs.regParams[8] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin X", win=controlPanel2_TA
			setVariable imRegSet9 disable = 1, fsize=12, limits={-inf, inf, 0.000001}, pos={270, 605}, size = {100, 20}, value = _NUM:TAPrefs.regParams[9] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin Y", win=controlPanel2_TA
			//
			popupmenu regImagesPopup font="Arial", disable = 0, fsize = 11, fstyle = 1, pos={ 380 , 605 }, size={ 110 , 20  }, mode = 1 ,value = "Yes;No;", title = "Align ch2", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "No"
			//
		endif
		//
		helpStr = "Executes alignment parameter calculation of dual-view or dual-cam images."
		Button getAlignParamButt disable = 0 , fsize=12, pos={ 270, 630 }, fstyle=0, size={140, 20}, title = "Calculate parameters", win=controlPanel2_TA, proc = tracesAnalyzer7#regisrationThresholdIma_TA_MT, help={helpStr}
		//	Box that surrounds variables
		GroupBox gBox_addSett5 appearance={default , Mac}, fColor=(0,0,40000), frame=5, fsize=12,fstyle=1, pos={ 265 , 480 }, size={ 220 , 175 }, title = "Image align parameters", win=controlPanel2_Ta
		//
		dowindow/f controlPanel2_TA
		AutoPositionWindow/R=controlPanel_TA  controlPanel2_TA
		//
	else			// hide the panel.
		//
		dowindow/hide = 1 controlPanel2_TA
		//
		getCoords_TA_MT( TAPrefs )
		save_preferences_TA_MT( TAPrefs )
		//
	endif
	//
end
// setting values for popupmenuControl variables
static function setting1_TA_MT(PM_Struct) : PopupMenuControl
	STRUCT WMPopupAction &PM_Struct 
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//
	string removeBleachedStr, removeBleachedStr1
	//
	if( PM_Struct.eventCode == 1 || PM_Struct.eventCode == 2 )		// act only on Enter key accepting edit, or on mouse up in the arrow buttons
		// checking which of the popup men us where selected
		strswitch( PM_Struct.ctrlName )						// string switch
		case "paricleTogglePopUp":
			TAPrefs.paricleToggle = PM_Struct.popNum
			break
		case "noChPopUp":
			TAPrefs.noChToggle = PM_Struct.popNum
			//
			break
		case "trToIdealpopUp":
			TAPrefs.IdTrName = PM_Struct.popNum
			//
			if( numtype(TAPrefs.IdTrName) != 0 )
				TAPrefs.IdTrName = 1
			endif
			//
			variable indexTrId = TAPrefs.IdTrName
			string namesIdTrTable = "\""+"030_0_;030_1_;030_2_;030_6_;030_7_;"+"\""
			string namesIdTrTable1 = "030_0_;030_1_;030_2_;030_6_;030_7_;"
			popupmenu trToIdealpopUp font="Arial", mode = 1 ,value = #namesIdTrTable, win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = stringFromList(indexTrId-1, namesIdTrTable1, ";")
			//
			break
		case "selAllIdealpopUp":
			TAPrefs.IdSelAllTrName = PM_Struct.popNum
			//
			if( numtype(TAPrefs.IdSelAllTrName) != 0 )
				TAPrefs.IdSelAllTrName = 1
			endif
			//
			string IdSelAllTrStr = "\""+"Selected signals;All signals;"+"\""
			string IdSelAllTrStr1 = "Selected signals;All signals;"
			popupmenu selAllIdealpopUp font="Arial", mode = 1 ,value = #IdSelAllTrStr, win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = stringFromList(TAPrefs.IdSelAllTrName-1, IdSelAllTrStr1, ";")
			//
			break
		case "normalisePopUp":
			TAPrefs.normaliseToggle = PM_Struct.popNum
			//
			if( TAPrefs.normaliseToggle == 1 )
				if( TAPrefs.normFolder == 1 )
					popupmenu normFolderPopUp font="Arial",disable=0 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
				elseif( TAPrefs.normFolder == 2 )
					popupmenu normFolderPopUp font="Arial",disable=0 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
				else
					popupmenu normFolderPopUp font="Arial",disable=0 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "3rd"
				endif
			else
				if( TAPrefs.normFolder == 1 )
					popupmenu normFolderPopUp font="Arial",disable=1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
				elseif( TAPrefs.normFolder == 2 )
					popupmenu normFolderPopUp font="Arial",disable=1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
				else
					popupmenu normFolderPopUp font="Arial",disable=1 ,value = "1st;2nd;3rd;", title = "folder with norm. image", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "3rd"
				endif		
			endif
			//
			break
		case "traceFiltPopUp":
			TAPrefs.tracesFilterVariables[ 0 ] = PM_Struct.popNum
			// report toggle value
			if( TAPrefs.tracesFilterVariables[ 0 ]  == 1 )
				setVariable testSetting29 disable = 1
			elseif( TAPrefs.tracesFilterVariables[ 0 ]  == 2 )
				setVariable testSetting29 disable = 0, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ],  title = "size"
			elseif( TAPrefs.tracesFilterVariables[ 0 ]  == 3 )
				setVariable testSetting29 disable = 0, value = _NUM:TAPrefs.tracesFilterVariables[ 1 ],  title = "freq."
			endif
			//
			break
		case "traceIntPopUp":
			TAPrefs.traceInt = PM_Struct.popNum 
			//
			break
		case "varGWidthPopUp":
			TAPrefs.variableGWidth = PM_Struct.popNum
			//
			break
		case "varGcoordPopUp":
			TAPrefs.variableGcoord = PM_Struct.popNum
			//
			break
		case "ampTypeICPdet_popMenu":							// amplitude type in Amp&Dur detection.
			TAPrefs.minAmpTypeToggle = PM_Struct.popNum
			//
			break
		case "icpDetectionPopUp":
			//
			TAPrefs.icpDetection[0] = PM_Struct.popNum
			// for ICP detection
			if( TAPrefs.icpDetection[ 0 ] == 1 ) //amplitude & duration
				// minimal amplitude 
				setvariable testSetting16d disable = 0, fsize=12, limits={0, inf, 0.01}, value = _NUM:TAPrefs.minAmp
				// minimal duration 
				setvariable testSetting16e disable = 0, fsize=12, limits={0, inf, 1}, value = _NUM:TAPrefs.minDur
				// cluster states in ICP detection
				if( numtype(TAPrefs.clusterStates) != 0 )
					TAPrefs.clusterStates = 1
				endif
				if( TAPrefs.clusterStates == 1 )
					CheckBox clusterICPDet_ckeckBox disable = 0, win = controlPanel2_TA, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
				else
					CheckBox clusterICPDet_ckeckBox disable = 0, win = controlPanel2_TA, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
				endif
				// amplitude type
				if( TAPrefs.minAmpTypeToggle == 1 )
					popupmenu ampTypeICPdet_popMenu disable = 0,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "Dependent on SD"
				else
					popupmenu ampTypeICPdet_popMenu disable = 0,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "Constant"						
				endif
				//
			elseif( TAPrefs.icpDetection[ 0 ] == 2 ) // HMM factor
				// minimal amplitude 
				setvariable testSetting16d disable = 1, fsize=12, limits={0, inf, 0.01}, value = _NUM:TAPrefs.minAmp
				// minimal duration 
				setvariable testSetting16e disable = 1, fsize=12, limits={0, inf, 1}, value = _NUM:TAPrefs.minDur
				// cluster states in ICP detection
				if( numtype(TAPrefs.clusterStates) != 0 )
					TAPrefs.clusterStates = 1
				endif
				if( TAPrefs.clusterStates == 1 )
					CheckBox clusterICPDet_ckeckBox disable = 1, win = controlPanel2_TA, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT
				else
					CheckBox clusterICPDet_ckeckBox disable = 1, win = controlPanel2_TA, mode = 0 , proc = tracesAnalyzer#setting2_TA_MT	
				endif
				// amplitude type
				popupmenu ampTypeICPdet_popMenu disable = 1,value = "Dependent on SD;Constant;", title = "Amplitude type",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "Dependent on SD"
				//
			endif			
			//
			break		
		case "blStatePopUp":
			TAPrefs.blStateToggle = PM_Struct.popNum
			//
			if( TAPrefs.blStateToggle == 1 )		// None
				popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "None"
			elseif( TAPrefs.blStateToggle == 2 )	// First
				popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "First"
			elseif( TAPrefs.blStateToggle == 3 )	// Last	
				popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Last"
			elseif( TAPrefs.blStateToggle == 4 )	// First & last	
				popupmenu blStatePopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "None;First;Last;First & last;", title = "Exclude partial states", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "First & last"		
			endif
			//
			break
		case "allORselected_stChar_PopUp":
			TAPrefs.IdSelAllTrStateChar = PM_Struct.popNum
			//
			if( TAPrefs.IdSelAllTrStateChar == 1 )		// selected signals
				popupmenu allORselected_stChar_PopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "Selected signals;All signals;", title = "Use", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "Selected signals"
			elseif( TAPrefs.IdSelAllTrStateChar == 2 )	// all signals
				popupmenu allORselected_stChar_PopUp font="Arial", fsize = 11, fstyle = 1, mode = 1 ,value = "Selected signals;All signals;", title = "Use", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "All signals"
			endif
			//
			break
			
		case "remBleachState_popUp":	// remove bleached state from state info table: FRET, Not FRET, Disabled.
			TAPrefs.blStateToggle2 = PM_Struct.popNum
			//
			if( TAPrefs.blStateToggle2 == 2 )
				setvariable testSettingNSDBleach disable = 0, value = _NUM:TAPrefs.nSdevBleach,  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			else
				setvariable testSettingNSDBleach disable = 1, value = _NUM:TAPrefs.nSdevBleach,  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			endif
			//
			break			
			//
		case "imageFileTypePopUp":
			TAPrefs.imageFileType = PM_Struct.popNum
			//
			break
		case "regImagesPopup":
			TAPrefs.regParams[ 0 ] = PM_Struct.popNum
			if( TAPrefs.regParams[ 0 ] == 1 )
				//
				setVariable imRegSet1 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[1]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dx", win=controlPanel2_TA
				setVariable imRegSet2 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[2]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dy", win=controlPanel2_TA
				setVariable imRegSet3 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[3]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a11", win=controlPanel2_TA
				setVariable imRegSet4 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[4]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a12", win=controlPanel2_TA
				setVariable imRegSet5 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[5]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a21", win=controlPanel2_TA
				setVariable imRegSet6 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[6]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a22", win=controlPanel2_TA
				setVariable imRegSet7 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[7]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a33", win=controlPanel2_TA
				setVariable imRegSet8 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[8]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin X", win=controlPanel2_TA
				setVariable imRegSet9 disable = 0, fsize=12, value = _NUM:TAPrefs.regParams[9]  ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin Y", win=controlPanel2_TA
				//
			else
				//
				setVariable imRegSet1 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[1] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dx", win=controlPanel2_TA
				setVariable imRegSet2 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[2] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "dy", win=controlPanel2_TA
				setVariable imRegSet3 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[3] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a11", win=controlPanel2_TA
				setVariable imRegSet4 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[4] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a12", win=controlPanel2_TA
				setVariable imRegSet5 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[5] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a21", win=controlPanel2_TA
				setVariable imRegSet6 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[6] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a22", win=controlPanel2_TA
				setVariable imRegSet7 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[7] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "a33", win=controlPanel2_TA
				setVariable imRegSet8 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[8] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin X", win=controlPanel2_TA
				setVariable imRegSet9 disable = 1, fsize=12, value = _NUM:TAPrefs.regParams[9] ,  proc = tracesAnalyzer#setting3_TA_MT , title= "origin Y", win=controlPanel2_TA
				//
			endif
			//
			break		
		case "imageTypePopUp":
			TAPrefs.imageTypeTA[0] = PM_Struct.popNum
			//
			if( TAPrefs.imageTypeTA[0] == 1 )
				if( TAPrefs.imageTypeTA[1] == 1 )
					popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "top/left;bottom/right;", title = "ch1 (donor) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "top/left"
				else
					popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "top/left;bottom/right;", title = "ch1 (donor) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "bottom/right"
				endif
				//
				if( TAPrefs.imageTypeTA[2] == 1 )
					popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "top/left;bottom/right;", title = "ch2 (acc) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "top/left"
				else
					popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "top/left;bottom/right;", title = "ch2 (acc) loc.:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "bottom/right"
				endif
				//
				if( TAPrefs.imageTypeTA[3] == 1 )
					popupmenu orientImagePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "horizontal"
				else
					popupmenu orientImagePopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "vertical"
				endif
				//
				if( TAPrefs.imageTypeTA[4] == 1 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "1st"
				elseif( TAPrefs.imageTypeTA[4] == 2 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "2nd"
				elseif( TAPrefs.imageTypeTA[4] == 3 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "two"			
				endif		
				//
			else
				if( TAPrefs.imageTypeTA[1] == 1 )
					popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "1st;2nd;", title = "ch1 (donor) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
				else
					popupmenu stChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "1st;2nd;", title = "ch1 (donor) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
				endif
				//
				if( TAPrefs.imageTypeTA[2] == 1 )
					popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "1st;2nd;", title = "ch2 (acc) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "1st"
				else
					popupmenu ndChLocPopUp font="Arial", disable=0, fsize = 11, fstyle = 1, mode = 1 ,value = "1st;2nd;", title = "ch2 (acc) folder:",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "2nd"
				endif
				//
				if( TAPrefs.imageTypeTA[3] == 1 )
					popupmenu orientImagePopUp font="Arial",disable=1, fsize = 11, fstyle = 1, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "horizontal"
				else
					popupmenu orientImagePopUp font="Arial",disable=1, fsize = 11, fstyle = 1, mode = 1 ,value = "horizontal;vertical;", title = "Orientation of image",win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT,  popvalue = "vertical"
				endif
				//
				if( TAPrefs.imageTypeTA[4] == 1 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "1st"
				elseif( TAPrefs.imageTypeTA[4] == 2 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "2nd"
				elseif( TAPrefs.imageTypeTA[4] == 3 )
					popupmenu numFolderPopUp font="Arial",disable=0, fsize = 11, fstyle = 1, mode = 1 , value = "1st;2nd;two;", title = "folder with image series", win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT, popvalue = "two"			
				endif
				//
			endif
			//
			break
		case "stChLocPopUp":
			TAPrefs.imageTypeTA[1] = PM_Struct.popNum
			//
			break
		case "ndChLocPopUp":
			TAPrefs.imageTypeTA[2] = PM_Struct.popNum
			//
			break
		case "orientImagePopUp":
			TAPrefs.imageTypeTA[3] = PM_Struct.popNum
			//
			break
		case "numFolderPopUp":
			TAPrefs.imageTypeTA[4] = PM_Struct.popNum
			//
			break
		case "normFolderPopUp":
			TAPrefs.normFolder = PM_Struct.popNum
			//
			break
		case "excTypePopUp":
			TAPrefs.excType = PM_Struct.popNum
			//
			if( TAPrefs.excType == 1 )
				popupmenu stLaserPopUp font="Arial",disable=0, win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT
			else
				popupmenu stLaserPopUp font="Arial",disable=1, win = controlPanel2_TA, proc =  tracesAnalyzer#setting1_TA_MT
			endif
			//
			break
		case "stLaserPopUp":
			TAPrefs.alex_stLaser = PM_Struct.popNum
			//
			break
		endswitch
		//
	endif
	//
	getCoords_TA_MT( TAPrefs )
	save_preferences_TA_MT( TAPrefs )
	//
end
//  setting values for check box controls variables
Function setting2_TA_MT (CB_Struct) : CheckBoxControl
	STRUCT WMCheckboxAction &CB_Struct
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//
	if( CB_Struct.eventCode == 1 || CB_Struct.eventCode == 2 )		// act only on Enter key accepting edit, or on mouse up in the arrow buttons
		// checking which of the check boxes where selected
		strswitch( CB_Struct.ctrlName )						// string switch
		case "testSettingAntiCorr":	// anti-correlation
			TAPrefs.antiCorToggleMain = CB_Struct.checked
			if( TAPrefs.antiCorToggleMain == 1 )
				SetVariable testSettingAmpCoef1 disable = 0, value = _NUM:TAPrefs.coefStepAmp[1], proc = tracesAnalyzer#setting3_TA_MT
				SetVariable testSettingAmpCoef2 disable = 0, value = _NUM:TAPrefs.coefStepAmp[2], proc = tracesAnalyzer#setting3_TA_MT	
			else
				SetVariable testSettingAmpCoef1 disable = 1, value = _NUM:TAPrefs.coefStepAmp[1], proc = tracesAnalyzer#setting3_TA_MT
				SetVariable testSettingAmpCoef2 disable = 1, value = _NUM:TAPrefs.coefStepAmp[2], proc = tracesAnalyzer#setting3_TA_MT		
			endif
			//
			break
		case "testSetting4":	// excluding MM trajectories
			TAPrefs.levelsSM[ 0 ] = CB_Struct.checked
			//
			if( TAPrefs.levelsSM[ 0 ] == 1 )
				// MM level in trajectories
				setvariable testSetting16a disable = 0, fsize=12, value = _NUM:TAPrefs.levelsSM[ 1 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			else
				// MM level in trajectories
				setvariable testSetting16a disable = 1, fsize=12, value = _NUM:TAPrefs.levelsSM[ 1 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA			
			endif
			// # of pnts above thresholds of MM and empty traj.
			if( TAPrefs.levelsSM[ 0 ] == 1 || TAPrefs.neverBleach[ 0 ] == 1 )
				setvariable testSetting16c disable = 0, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			else
				setvariable testSetting16c disable = 1, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			endif
			//
			break
		case "checkBox_empty":	// excluding empty trajectories
			TAPrefs.neverBleach[ 0 ] = CB_Struct.checked
			//
			if( TAPrefs.neverBleach[ 0 ] == 1 )
				// SD for empty traj exclusion
				setvariable setVarCtrl_neverBleach disable = 0, fsize=12, value = _NUM:TAPrefs.neverBleach[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA		
			else
				// SD for empty traj exclusion
				setvariable setVarCtrl_neverBleach disable = 1, fsize=12, value = _NUM:TAPrefs.neverBleach[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "# SD", win=controlPanel2_TA
			endif
			// # of pnts above thresholds of MM and empty traj.
			if( TAPrefs.levelsSM[ 0 ] == 1 || TAPrefs.neverBleach[ 0 ] == 1 )
				setvariable testSetting16c disable = 0, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			else
				setvariable testSetting16c disable = 1, value = _NUM:TAPrefs.levelsSM[ 3 ],  proc = tracesAnalyzer#setting3_TA_MT, win=controlPanel2_TA
			endif
			//
			break
		case "clusterICPDet_ckeckBox":	// cluster states in ICP detection
			TAPrefs.clusterStates = CB_Struct.checked
			//
			break
			//
		case "remBleachIdeal_ckeckBox":
			//
			TAPrefs.removeBleach = CB_Struct.checked
			//
			break
			//
		case "expandTrICPdet_checkBox":	// toggle for trace expansion
			TAPrefs.expandTrace[0] = CB_Struct.checked
			//
			if( TAPrefs.expandTrace[0] == 1 )
				setvariable expandTrICPdet_setValue disable = 0, value = _NUM:TAPrefs.expandTrace[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "exp. factor", win=controlPanel2_TA
			else
				setvariable expandTrICPdet_setValue disable = 1, value = _NUM:TAPrefs.expandTrace[1],  proc = tracesAnalyzer#setting3_TA_MT , title= "exp. factor", win=controlPanel2_TA
			endif
			//
			break
			//	
		case "silentICP_ckeckBox":	// show/ do not show results of ICP detection
			TAPrefs.silentICPDetection = CB_Struct.checked
			//
			break
			//	
		case "testSetting5":	// removing bckg from 1st channel images 
			TAPrefs.bckgSubtrVariables[ 0 ] = CB_Struct.checked
			//
			if( TAPrefs.bckgSubtrVariables[ 0 ] == 1 )
				setVariable testSetting19 disable = 0, fsize=12, value = _NUM:TAPrefs.bckgSubtrVariables[ 2 ] // ball radius  1st channel
			else
				setVariable testSetting19 disable = 1, fsize=12, value = _NUM:TAPrefs.bckgSubtrVariables[ 2 ] // ball radius  1st channel
			endif
			//
			break
		case "testSetting6":	// removing bckg from 2nd channel images
			TAPrefs.bckgSubtrVariables[ 1 ] = CB_Struct.checked
			//
			if( TAPrefs.bckgSubtrVariables[ 1 ] == 1 )
				setVariable testSetting20 disable = 0, fsize=12, value = _NUM:TAPrefs.bckgSubtrVariables[ 3 ] // ball radius  2nd channel
			else
				setVariable testSetting20 disable = 1, fsize=12, value = _NUM:TAPrefs.bckgSubtrVariables[ 3 ] // ball radius  2nd channel
			endif
			//
			break
		case "testSetting7":	// filtering 1st channel images by Gaussian
			TAPrefs.imageFiltering[ 0 ] = CB_Struct.checked
			//
			if( TAPrefs.imageFiltering[ 0 ] == 1 )
				setVariable testSetting25 disable = 0, fsize=12, value = _NUM:TAPrefs.imageFiltering[ 4 ] // gaussian kernel size 1st channel 	
			else
				setVariable testSetting25 disable = 1, fsize=12, value = _NUM:TAPrefs.imageFiltering[ 4 ]  // gaussian kernel size 1st channel 	
			endif	
			//	
			break
		case "testSetting8":	// filtering second channel images by gaussian
			TAPrefs.imageFiltering[ 1 ] = CB_Struct.checked
			//
			if( TAPrefs.imageFiltering[ 1 ] == 1 )
				setVariable testSetting26 disable = 0, fsize=12, value = _NUM:TAPrefs.imageFiltering[ 5 ]  // gaussian kernel size 2nd channel 	
			else
				setVariable testSetting26 disable = 1, fsize=12, value = _NUM:TAPrefs.imageFiltering[ 5 ]  // gaussian kernel size 2nd channel 	
			endif	
			//
			break
		case "testSetting9":	// filtering 1st channel images by low-pas filters
			TAPrefs.imageFiltering[ 2 ] = CB_Struct.checked
			//
			if( TAPrefs.imageFiltering[ 2 ] == 1 )
				setVariable testSetting27 disable = 0, value = _NUM:TAPrefs.imageFiltering[ 6 ] // cut-off frequency of low -pass filter for 1st channel
			else
				setVariable testSetting27 disable = 1, value = _NUM:TAPrefs.imageFiltering[ 6 ] // cut-off frequency of low -pass filter for 1st channel
			endif
			//
			break
		case "testSetting10":	// filtering 2nd channel images by low-pas filters
			TAPrefs.imageFiltering[ 3 ] = CB_Struct.checked
			if( TAPrefs.imageFiltering[ 3 ] == 1 )
				setVariable testSetting28 disable = 0, value = _NUM:TAPrefs.imageFiltering[ 7 ] // cut-off frequency of low -pass filter for 1st channel
			else
				setVariable testSetting28 disable = 1, value = _NUM:TAPrefs.imageFiltering[ 7 ] // cut-off frequency of low -pass filter for 1st channel
			endif
			break
		case "testSetting11":	// fit particles from the 1st channel to 2D Gauss
			TAPrefs.particleFitting[ 0 ] = CB_Struct.checked
			break
		case "testSetting12":	// fit particles from 2nd channel to 2D Gauss
			TAPrefs.particleFitting[ 1 ] = CB_Struct.checked
			break
		case "partsAnalSet1":	// particle detection and co-localization
			TAPrefs.partsAnalysis[ 0 ] = CB_Struct.checked
			break
		case "partsAnalSet2":	// trajectory extraction
			TAPrefs.partsAnalysis[ 1 ] = CB_Struct.checked
			break
		case "partsAnalSet3":	// trajectory filtering
			TAPrefs.partsAnalysis[ 2 ] = CB_Struct.checked
			break
		case "partsAnalSet4":	// ICP detection
			TAPrefs.partsAnalysis[ 3 ] = CB_Struct.checked
			break
		case "partsAnalSet5":	// characterize detected states
			TAPrefs.partsAnalysis[ 4 ] = CB_Struct.checked
			break
			case "partsAnalSet6":	// auto select traces
			TAPrefs.partsAnalysis[ 5 ] = CB_Struct.checked
			break
		endswitch
		//
	endif
	//
	getCoords_TA_MT( TAPrefs )
	save_preferences_TA_MT( TAPrefs )
	//
End
// 
static function setting3_TA_MT(SV_Struct) : SetVariableControl
	STRUCT WMSetVariableAction &SV_Struct
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//
	if( SV_Struct.eventCode == 1 || SV_Struct.eventCode == 2 )			// act only on Enter key accepting edit, or on mouse up in the arrow buttons
		// checking which of the setVariable control was executed
		strswitch( SV_Struct.ctrlName )						// string switch
		case "testSetting16a":	// deviation of tajectories from equilibrium
			TAPrefs.levelsSM[ 1 ] = SV_Struct.dval
			break
		case "testSetting16b":	// max intensity of ch1
			TAPrefs.levelsSM[ 2 ] = SV_Struct.dval
			break
		case "testSetting16c":	// max intensity of ch1
			TAPrefs.levelsSM[ 3 ] = SV_Struct.dval
			break
		case "testSettingNSDBleach":	// # of sdev for bleaching state detection.
			TAPrefs.nSdevBleach = SV_Struct.dval
			break
		case "setVarCtrl_neverBleach":	// # of sdev for empty traj.
			TAPrefs.neverBleach[1] = SV_Struct.dval
			break
		case "expandTrICPdet_setValue":	// factor of trace expansion
			TAPrefs.expandTrace[1] = SV_Struct.dval
			break
		case "testSetting16d":	// minimal step amplitude
			TAPrefs.minAmp = SV_Struct.dval
			break
		case "testSetting16e":	// minimal step duration
			TAPrefs.minDur = SV_Struct.dval
			break
		case "testSettingAmpCoef1":	// amplitude ch1.
			TAPrefs.coefStepAmp[1]  = SV_Struct.dval
			break
		case "testSettingAmpCoef2":	// amplitude ch2.
			TAPrefs.coefStepAmp[2]  = SV_Struct.dval
			break
		case "testSetting19":	// ball radius ch1
			TAPrefs.bckgSubtrVariables[ 2 ] = SV_Struct.dval
			break
		case "testSetting20":	//  ball radius ch2
			TAPrefs.bckgSubtrVariables[ 3 ]  = SV_Struct.dval
			break
		case "testSetting23":	// x0
			TAPrefs.sizeImage[ 2 ] = SV_Struct.dval
			break
		case "testSetting24":	// x1
			TAPrefs.sizeImage[ 3 ] = SV_Struct.dval
			break
		case "testSetting24a":	// y0
			TAPrefs.sizeImage[ 4 ] = SV_Struct.dval
			break
		case "testSetting24b":	// y1
			TAPrefs.sizeImage[ 5 ] = SV_Struct.dval
			break		
		case "testSetting25":	// gauss size ch1
			TAPrefs.imageFiltering[ 4 ] = SV_Struct.dval
			break
		case "testSetting26":	// gauss size ch2
			TAPrefs.imageFiltering[ 5 ] = SV_Struct.dval
			break
		case "testSetting27":	// cut-off frequency ch1
			TAPrefs.imageFiltering[ 6 ]  = SV_Struct.dval
			break
		case "testSetting28":	// cut-off frequnecy ch2
			TAPrefs.imageFiltering[ 7 ] = SV_Struct.dval
			break
		case "testSetting30":	// number of images to average before bckg removing in 1st ch 
			TAPrefs.imageFiltering[ 8 ]  = SV_Struct.dval
			break
		case "testSetting31":	// number of images to average before bckg removing in 2nd ch 
			TAPrefs.imageFiltering[ 9 ]  = SV_Struct.dval
			break
		case "numImagesSetting":	// number of images for signal extraction
			TAPrefs.numImagesTA  = SV_Struct.dval
			break	
		case "imRegSet1":	// dx
			TAPrefs.regParams[1]   = SV_Struct.dval
			break
		case "imRegSet2":	// dy
			TAPrefs.regParams[2]  = SV_Struct.dval
			break
		case "imRegSet3":	// a11
			TAPrefs.regParams[3]  = SV_Struct.dval
			break
		case "imRegSet4":	// a12
			TAPrefs.regParams[4]  = SV_Struct.dval
			break
		case "imRegSet5":	// a21
			TAPrefs.regParams[5]  = SV_Struct.dval
			break
		case "imRegSet6":	// a22
			TAPrefs.regParams[6]  = SV_Struct.dval
			break
		case "imRegSet7":	// a33
			TAPrefs.regParams[7]  = SV_Struct.dval
			break
		case "imRegSet8":	// originX
			TAPrefs.regParams[8]  = SV_Struct.dval
			break
		case "imRegSet9":	// originY
			TAPrefs.regParams[9]  = SV_Struct.dval
			break
		endswitch
		//
	endif
	//
	getCoords_TA_MT( TAPrefs )
	save_preferences_TA_MT( TAPrefs )
	//
end
//
static function setting01_TA_MT(SV_Struct) : SetVariableControl
	STRUCT WMSetVariableAction &SV_Struct
	//
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	//
	if( SV_Struct.eventCode == 1 || SV_Struct.eventCode == 2 )			// act only on Enter key accepting edit, or on mouse up in the arrow buttons
		// checking which of the setVariable control was executed
		strswitch( SV_Struct.ctrlName )						// string switch
		case "testSetting001":	// minimal are of particle for bckg image
			TAPrefs.minArea[ 0 ] = SV_Struct.dval
			break
		case "testSetting002":	// threshold of bckg image
			TAPrefs.minArea[ 1 ] = SV_Struct.dval
			break
		case "testSetting003a":	// maximal errror of gaussian fit ch1
			TAPrefs.maxDeviation[0] = SV_Struct.dval
			break
		case "testSetting003b":	// maximal errror of gaussian fit ch2
			TAPrefs.maxDeviation[1] = SV_Struct.dval
			break
		case "testSetting004":	// co-localization distance
			TAPrefs.lenghtLinkParticles = SV_Struct.dval
			break
		case "testSetting006":	// threshold ch 2
			TAPrefs.threshold[ 1 ]  = SV_Struct.dval
			break
		case "testSetting007":	// threshold ch1
			TAPrefs.threshold[ 0 ] = SV_Struct.dval
			break
		case "testSetting006b":	// threshold ch 2
			TAPrefs.threshold[ 3 ]  = SV_Struct.dval
			break
		case "testSetting007b":	// threshold ch1
			TAPrefs.threshold[ 2 ] = SV_Struct.dval
			break
		case "testSetting18":	// crop size for 2D Gauss fitting
			TAPrefs.radiusVariables  = SV_Struct.dval
			break
		case "testSetting022":	// ICP detection parameter
			TAPrefs.icpDetection[1]  = SV_Struct.dval
			break
		case "testSetting29":	// trace filtering parameter
			TAPrefs.tracesFilterVariables[ 1 ] = SV_Struct.dval
			break
		endswitch
		//
	endif
	//
	getCoords_TA_MT( TAPrefs )
	save_preferences_TA_MT( TAPrefs )
	//
end
//**************     describes state of program in the control panel   ******************
function State_GUI_TA_MT( inputString )
	string inputString
	setDrawLayer/K/w=controlPanel_TA userBack 
	SetDrawLayer/W=controlPanel_TA /K  progFront
	SetDrawEnv/W=controlPanel_TA xcoord=abs, ycoord=abs, fillbgc=(65000,0,0), fillfgc=(65000,0,0), linebgc=(65000,0,0), linefgc=(65000,0,0), textrgb=(0,0,0), fillpat=1, linethick=2, fsize=14
	DrawText/W=controlPanel_TA 30, 430, inputString
	doUpdate
end
//******************* draws circles around a particles  ********************************
Function DC_TA_MT( xCoordWave, yCoordWave, rVal, gVal, bVal, particleNumber , nameofWindow ,  heightOfImage , widthOfImage , layerDrawing, offset , radW )
	wave xCoordWave, yCoordWave, radW
	variable  rVal, gVal, bVal, particleNumber , heightOfImage , widthOfImage, offset
	string nameofWindow, layerDrawing
	// defining local varaibles
	variable leftCircle, topCircle, rightCircle, bottomCircle  // corners coords of the circle
	variable tu										// counter
	// defining layer for drawing
	SetDrawLayer/W=$nameofWindow/K $layerDrawing
	// drawing circles around particles
	for( tu = 0 ; tu < particleNumber ; tu += 1 )
		// corner coords of the circle around particle tu
		leftCircle =( xCoordWave[ tu ] - radW[ tu ] - offset )/( widthOfImage )
		topCircle =( yCoordWave[ tu ] - radW[ tu ] - offset )/( heightOfImage )
		rightCircle =( xCoordWave[ tu ] + radW[ tu ] + offset )/( widthOfImage )
		bottomCircle =( yCoordWave[ tu ] + radW[ tu ] + offset )/( heightOfImage )
		// drawing circle around a particle tu
		SetDrawEnv/W=$nameofWindow linefgc=(rVal, gVal, bVal), linethick=2, fillpat=0, xcoord=rel, ycoord=rel
		DrawOval/W=$nameofWindow leftCircle, topCircle, rightCircle, bottomCircle
	endfor
	// writing number of particles on a window 
	TextBox/W=$nameofWindow/K/N=text0
	TextBox/W=$nameofWindow/C/N=text0 "\\Z12\\f01Particle Nr:   "+num2str(particleNumber)+"\r\\K(40000,0,0) Gauss fit succ.\r\\K(0,40000,0) Gauss fit failed."
	// releasing the memory occupyed by variables
	killVariables/z leftCircle, topCircle, rightCircle, bottomCircle , tu
end  // end of circles drawing function
//****************       draws single circle around a particle   ***********************
Function DSC_TA_MT(xCoordWave, yCoordWave, rVal, gVal, bVal , nameofWindow, Offset , heightOfImage , widthOfImage , circleLabelToggle , circleLabel , radiusLocal )
	variable xCoordWave, yCoordWave
	variable  rVal, gVal, bVal, Offset
	variable heightOfImage , widthOfImage , circleLabelToggle, radiusLocal
	string nameofWindow , circleLabel
	// defining variables
	Variable xCenterOfCircle, yCenterOfCircle		// center coords of a particle
	variable leftCircle, topCircle, rightCircle, bottomCircle		// corner coords of a circle
	// definig drwaing layer
	SetDrawLayer/W=$nameofWindow userFront
	// calculating the corner coordinates of a circle
	leftCircle =(xCoordWave - radiusLocal - Offset)/(widthOfImage)
	topCircle =(yCoordWave - radiusLocal - Offset )/(heightOfImage)
	rightCircle =(xCoordWave + radiusLocal + Offset)/(widthOfImage)
	bottomCircle =(yCoordWave + radiusLocal + Offset)/(heightOfImage)
	// drawig the circle
	SetDrawEnv/W=$nameofWindow linefgc=(rVal, gVal, bVal), linethick=2, fillpat=0, xcoord=rel, ycoord=rel
	DrawOval/W=$nameofWindow leftCircle, topCircle, rightCircle, bottomCircle
	if( circleLabelToggle == 0 )
		drawText/w = $nameofWindow rightCircle + 1 , topCircle + 1, circleLabel
	endif
	// releasing memory occupied by variables and strings
	killVariables/z xCenterOfCircle, yCenterOfCircle,  leftCircle, topCircle, rightCircle, bottomCircle
end  // end of circle drawing procedure

// exporting ibw to text files.
function exportTXT_TA_MT( ctrlName ) : buttonControl
	string ctrlName
	//
	variable fret, alex, aa, bb, accRejTags, coordsToggle, numFolders
	string type, fileName, folderNames, currentFolder
	//
	prompt fret, "Is it FRET type signals?", popup, "yes;no;"
	prompt accRejTags, "Save acc/rej tags wave?", popup, "yes;no;"
	prompt coordsToggle, "Save coords wave?", popup, "yes;no;"
	doprompt "Select", fret, accRejTags, coordsToggle
	if( V_flag != 0 )
		Abort
	else
		if( fret == 2 )
			//
			prompt type, "Uniqe fraction of table name (like 030_0_): "
			doprompt "Enter", type
			if( V_flag != 0 )
				Abort
			endif
			//
		else
			//
			prompt alex, "Is it alex type signals?", popup, "yes;no;"
			doprompt "Enter", alex
			if( V_flag != 0 )
				Abort
			endif
			//
		endif
	endif
	//
	newpath/o /m= "navigate to the results folder with ibw files" pathMain
	if( V_flag != 0 )
		Abort
	endif
	//
	folderNames = indexedDir(pathMain, -1, 1 )
	//
	bb = 0
	do
		if( StringMatch( stringFromList( bb, folderNames, ";" ),  "*concatenatedTables*" ) == 1 )
			//print stringFromList( loopCounter1, listOfFolders, ";" ), ": this folder was removed from conatenated folder list."
			folderNames = RemoveListItem( bb , folderNames, ";" )
		else
			bb += 1
		endif
		//
		if( bb >= itemsinlist(folderNames, ";" ) )
			break
		endif
		//
	while( 1 )
	//
	numFolders = itemsinlist(folderNames,";"); print numFolders, "# of folders."
	//
	for( bb = 0 ; bb < numFolders; bb += 1 )
		//
		currentFolder = stringFromList( bb, folderNames ); print currentFolder, ": name of the current folder."
		NewPath/o/Q/Z path1 , currentFolder
		NewPath/o/Q/Z path2 , currentFolder
		//pathinfo path1;	newpath/c/o path2 s_path+"txtFiles"
		// acc/rej tags
		if( accRejTags == 1 )
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "051_*" , ";" ), ";" ); //print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), w1
			Save/J/M="\r\n"/O/p=path2 w1 as "tags_051.txt"
		endif
		// coordinates
		if( coordsToggle == 1 )
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "040_*" , ";" ), ";" );// print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), coordsTable
			make/o/n=(dimsize(coordsTable,0),2) coordsTableCh1
			coordsTableCh1[][0] = coordsTable[p][%xc1]
			coordsTableCh1[][1] = coordsTable[p][%yc1]
			Save/J/M="\r\n"/O/p=path2 coordsTableCh1 as "coords_040.txt"
		endif
		//
		if( fret == 1 )
			// traces
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*030_0_"+"*" , ";" ), ";" ); //print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave0
			wave0[][] = numtype(wave0[p][q]) == 2 ? 0 : wave0[p][q]		// remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave0 as "eFRET_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave0,0),0) wave0_acc
//			for( aa = 0 ; aa < dimsize(wave0,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave0_acc,1),1, wave0_acc
//					wave0_acc[][dimsize(wave0_acc,1)-1] = wave0[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave0_acc
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*030_1_"+"*" , ";" ), ";" );// print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave1
			wave1[][] = numtype(wave1[p][q]) == 2 ? 0 : wave1[p][q]		// remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave1 as "cy3_532_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave1,0),0) wave1_acc
//			for( aa = 0 ; aa < dimsize(wave1,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave1_acc,1),1, wave1_acc
//					wave1_acc[][dimsize(wave1_acc,1)-1] = wave1[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave1_acc
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*030_2_"+"*" , ";" ), ";" ); //print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave2
			wave2[][] = numtype(wave2[p][q]) == 2 ? 0 : wave2[p][q]		// remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave2 as "cy5_532_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave2,0),0) wave2_acc
//			for( aa = 0 ; aa < dimsize(wave2,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave2_acc,1),1, wave2_acc
//					wave2_acc[][dimsize(wave2_acc,1)-1] = wave2[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave2_acc
			//
		else		//  traces
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*"+type+"*" , ";" ), ";" ); //print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			//duplicate/o/r=[*,*][*,*][0,0] waveX, wave0
			make/o/n=(dimSize(waveX,0),dimSize(waveX,1)) wave0 = waveX[p][q][0]
			wave0[][] = numtype(wave0[p][q]) == 2 ? 0 : wave0[p][q]		// remove nans before saving
			//
			Save/J/M="\r\n"/O/p=path2 wave0 as fileName+".txt"	
			//		
		endif
		//
		if( alex == 1 )
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*"+type+"6_"+"*" , ";" ), ";" );// print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave6
			wave6[][] = numtype(wave6[p][q]) == 2 ? 0 : wave6[p][q]		// remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave6 as "cy3_635_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave6,0),0) wave6_acc
//			for( aa = 0 ; aa < dimsize(wave6,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave6_acc,1),1, wave6_acc
//					wave6_acc[][dimsize(wave6_acc,1)-1] = wave6[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave6_acc
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*"+type+"7_"+"*" , ";" ), ";" );// print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave7
			wave7[][] = numtype(wave7[p][q]) == 2 ? 0 : wave7[p][q]   // remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave7 as "cy5_635_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave7,0),0) wave7_acc
//			for( aa = 0 ; aa < dimsize(wave7,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave7_acc,1),1, wave7_acc
//					wave7_acc[][dimsize(wave7_acc,1)-1] = wave7[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave7_acc
			//
			fileName = stringfromlist( 0, ListMatch( indexedFile( path1, -1, ".ibw" ) , "*"+type+"10_"+"*" , ";" ), ";" ); //print fileName
			LoadWave/Q/H/O/p=path1 fileName
			duplicate/o $stringfromlist(0, S_waveNames, ";"), waveX
			duplicate/o/r=[*,*][*,*][0,0] waveX, wave10
			wave10[][] = numtype(wave10[p][q]) == 2 ? 0 : wave10[p][q]	// remove nans before saving
			Save/J/M="\r\n"/O/p=path2 wave10 as "stoch_"+fileName+".txt"
			//
//			make/o/n=(dimSize(wave10,0),0) wave10_acc
//			for( aa = 0 ; aa < dimsize(wave10,1) ; aa += 1 )
//				if( accRejTable1[aa] == 1 )
//					insertpoints/m=1 dimsize(wave10_acc,1),1, wave10_acc
//					wave10_acc[][dimsize(wave10_acc,1)-1] = wave10[p][aa]
//				endif
//			endFor
//			DeletePoints/M=1 0,1, wave10_acc
			//
		endif
		//
	endFor
	//
end