#pragma rtGlobals=3		// Use modern global access method and strict wave access.

function HMM_TA_MT( nStatesW, inWOrig, silentICP, numCh, minAmp, minDur )
	wave nStatesW
	wave inWOrig
	variable silentICP
	variable numCh
	variable minAmp, minDur
	// normalise signal
	duplicate/o inWOrig, inW, indexW
	wavestats/q /r = [ 0 , 10 ] inW; inW /= V_avg
	//
	variable kk, pp = 0
	variable/g nStatesVar = dimSize( nStatesW, 0 )
	variable/g lastFitVar = 0
	// generate initial gueses and limits waves
	make/o /n = ( nStatesVar+1+abs(nStatesVar^2) ) xWave  			// starting gueses.
	make/o /n = ( nStatesVar+1+abs(nStatesVar^2), 2 ) XLimitWave  	// max & min value limits of gueses
	make/o /n = ( nStatesVar+1+abs(nStatesVar^2), 3 ) stepWave		// max & min step value limits of gueses
	// fill the waves
	for( kk = 0 ; kk < dimSIze( xWave, 0 ); kk += 1 ) 
		//
		if( kk == 0 )
			//
			xWave[kk] = 0.2				// sigma
			//
			XLimitWave[kk][0] = 0.05 		// min sigma
			XLimitWave[kk][1] = 0.4   		// max sigma
			//
			stepWave[kk][0] = 0.1
			stepWave[kk][1] = 0.05
			stepWave[kk][2] = 0.1
			//
		elseif( kk > 0 && kk < nStatesVar + 1 )
			//
			xWave[kk] =  nStatesW[ pp ][0] + abs( abs( nStatesW[ pp ][1]-nStatesW[ pp ][0] ) / 2 )
			//
			XLimitWave[kk][0] = nStatesW[ pp ][ 0 ]			// min state int.
			XLimitWave[kk][1] = nStatesW[ pp ][ 1 ]		       // max state int.			
			//
			stepWave[kk][0] = abs( nStatesW[ pp ][1]-nStatesW[ pp ][0] ) / 3
			stepWave[kk][1] = abs( nStatesW[ pp ][1]-nStatesW[ pp ][0] ) / 10
			stepWave[kk][2] = abs( nStatesW[ pp ][1]-nStatesW[ pp ][0] ) / 3
			//
			pp += 1
			//
		else
			//
			xWave[kk] = 0.1
			//
			XLimitWave[kk][0] = 0.01	// min trans prob.
			XLimitWave[kk][1] = 1		// max trans prob.
			//
			stepWave[kk][0] = 1
			stepWave[kk][1] = 0.05
			stepWave[kk][2] = 1
			//
		endif
	endFor
	// optimize (find maximum of trace prob) for best values of emission probability, transition probability and sigma.
	Optimize/I = (250) /A /X = xWave /XSA = XLimitWave /SSA = stepWave /M = { 3, 0 } /TSA = {0, 0.1 } /Q viterbi_HMM_TA_MT, inW
	//  use optimised parameters to build ideal trace.
	lastFitVar = viterbi_HMM_TA_MT( inW, xWave ); wave indexW
	// make ideal trace using avg intensities of identified ICPs.
	idealTrace_HMM( indexW, inW, minDur, minAmp, inWOrig ); wave idealTraceOutput
	// show result of ICP detection
	if( silentICP == 1 )
		print lastFitVar, ": total probability."
		print xWave
		doWindow/k graphTemp; 	display /n = graphTemp inW, idealTraceOutput
		ModifyGraph /w = graphTemp mode(idealTraceOutput)=6,rgb(idealTraceOutput)=(0,0,0), lsize(idealTraceOutput)=1.5
		execute " TileWindows/G=5/A=(1,1)/W=(42,18,786,468) graphTemp"; 		doUpdate
		kk = 2
		prompt kk, "Stop: ", popUp, "yes;no"
		doprompt "Choose", kk
		if( kk == 1 )
			abort
		endif
		doWindow/k graphTemp
	endif
	//
end
//
Function viterbi_HMM_TA_MT( xW, parW )
	wave xW		// signal
	wave parW	// parameter wave.
	//
	// parW[0] - sigma
	// parW[1 till 1 + nStates] - meanInt
	// parW[1 + nStates till 1 + nStates + nStates^2 ] - transition prob.
	//
	wave indexW
	NVAR nStatesVar, lastFitVar
	//
	variable probTotal = 0.01, valMax, v_prob, maxarg
	variable aa, bb, cc
	variable count, intDiff 
	// calculate probability with given parameters for each point of the input trace and then return integral of probability/ num of points in trace.
	for( aa = 0 ; aa < dimSize( xW, 0 ); aa +=1 )
		// reset the current probability, max probability value and counter to zero.
		valMax = 0;	count = 0; maxarg = 0
		//
		for( bb = 0 ; bb < nStatesVar; bb += 1 )  // current state
			//
			for( cc = 0 ; cc < nStatesVar; cc += 1 ) // following state
				// calculate emission probability
				intDiff = xW[ aa ] - parW[ 1+ bb ]
				intDiff /= parW[ 0 ]
				intDiff = intDiff ^ 2
				intDiff *= -2
				v_prob = abs( 1/ parW[ 0 ] ) * exp( intDiff )
				// multiply emission probability by the transition probability, to get total probability
				v_prob *= parW[ nStatesVar + count + 1 ]
				// check if probability is higher than the max value, if so record probaiblity value and the current state index - cc.
				if( v_prob > valMax )
					valMax = v_prob
					maxarg = bb
				endif
				// update the counter
				count += 1
				//
			endFor
			//
		endFor
		// update product of probability.
		probTotal += valMax
		// record the maximum probabilty value
		indexW[ aa ] = maxarg
		//
	endFor
	//
	return probTotal
	//
end
// make a ICP table and the idealised trace.
function idealTrace_HMM( indexW, inW, minDur, minAmp, inWOrig )
	wave indexW, inW, inWOrig
	variable minDur, minAmp
	// make icp list.
	make/o /n = ( 0, 2 ) icpList
	variable kk = 0, hh = 0, yy, ampCurr
	for( yy = 0 ; yy < dimSize( indexW, 0 ) - 1; yy += 1 )
		if( indexW[yy] != indexW[yy+1] && yy - hh > minDur )
			insertPoints/m=0 kk, 1 , icpList
			icpList[kk][0] = hh;	icpList[kk][1] = yy
			kk += 1; 		hh = yy + 1
		endif
	endFor
	//
	doupdate
	// fill ICP location for the last state.
	insertPoints/m=0 dimsize(icpList,0), 1 , icpList;
	if( dimsize(icpList,0) == 1 )
		icpList[dimsize(icpList,0)-1][0] = 0; 	icpList[dimsize(icpList,0)-1][1] = dimSize( indexW, 0 ) - 1
	else
		icpList[dimsize(icpList,0)-1][0] = icpList[dimsize(icpList,0)-2][1]+1; 	icpList[dimsize(icpList,0)-1][1] = dimSize( indexW, 0 ) - 1
	endif
	//
	if( dimsize(icpList,0) > 1 )
		yy = 0
		do
			ampCurr = abs( mean( inW, icpList[ yy+1 ][0], icpList[ yy+1 ][1] ) - mean( inW, icpList[ yy ][0], icpList[ yy ][1] ) )
			if( ampCurr < minAmp )
				icplist[yy+1][0] = icplist[yy][0]
				deletepoints/m=0 yy, 1, icplist
			else
				yy += 1
			endif
			//
			if( yy + 1 >= dimsize( icplist, 0 ) )
				break
			endif
			//
		while(1)
		//
	endif
	// make ideal trace
	duplicate/o indexW, idealTraceOutput; idealTraceOutput = nan
	for( yy = 0 ; yy < dimSize( icpList, 0 ) ; yy += 1 )
		for( kk = icpList[yy][0] ; kk <= icpList[yy][1] ; kk += 1 )
			idealTraceOutput[ kk ] = mean( inWOrig, icpList[yy][0], icpList[yy][1])
		endFor
	endFor
	//
end


				// check that trnsition probaiblity sum from currnet state to all other would be less than 1.
//				if( cc < nStatesVar - 1 )// not the last state
//					//
//					if( sumP - parW[ nStatesVar + count + 1 ] < 0 )
//						parW[ nStatesVar + count + 1 ] = sumP
//						sumP = 0
//					else
//						sumP -= parW[ nStatesVar + count + 1 ]
//					endif
//					//	 
//				else // last state
//					if( sumP - parW[nStatesVar+count+1] < 0 )
//						parW[ nStatesVar + count + 1 ] = sumP
//					else
//						parW[ nStatesVar + count + 1 ] = sumP
//					endif				
//				endif