#pragma rtGlobals=1		// Use modern global access method.
#pragma ModuleName = tracesAnalyzer4

//***************   	Intensity change point analysis			****************
Function ICPdet_TA_MT(ctrlName):buttonControl
	string ctrlName
	//
	killVariables/z/a; killWaves/z/a; killStrings/a/z
	// defining global variables
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	// defining local variables from structure 
	variable numCh = TAPrefs.noChToggle											// FRET or single channel.
	variable icpDetectionType = TAPrefs.icpDetection[0]						// 1 - Amp&Dur method, 2 - Hidden Markov Model.
	variable indexIdTr = TAPrefs.IdTrName										// index to name of table to idealise.
	variable minAmp = TAPrefs.minAmp												// minimal aplitude of ICP.
	variable minDur = TAPrefs.minDur												// minimal state duration.
	variable normToggle = TAPrefs.normaliseToggle								// 1- normalisation on, 2 - off.
	variable groupStatesToggle = TAPrefs.clusterStates						// 1 - ebnable clustering of neighbouring states in amp & dur ICP detection method.
	variable removeBleachedToggle = TAPrefs.removeBleach					// 1 - remove the bleached fraction of FRET trace before ICP detection
	variable anslyseSelAllTraces = TAPrefs.IdSelAllTrName					// toggle between analyse selected or all traces.
	variable silentICP = TAPrefs.silentICPDetection							// if = 1: window with results of all ICPs detected will appear, else - does not appear.
	Variable methodFilter = TAPrefs.tracesFilterVariables[ 0 ]			// filtering methods
	variable filterParameter = TAPrefs.tracesFilterVariables[ 1 ]		// cut - off frequency of the low pass filters or number of points for box - car smoothing 
	variable testAntiCorr = TAPrefs.antiCorToggleMain						// toggle for anti-correlation in ch1 and ch2 signals testing.
	variable ampCh1AntiCorr = TAPrefs.coefStepAmp[1]							// amplitude for anti-corr testing ch1
	variable ampCh2AntiCorr = TAPrefs.coefStepAmp[2]							// amplitude for anti-corr testing ch2
	variable minAmpSDtoggle = TAPrefs.minAmpTypeToggle						// amplitude criteria for AmpDur ICP detection: 1 - dependent of SD of signal, 2 - predefined.
	variable expandToggle = TAPrefs.expandTrace[0]	 						// toggle for trace expansion
	variable expandFactor = TAPrefs.expandTrace[1]	 						// factor for trace expansion
	// possibly future global variables
	variable portionToNorm = 0.1
	variable minIntNormThresh = 20 
	// local variable						
	variable stopvVar1 = 0
	variable rejectVar = 0
	variable temp, aa, ii, jj
	variable normValue
	string namesIdTrTable1 = "030_0_;030_1_;030_2_;030_6_;030_7_;"
	string namesIdTrTableSingle = stringFromList(indexIdTr-1, namesIdTrTable1, ";")
	//
	dowindow/k graphTemp
	//	Print initialization message
	print "*******************************************************************************************************"
	//
	if( icpDetectionType == 1 )
		print "Detecting ICPs by amplitude and duration algorithm. Minimal amplitude: "+num2str(minAmp)+" and duration: "+num2str(minDur)
		//
		if( groupStatesToggle == 1 )
			print "State clustering enabled"
		else
			print "State clustering disabled"
		endif
		//
		if( minAmpSDtoggle == 1 )
			print "Amplitude type: dependent of SD."
		else
			print "Amplitude type: constant."
		endif
		//
	elseif( icpDetectionType == 2 )
		print "Detecting ICPs by Hidden Markov model"
	endif
	//
	if( methodFilter == 2 )
		print "Signal traces will be filtered by box-car smoothing method, size of smoothing box:  "+num2str( filterParameter )
	elseif( methodFilter == 3 )
		print "Signal traces will be filtered by DWT filtering method, cut-off freq.:  "+num2str( filterParameter )
	else
		print "Signal traces will not be filtered."
	endif
	//
	if( normToggle == 1 )
		print "Traces will be normalised using excitation image."	
	elseif( normToggle == 2 )
		print "Traces will be normalised to begining."
	else
		print "Traces will not be normalised."	
	endif
	//
	if( anslyseSelAllTraces == 1 )
		print "Detect ICPs in selected traces."	
	else
		print "Detect ICPs in all traces."
	endif
	//
	if( removeBleachedToggle == 1 )
		print "Remove bleached fraction of FRET traces."	
	else
		print "Do not remove bleached fraction of FRET traces."
	endif
	//
	if( silentICP == 1 )
		print "Results of ICP detection will be shown."
	else
		print "Results of ICP detection will not be shown."
	endif
	//
	if( testAntiCorr == 1 )
		print "Anti-correlation in ch1 and ch2 test enabled. Min. amplitudes ch1: "+num2str(ampCh1AntiCorr)+", ch2: "+num2str(ampCh1AntiCorr)
	else
		print "Anti-correlation in ch1 and ch2 test disabled."
	endif
	//
	if( expandToggle == 1 )
		print "Expanding of trace enabled. Factor for expansion: "+num2str(expandFactor)
	else
		print "Expanding of trace disabled."
	endif
	//
	print namesIdTrTableSingle, ": unique fraction of table name for traces to idealise."
	// check if path4 exsists
	pathInfo path4
	if( V_flag == 0 )
		abort "Path to data does not exsist"
	endif
	// load required waves from the path4 into the current data folder
	loadWMain_TA_MT( numCh, icpDetectionType, namesIdTrTableSingle, anslyseSelAllTraces, groupStatesToggle, testAntiCorr )
	wave rawTr, accRejTable, spotInfoTableOrg
	if( groupStatesToggle == 1 ) 
		wave nStatesW
	endif
	if( testAntiCorr == 1 )
		wave ch1SignalTable, ch2SignalTable
	endif
	//	make container for idealised trajectories
	make/o /n =( dimSize( rawTr , 0 ) , dimSize( rawTr , 1 ) ) trIdSignal = nan
	// wave for excitation intensity
	make/o /n = ( dimSize( rawTr , 1 ) ) excIntW
	//	local waves
	make/o /d /n = 0 idealTraceOutput
	//
	make/o/n=30 hist1
	//**********************************************************************
	// filter traces
	if( methodFilter != 1 )
		//
		make/o/n=(dimsize(rawTr,0)) cropW = 0
		//
		for( ii = 0 ; ii < dimsize( rawTr, 1 ) ; ii += 1 )
			//
			cropW = rawTr[ p ][ ii ]
			//
			if( methodFilter == 2 )    //  by box-car smoothing algorithm
				//
				Smooth/dim = 0 /B=(1) filterParameter, cropW
				//
			elseif( methodFilter == 3 )	   //  by DWT filters
				// single channel
				highPassDWT_filter_TA_MT( cropW, filterParameter, "cropW", 0 )
				//
			endif
			//
			rawTr[ ][ ii ] = cropW[ p ]
			//
		endfor
		//
	endif
	// save the noramlise traces table into the results folder.
	Save/C /O /P = path4 rawTr as "031_0_filtSignalTr.ibw"
	//********************************************************************
	// normalize traces 
	if( normToggle == 1 )	// normalise to the illuminatio profile image.
		//
		determineExcInt_ICP_TA_MT( excIntW, spotInfoTableOrg )
		//
		for( aa = 0 ; aa < dimsize( rawTr, 1 ) ; aa += 1 )
			for( ii = 0 ; ii < dimsize( rawTr, 0 ) ; ii += 1 )
				rawTr[ ii ][ aa ] /= excIntW[ aa ]
			endFor
		endFor
		//
	elseif( normToggle == 2 ) // normalisation to begining of trace, by fitting Gaussian
		//
		make/o/n=( dimsize( rawTr, 0 ) ) cropW = 0
		//
		for( aa = 0 ; aa < dimsize( rawTr, 1 ) ; aa += 1 )
			//
			cropW[ ] = rawTr[ p ][ aa ]
			//
			normValue = normTraceToBegin_ICP_TA_MT( cropW, portionToNorm, minIntNormThresh, hist1 ); wave w_coef
			//
			rawTr[ ][ aa ] /= normValue
			rawTr[ ][ aa ] /= w_coef[2]
			//
		endFor
		//
	endif
	// save the noramlise traces table into the results folder.
	Save/C /O /P = path4 rawTr as "032_0_normSignalTr.ibw"
	//***************************************************************************
	//	 loop which calls BF ICP detection for each extracted trajectory
	for(temp = 0; temp < dimSize( rawTr , 1 ) ; temp += 1 )
		//	report  satus of analysis in the control panel window.
		State_GUI_TA_MT("\tICP detection\r\tTrace # "+num2str( temp + 1 )+"  from "+num2str( dimSize( rawTr , 1 ) ) )
		//
		if( accRejTable[temp] != 0 )
			//	crop single traces from the container
			make/o /d /n = ( dimSize( rawTr ,0 ) ) signalRaw = rawTr[ p ][ temp ]
			// 	remove the bleached part of the trace
			if( removeBleachedToggle == 1 )
				//
				removeBleachedFRET_TA_MT( signalRaw )
				//
			endif
			// expand trace
			if( expandToggle == 1 )
				expandTrace_ICP_TA_MT( signalRaw, expandFactor ); 	wave intensityWave1	// expanded trace
			endif	
			//	detect ICPs in the current trace
			if( icpDetectionType == 1 )
				//
				ampDurICPD_TA_MT( intensityWave1, silentICP, minAmp, minDur, groupStatesToggle, minAmpSDtoggle )
				//
			elseif( icpDetectionType == 2 )
				//	Hidden Markov model detection of ICPs
				HMM_TA_MT( nStatesW, intensityWave1, silentICP, numCh, minAmp, minDur )
				//
			endif
			// test for anticorrelation in ch1 and ch2 signals 
			if( testAntiCorr == 1 )
				make/o /d /n = ( dimSize( ch1SignalTable ,0 ) ) ch1Signal = ch1SignalTable[ p ][ temp ]
				make/o /d /n = ( dimSize( ch2SignalTable ,0 ) ) ch2Signal = ch2SignalTable[ p ][ temp ]
				testAntiCorr_ICP_TA_MT( idealTraceOutput, ch1Signal, ch2Signal, ampCh1AntiCorr, ampCh2AntiCorr )
			endif
			// shrink expanded trace to original length
			if( expandToggle == 1 )
				shrinkTr_ICPdet_TA_MT( idealTraceOutput, expandFactor )
			endif
			//
		else
			//
			idealTraceOutput = 0
			//
		endif
 		//	fills idealized traces
	 	trIdSignal[ ][ temp ] = idealTraceOutput[ p ]
		//
	endFor
	// *************         saving results of CP analysis
	Save/C/O/P=path4 trIdSignal as "033_0_signal_IdealTr.ibw"
	// updating status
	State_GUI_TA_MT("ICP's detected.")
	print "ICP's detected."
	// saving parameters into the structure
	save_preferences_TA_MT( TAPrefs )
	// saving notes
	Notes_ICPdetection_TA_MT(  )
	// releasing memory occupied by local variables and local waves
	killVariables/z; killStrings/z; 	killWaves/z
end  // end of CP analysis function
// expands trace by a given factor and smooths the extended trace by the same factor.
function expandTrace_ICP_TA_MT( inW, expandBy )
	wave inW
	variable expandBy
	//
	variable zz
	//
	make/o /d /n=(dimsize(inW,0)*expandBy) intensityWave1
	//
	for( zz = 0 ; zz< dimsize(intensityWave1,0) ; zz += 1 )
		intensityWave1[zz] = inW[floor(max(0,zz/expandBy))]
	endFor
	//
	if( expandBy > 1 )
		Smooth/B expandBy, intensityWave1
	endif
	//
end
//
function shrinkTr_ICPdet_TA_MT( idealTraceOutput, factor )
	wave idealTraceOutput
	variable factor
	//
	variable rr, count1 = 0
	//
	duplicate/o idealTraceOutput, idealTraceOutput1
	//
	make/o / n = 0 idealTraceOutput
	//
	for( rr = 0 ; rr < dimsize( idealTraceOutput1, 0 ); rr += factor )
		insertpoints/m=0 count1, 1, idealTraceOutput
		idealTraceOutput[count1] = idealTraceOutput1[rr]
		count1 += 1
	endFor
	//	
end	
//
function/D normTraceToBegin_ICP_TA_MT( inW, portionToNorm, minIntNormThresh, hist1 )
	//
	wave inW, hist1
	variable portionToNorm, minIntNormThresh
	//
	variable meanVal, minAvg, gg
	// seach for minimal avg.
	for( gg = 0 ; gg + 10 < dimsize( inW, 0 )*portionToNorm ; gg += 1 )
		//
		meanVal = mean( inW, gg, gg + 10 )
		//
		if( gg == 0 )
			minAvg = meanVal
		else
			if( meanVal < minAvg && meanVal > minIntNormThresh  )
				minAvg = meanVal
			endif
		endif
		//
	endfor
	//
	inW /= minAvg
	// fit gaussian
	histogram/c/p/b={0.5, abs(1.4-0.5)/30,30} inW, hist1
	CurveFit/M=2 /W=2 /Q /N=1 /NTHR=0 gauss, hist1
	wave w_coef
	//
	return minAvg
	//
end
//
//****************************************************************************
function determineExcInt_ICP_TA_MT( inW1, inW2 )
	// defining input vwaves
	wave inW1 // wave for storing excitation intensity.
	wave inW2 // spot info table
	// defining local variables and strings
	string filenames = IndexedFile( path3, -1, ".tif"  )
	variable jj, x1, x2, y1, y2
	// load image from the folder
	ImageLoad/q /N = im0 /O /T = TIFF /P = path3 stringFromList( 0 , filenames , ";" ); 		wave/z imAcc1 = $stringfromlist( 0, S_waveNames, ";" )
	// fitting 4 order polynomial to image
	duplicate/o imAcc1, imAcc0;		CurveFit /NTHR = 0 /q /w = 2 poly2D 4,  imAcc1 /d = imAcc0
	// normalise output of fit to unity.
	wavestats/q imAcc0;		imAcc0 +=abs( min(0, V_min) )
	wavestats/q imAcc0;		imAcc0 /= V_max;
	imAcc0 += 0.1
	//**********************************
	// extract intensity of image
	for( jj = 0 ; jj < dimsize( inW2, 0 ); jj += 1 )
		//
		x1 = round( inW2[jj][%xC1] ) - ceil( inW2[jj][ %xW1 ] )
		x2 = round( inW2[jj][%xC1] ) + ceil( inW2[jj][ %xW1 ] )
		y1 = round( inW2[jj][%yC1] ) - ceil( inW2[jj][ %xW1 ] )
		y2 = round( inW2[jj][%yC1] ) + ceil( inW2[jj][ %xW1 ] )
		// determine excitation intensity by simple ROI average
		imagestats /q /m = 1 /g = { x1, x2, y1, y2 } imAcc0
		// fill in the excitation intensity into the dedicated wave
		inW1[ jj ] = V_avg + 0.1
		//
	endFor
	//
end
//
function loadWMain_TA_MT( numCh, icpDetectionType, namesIdTrTableSingle, anslyseSelAllTraces, groupStatesToggle, testAntiCorr )
	// input variabes and strings
	variable numCh, icpDetectionType, anslyseSelAllTraces, groupStatesToggle, testAntiCorr
	string namesIdTrTableSingle
	// local variables and strings
	string fileName
	//
	fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*"+namesIdTrTableSingle+"*" )
	LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
	duplicate/o /r = [*,*][*,*][0,0] $stringFromlist( 0 , S_wavenames ), rawTr
	//
	if( anslyseSelAllTraces == 1 )
		fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*051_*" )
		LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
		duplicate/o $stringFromlist( 0 , S_wavenames ), accRejTable	
	else
		make/o /n = ( dimsize( rawTr, 1 ) ) accRejTable = 1
	endif
	//
	fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*040_*" )
	LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
	duplicate/o $stringFromlist( 0 , S_wavenames ), spotInfoTableOrg	
	//
	if( groupStatesToggle == 1 )
		fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*000_*" )
		LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
		duplicate/o $stringFromlist( 0 , S_wavenames ), nStatesW
	endif
	//
	if( testAntiCorr == 1 )
		//
		fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*030_1_*" )
		LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
		duplicate/o $stringFromlist( 0 , S_wavenames ), ch1SignalTable
		//
		fileName = ListMatch( (indexedFIle ( path4 , -1 , ".ibw" )) , "*030_2_*" )
		LoadWave/H/O/N = filteredSignalTraces/P = path4/Q  stringFromList( 0, fileName )
		duplicate/o $stringFromlist( 0 , S_wavenames ), ch2SignalTable	
		//
	endif
	//
	killStrings/z fileName
	//
end
//
function removeBleachedFRET_TA_MT( inW )
	wave inW
	//
	variable bb = 0, cc = 0, countBleach = 0
	variable minY = -0.2 , maxY = 1.2
	variable nPntsBleach = 1
	variable lengthToAnalyse = 5
	//
	do	
		// ***********
		if( inw[bb] > maxY || inw[bb] < minY  )
			//
			cc = bb + 1
			countBleach = 0
			do
				if( inw[cc] > maxY || inw[cc] < minY  )
					countBleach += 1
				endif
				//
				cc += 1
				if( cc >= dimSize( inw, 0 ) )
					break
				endif
				//
				if( cc - bb > lengthToAnalyse  )
					break
				endif
				//
			while( 1 )
			//
		endif
		//***********
		if( countBleach > nPntsBleach )
			//
			do
				//
				if( bb < dimsize( inW, 0 ) )
					deletepoints/m=0 bb, 1, inW
				else
					break
				endif
				//
			while(1)
			//
			break
		else
			bb += 1
		endif
		//***********
		if( bb >= dimsize( inW, 0 ) )
			break
		endif
		//
	while(1)
	//
end
// ****  ICP detection  notebook function
Function Notes_ICPdetection_TA_MT( )
	// loading structure variables
	Struct TA_preferences TAPrefs
	load_preferences_TA_MT( TAPrefs )
	// closing notebook if it exist
	DoWindow logWin
	if(V_flag==1)
		DoWindow/K logWin
	endif
	//
	variable aa
	string str1 = "BFactor Gauss;BFactor Poisson;Amplitude and Duration;Hidden Markov Model;"
	// making new notebook
	NewNoteBook/F=0/N=logWin
	// writing text on logWIn window
	NoteBook logWin text = "\r\rData treated with TAMT."
	NoteBook logWin text = "\rWritten by Marijonas Tutkus\r@ BioNano, KU and @ Department of Molecular Compound Physics, CPST."
	// data path information
	NoteBook logWin text = "\r\rData path information:"
	pathInfo path4;	NoteBook logWin text = "\rResults stored at: " + S_path
	// ICP detection parameters
	if( TAPrefs.icpDetection[0] == 1 )
		NoteBook logWin text = "\rICP detected by Amplitude and Duration algorithm."
		NoteBook logWin text = "\rMinimal step amplitude: "+num2str( TAPrefs.minAmp )
		NoteBook logWin text = "\rMinimal step amplitude expressed by: "+stringfromlist(TAPrefs.minAmpTypeToggle-1, "Dependent on SD;Constant predefined;", ";")
		NoteBook logWin text = "\rMinimal step duration: "+num2str( TAPrefs.minDur )	
		NoteBook logWin text = "\rClustering os states: "+stringfromlist(TAPrefs.clusterStates-1, "Enabled;Disabled;", ";")	
	elseif( TAPrefs.icpDetection[0] == 5 )
		NoteBook logWin text = "\rICP detected by Hidden Markov model algorithm."
	endif
	// normalisation.
	if( TAPrefs.normaliseToggle == 1 )
		NoteBook logWin text = "\rIntensity traces were normalised to illumintaion image."
	elseif( TAPrefs.normaliseToggle == 2 )
		NoteBook logWin text = "\rIntensity traces were normalised to beginning."
	elseif( TAPrefs.normaliseToggle == 3 )
		NoteBook logWin text = "\rIntensity traces were not normalised."
	endif
	// filtering.
	if( TAPrefs.tracesFilterVariables[ 0 ] == 2 )
		NoteBook logWin text = "\r\rSignal traces were filtered by box-car smoothing method, size of smoothing box:  "+num2str( TAPrefs.tracesFilterVariables[ 1 ] )
	elseif( TAPrefs.tracesFilterVariables[ 0 ] == 3 )
		NoteBook logWin text = "\r\rSignal traces were filtered by DWT filtering method, cut-off freq.:  "+num2str( TAPrefs.tracesFilterVariables[ 1 ] )
	else
		NoteBook logWin text = "\r\rSignal traces were not filtered."
	endif
	//
	if( TAPrefs.IdSelAllTrName	 == 1 )
		NoteBook logWin text = "\r\rDetect ICPs in selected traces."	
	else
		NoteBook logWin text = "\r\rDetect ICPs in all traces."
	endif
	//
	if( TAPrefs.removeBleach == 1 )
		NoteBook logWin text = "\r\rRemove bleached fraction of FRET traces."	
	else
		NoteBook logWin text = "\r\rDo not remove bleached fraction of FRET traces."
	endif
	//
	if( TAPrefs.antiCorToggleMain == 1 )
		NoteBook logWin text = "\r\rAnti-correlation in ch1 and ch2 test enabled. Min. amplitudes ch1: "+num2str(TAPrefs.coefStepAmp[1]	)+", ch2: "+num2str(TAPrefs.coefStepAmp[2]	)
	else
		NoteBook logWin text = "\r\rAnti-correlation in ch1 and ch2 test disabled."
	endif
	//
	if( TAPrefs.expandTrace[0] == 1 )
		NoteBook logWin text = "\r\rExpanding of trace enabled. Factor for expansion: "+num2str(TAPrefs.expandTrace[1])
	else
		NoteBook logWin text = "\r\rExpanding of trace disabled."
	endif	
	//
	variable indexIdTr = TAPrefs.IdTrName						// index to name of table to idealise
	string namesIdTrTable1 = "030_0_;030_1_;030_2_;030_6_;030_7_;"
	NoteBook logWin text = "\r\rUnique fraction of table name for traces to idealise: "+stringFromList(indexIdTr-1, namesIdTrTable1, ";")
	// saving notebook
	SaveNoteBook/O/P= path4 /S=6 logWin as "LogBook5_ICPdetection.txt"
	doWindow/K logWin
	//
end 		// end of notebook function
//****************************************************************************
function removeBleachedFRETBatch_TA_MT( inTable )
	wave inTable
	//
	variable gg , kk
	duplicate/o inTable, outTable
	outTable = 0
	//
	for( gg = 0 ; gg < dimsize( inTable, 1 ) ; gg += 1 )
		//
		make/o/n=(dimsize(inTable,0)) crop1 = inTable[p][gg]
		//
		removeBleachedFRET_TA_MT( crop1 )
		//
		for( kk = 0 ; kk < dimsize( crop1, 0 ) ; kk += 1 )
			//
			outTable[kk][gg] = crop1[kk] 
			//
		endfor
		//	
	endfor
	//
end
//****************************************************************************
function testAntiCorr_ICP_TA_MT( idealTraceOutput, ch1Signal, ch2Signal, ampCh1AntiCorr, ampCh2AntiCorr )
	wave idealTraceOutput, ch1Signal, ch2Signal
	variable ampCh1AntiCorr, ampCh2AntiCorr
	//
	variable aa = 0,ampCh1, ampCh2, removeICP = 0, intLevel = idealTraceOutput[ 0 ]
	//
	do
		//
		if( idealTraceOutput[aa] != idealTraceOutput[aa+1] )
			//
			EdgeStats /P /Q /R=( max( 0, aa - 3 ), min( aa + 3, dimSize(ch1Signal,0)-1 ) ) ch1Signal
			ampCh1 = abs( V_EdgeAmp4_0 )
			EdgeStats /P /Q /R=( max( 0, aa - 3 ), min( aa + 3, dimSize(ch2Signal,0)-1 ) ) ch2Signal
			ampCh2 = abs( V_EdgeAmp4_0 )
			//
			if( ampCh1 < ampCh1AntiCorr || ampCh2 < ampCh2AntiCorr )
				removeICP = 1
				intLevel = idealTraceOutput[aa]			
			else
				removeICP = 0
				intLevel = idealTraceOutput[aa+1]
			endif
			//
		endif
		//
		aa += 1
		//
		idealTraceOutput[aa] = intLevel
		//
		if( aa >= dimSize( idealTraceOutput, 0 ) )
			break
		endif
		//
	while(1)
	//
end





//
//// KMeans ICP detection algorithm
//function KMeansICPD_TA_MT( inW, nGroupsKmeans, silentICP, meanGroupW )
//	// input signal and variables
//	wave inW
//	variable nGroupsKmeans, silentICP
//	wave meanGroupW
//	// local variabes
//	variable kk, jj, startPoint = 0
//	// make input wave to have right type
//	make/o/n=(1,dimsize(inW,0) ) inW2; 	inW2[0][] = inW[q]
//	//
//	make/o/n=(1,dimsize(meanGroupW,0)) meanGroupW1
//	meanGroupW1[0][] = meanGroupW[q]
//	// perform the KMeans clustering algorithm.
//	KMeans /DEAD = 1  /DIST = 1 /INIT = 2 /INW = meanGroupW1 /OUT = 2  /TER = 2  inW2
//	wave W_KMMembers
//	// make a idealised trace usign tht einformation passed fro mthe Kmeans algorith.
//	duplicate/o inW, idealTraceOutput;	idealTraceOutput = 0
//	for( kk = 0 ; kk < dimsize( W_KMMembers, 0 ) ; kk += 1 )
//		//
//		if( W_KMMembers[kk] == W_KMMembers[kk+1] && kk < dimsize( W_KMMembers, 0 ) - 1 )
//			//
//		else
//			//
//			for( jj = startPoint ; jj <= kk ; jj += 1 )
//				idealTraceOutput[ jj ] = mean( inW, startPoint, kk )
//			endFor
//			//
//			startPoint = kk + 1 
//		endif
//		//
//	endfor
//	//
//	if( silentICP == 1 )
//		//
//		doWindow/k graphTemp
//		display /n = graphTemp inW, idealTraceOutput
//		ModifyGraph /w = graphTemp mode(idealTraceOutput)=6,rgb(idealTraceOutput)=(0,0,0)
//		execute " TileWindows/G=5/A=(1,1)/W=(42,18,786,468) graphTemp"
//		//
//		doUpdate
//		kk = 2
//		prompt kk, "Stop: ", popUp, "yes;no"
//		doprompt "Choose", kk
//		if( kk == 1 )
//			//doWindow/k graphTemp
//			abort
//		endif
//		doWindow/k graphTemp
//	endif
//	//
//end
////