#pragma rtGlobals=1		// Use modern global access method.
//********************************************************************************************************************
// detection of ICP in the intensity versus time traces by amplitude and duration algorithm.
// written by M.Tutkus @ BioNano in KU and @ MDFL in CPST
function ampDurICPD_TA_MT( intensityWaveOrg, silentToggle, minAmp, minDur , groupStatesToggle, minAmpSDtoggle )
	wave intensityWaveOrg			// input wave containing intensity versus time trace
	variable silentToggle			// toggle of printing results, 1 == printing on, else - off.
	variable minAmp, minDur		// value for minimal amplitude and minimal duration.
	variable groupStatesToggle	// state clustering toggle
	variable minAmpSDtoggle		// toggle for amplitude criteria: 1- dependent on SD of signal, 2 - predefined.
	// local variables, and initial conditions
	variable startPoint, currentIndex
	// print status
	if( silentToggle == 1 )
		//
		print "ICP detection based on amplitude & duration, initiated. min aplitude: "+stringfromlist(minAmpSDtoggle-1, "dependent on # SD ;predefined ;",";")+num2str(minAmp)+", duration: "+num2str(minDur)
		//
	endIf
	// analysis of the cropped piece of trajectory
	scanFrame_ICP_TA_MT( intensityWaveOrg, minAmp, minDur , minAmpSDtoggle );	wave icpList		// 1D wave containing locations of ICPs.
	// cluster detected states
	if( groupStatesToggle == 1 )
		groupStates_ICP_TA_MT( icplist, intensityWaveOrg, nStatesW )
	endif
	// output Waves
	make/o/d/n = ( dimSize( icpList , 0 ) - 1 ) levelWave
	make/o/d/n = ( dimSize( intensityWaveOrg, 0 ) ) idealTraceOutput = 0
	// assign avg intensity for detected states and make ideal trajectory
	for( currentIndex = 0 ; currentIndex + 1 < dimSIze( icpList , 0 ) ; currentIndex +=1 )
		// estimate average intensity of this part of trajectory
		if( icpList[ currentIndex +1]  - icpList[ currentIndex ] > 4 )
			levelWave[ currentIndex ] = mean( intensityWaveOrg, icpList[ currentIndex ] + 2, icpList[ currentIndex + 1 ] - 2)
		else
			levelWave[ currentIndex ] = mean( intensityWaveOrg, icpList[ currentIndex ] + 1, icpList[ currentIndex + 1 ] - 1)
		endif
		//assign this average value to part of ideal trajetory
		for( startPoint = icpList[ currentIndex ]; startPoint <= icpList[ currentIndex + 1 ] ; startPoint += 1 )
			idealTraceOutput[ startPoint ] = levelWave[ currentIndex ]
		endFor
		//
	endFor
	//
	if( silentToggle == 1 )
		//print icpList
		displayOutput_BF_TA_MT( intensityWaveOrg, idealTraceOutput )
	endif
	//
end
//
function displayOutput_BF_TA_MT( intensityWaveIn, idealTraceOutput )
	wave intensityWaveIn, idealTraceOutput
	//
	//wave fretWave
	//
	variable stopvar
	//
	doWindow/k graphTemp
	display /n = graphTemp intensityWaveIn, idealTraceOutput
	//appendtograph/w = graphTemp /r fretWave
	ModifyGraph /w = graphTemp mode(idealTraceOutput)=6,rgb(idealTraceOutput)=(0,0,0), lsize(idealTraceOutput)=1.5//, axisEnab(left)={0.45,1}, rgb(fretWave)=(0,40000,0), axisEnab(right)={0,0.5}
	//SetAxis/w = graphTemp right -0.1,1.1
	execute " TileWindows/G=5/A=(1,1)/W=(42,18,786,468) graphTemp"
	//
	doUpdate
	stopvar = 2
	prompt stopvar, "Stop: ", popUp, "yes;no"
	doprompt "Choose", stopvar
	if( stopvar == 1 )
		abort
	endif
	doWindow/k graphTemp
	//
end
//
function groupStates_ICP_TA_MT( icplist, intensityWaveOrg, nStatesW )
	wave icplist, intensityWaveOrg, nStatesW
	//
	variable npntesDel, zz, pp
	variable startPoint, midPoint
	variable currGr, prevGr
	//
	do
		//
		npntesDel = 0
		zz = 1
		//	
		do
			//
			if( dimsize( icplist,0) > 2 )
				//
				startPoint = mean( intensityWaveOrg, icpList[zz]+1, icpList[zz+1]-1 )
				midPoint = mean( intensityWaveOrg, icpList[zz-1]+1, icpList[zz]-1 )
				//
				for( pp = 0 ; pp < dimsize( nStatesW, 0 ) ; pp += 1 )
					if( startPoint > nStatesW[pp][0] && startPoint < nStatesW[pp][1] )
						currGr = pp
					endif
				endFor
				//
				for( pp = 0 ; pp < dimsize( nStatesW, 0 ) ; pp += 1 )
					if( midPoint > nStatesW[pp][0] && midPoint < nStatesW[pp][1] )
						prevGr = pp
					endif
				endFor
				//
				if( currGr == prevGr )
					deletepoints/m=0 zz, 1, icplist
					npntesDel += 1
				else
					zz += 1
				endif
				//
				if( zz + 1 >= dimsize(icplist,0) )
					break
				endif
				//
			else
				break
			endif
			//
		while(1)
		//
		if( npntesDel <= 0 )
			break
		endif
		//
	while(1)
	//
end
//
function scanFrame_ICP_TA_MT( inWLong, minAmpIn, frameSize, minAmpSDtoggle )
	wave inWLong
	variable minAmpIn, frameSize, minAmpSDtoggle
	//
	variable aa = 0, zz
	variable ampCur
	variable nPntsRemoved
	variable midPos = ceil(frameSize / 2)
	variable durCurr
	variable slopeMin
	variable minAmp
	variable steadyLevelToggle = 0
	variable avgIntEnd, sdIntEnd
	string bFOut
	//
	make/o /n = ( frameSize ) cropW
	make/o /d /n = 2 icpList; 	icpList = { 0,  dimsize( inWLong, 0 ) }
	make/o /n = (dimsize( inWLong, 0 ),4)  ampW
	make/o /n = (dimsize(inWLong,0),frameSize) cropWTable
	// method for amplitude threshold calculation/
	if( minAmpSDtoggle == 1 )		// dependent on SD of end of signal.
		avgIntEnd = mean( inWLong, dimSize(inWLong, 0)*0.9, inf )
	 	sdIntEnd = sqrt( variance( inWLong, dimSize(inWLong, 0)*0.9, inf ) ) * minAmpIn
		minAmp = avgIntEnd + sdIntEnd
	else									// predefined by the user.
		minAmp = minAmpIn
	endif
	//
	do 
		// calculate amplitude step
		ampCur = mean(inWLong,aa+midPos,(aa+frameSize)-1) - mean(inWLong,aa,abs(aa+midPos)-1)
		// if amplitude is higher than the threshold value, then record aa into icpList.
		if( abs( ampCur ) > minAmp )
			insertpoints/m=0 1,1, icpList
			icpList[1] = midPos + aa
			aa += midPos
		else
			aa += 1
		endif
		//
		if( aa + midPos >= dimsize( inWLong, 0 ) )
			break
		endif
		//
	while(1)
	//
	sort icpList, icpList
	// refine the detected ICPs.
	do
		//
		aa = 1
		nPntsRemoved = 0 
		//
		if( dimsize( icplist,0 ) > 2 )
			//
			do
				//
				ampCur = abs( mean(inWLong,icpList[aa],icpList[aa+1]) - mean(inWLong,icpList[aa-1],icpList[aa]) )
				durCurr = min( icpList[aa+1]-icpList[aa], icpList[aa]-icpList[aa-1] )
				// fit a line do determine slope of states separated by the aa ICP.
				if( durCurr >= 2 )
					CurveFit/M=2/W=0/N=1/NTHR = 0/Q line, inWLong[icpList[aa],icpList[aa+1]]
					wave W_coef
					steadyLevelToggle = abs(W_coef[1])
					CurveFit/M=2/W=0/N=1/NTHR = 0/Q line, inWLong[icpList[aa-1],icpList[aa]]
					steadyLevelToggle += abs(W_coef[1])
				else
					steadyLevelToggle = 0
				endif
				//
				if( durCurr < midPos || ampCur < minAmp || steadyLevelToggle > 20 )
					//
					deletepoints/m=0 aa , 1, icpList
					nPntsRemoved += 1
					//
				else
					aa += 1
				endif
				//
				if( aa >= dimsize( icpList, 0  ) -1 )
					break
				endif
				//
			while(1)
			//
			if( nPntsRemoved == 0 )
				//
				break
				//
			endif
			//
		else			// size of ICP table less than 3.
			//
			break
			//
		endif
		//
	while(1)
	//
	sort icpList, icpList
	//
end








////
//function detectICP_maxLogL_TA_MT( intensityWave,  threshold, durMin )
//	wave intensityWave
//	variable threshold, durMin
//	//
//	variable aa = 0, startPnt, endPnt
//	logProb_calc_PoissDist_TA_MT( intensityWave );	wave numBayesPow
//	// differentiate the max likelihood function
//	Differentiate numBayesPow/D=W_DIF
//	// apply threshold and figure out where the CP are
//	findPeak_BIC_TA_MT(  W_DIF , threshold);	wave icplist
//	// remove to to short duartion states
//	make/o/n=(dimsize(icplist,0)-1) durW = icplist[p+1]-icplist[p]
//	aa = 0
//	do
//		//
//		if( durW[aa] < durMin )
//			deletepoints/m=0 aa+1, 1, icplist
//			deletepoints/m=0 aa, 1, durW
//		else
//			aa += 1
//		endif
//		//
//		if( aa >= dimsize(icplist,0)-1 )
//			break
//		endif
//		//
//	while(1)
//	//
//end
////
//function detectICP_BF_TA_MT( intensityWave, BFThreshold, refinementToggle, methodToggle )
//	wave intensityWave
//	variable BFThreshold, refinementToggle
//	variable methodToggle	// 1 - gaussian process, else -poissonian process.
//	// local variables
//	variable startPoint = 0
//	variable currentIndex = 0
//	variable midPoint = 0
//	variable endPoint = dimSize( intensityWave, 0 ) - 1
//	variable icpLocOut
//	string bFOut
//	variable removedCount = 0
//	variable nICPAdded = 0
//	variable shortestSegment = 10
//	// make a wave for storing ICP locations, first and last points are predifined.
//	make/o /d /n = 2 icpList; 	icpList = { 0,  endPoint }
//	//
//	currentIndex = 1
//	startPoint = icpList[ currentIndex - 1 ]; endPoint = icpList[ currentIndex ];
//	//
//	do
//		//
//		if( abs( endPoint - startPoint ) > shortestSegment )
//			// 	crop the region defined by the markers, and make an empti wave for storing results.
//			duplicate/o/r = [ startPoint , endPoint ] intensityWave, cropTrace1;	setScale/p x, 0, 1,  cropTrace1
//			// 	calculated BF for this piece of trajectory
//			if( methodToggle == 1 )
//				bFOut = BF_calculation_gaussDist_TA_MT( cropTrace1 );	wave/t numBayesStr
//			elseif( methodToggle == 2 )
//				bFOut = BF_calculation_PoissDist_TA_MT( cropTrace1  );	wave/t numBayesStr
//			endif
//			// 	compare BF threshold with the BF of the current piece of trace.
//			APMath/n = 5 destStr1 = comp(bFOut,BFThreshold)
//			// 	most likely there is an ICP in this region
//			if( str2num( destStr1 ) >= 0  )
//				//	adjust the x scale for posterior PDF 
//				setScale/p x, startPoint, 1,  cropTrace1
//				//  	find maximum. in  post prob by identifying peak and check if max location is in the converging region.
//				icpLocOut = findPeak_BF_TA_MT( numBayesStr ) + startPoint
//				// 	check if there is simmilar point to this?
//				FindValue/V=(icpLocOut) /T=1 /Z icpList
//				if( V_value < 0 )
//					// 	insert the location of iCP
//					insertPoints/m = 0 currentIndex , 1 , icpList
//					icpList[ currentIndex ] = icpLocOut
//					nICPAdded += 1
//					//
//				else
//					//
//					currentIndex += 1
//					//				
//				endif
//				//
//			else	// 	no ICP is in this region, thus extend it by step size
//				//
//				currentIndex += 1
//				//
//			endif
//			//
//		else
//			//
//			currentIndex += 1
//			//
//		endif
//		//
//		startPoint = icpList[ currentIndex - 1 ]; 	endPoint = icpList[ currentIndex ]
//		//
//		if( startPoint >= icpList[ dimSize( icpList, 0 ) - 1 ] )
//			break
//		endif
//		//
//	while( 1 )  // end for while loop of iCP detection	
//	//**************************************************************************
//	// sort identifyied ICP locations in increasing order.
//	sort icpList, icpList
//	// refinement of the detected ICPs by checking BFactor and state duration
//	// implement removal of states by the state duration.!!!!!!!!!!!!!!!!!
//	if( dimSize( icpList , 0 ) > 2 && refinementToggle == 1 )
//		do
//			//
//			currentIndex = 0;	removedCount = 0
//			//
//			do
//				//
//				startPoint = currentIndex; 	midPoint = currentIndex + 1; 	endPoint = currentIndex + 2 
//				// crop piece of trajectory
//				duplicate/o/r = [ icpList[ startPoint ] , icpList[ endPoint ] ]  intensityWave, cropTrace1;	setScale/p x, 0, 1,  cropTrace1
//				// 	calculated BF for this piece of trajectory
//				if( methodToggle == 1 )
//					bFOut = BF_calculation_gaussDist_TA_MT( cropTrace1 );	wave/t numBayesStr
//				elseif( methodToggle == 2 )
//					bFOut = BF_calculation_PoissDist_TA_MT( cropTrace1  );	wave/t numBayesStr
//				endif
//				//
//				APMath/n = 5 destStr1 = comp(bFOut,BFThreshold)
//				if( str2num( destStr1 ) < 0 )
//					deletePoints/m = 0 midPoint , 1 , icpList
//					removedCount += 1
//				else
//					currentIndex += 1
//				endif
//				//
//				if( currentIndex + 2 >= dimSize( icpList, 0 ) )
//					break
//				endif
//				//
//			while( 1 )
//			//
//			if( removedCount <= 0 || dimSize( icpList , 0 ) <= 2 )
//				break
//			endif
//			//
//		while(1)
//		//
//	endif
//	//
//end
////
//function/d findPeak_BF_TA_MT(  numBayesStr )
//	wave/t numBayesStr
//	//
//	variable aa
//	Variable vOut = 0
//	string localString
//	//
//	for( aa = 2 ; aa < dimsize( numBayesStr, 0 ) - 2 ; aa += 1 )
//		//
//		if( aa == 2 )
//			//
//			localString = numBayesStr[aa]
//			//
//		else
//			//
//			APMath/n = 5 destStr1 = comp(numBayesStr[aa],localString)
//			//
//			if( str2num( destStr1 ) > 0 ) // if numBayesStr[aa] > localString
//				vOut = aa
//				localString = numBayesStr[aa]
//			endif
//			//
//		endif
//		//
//	endfor
//	//
//	return vOut
//	//
//end
////
//function findPeak_BIC_TA_MT(  W_DIF, threshold )
//	wave W_DIF
//	variable threshold
//	//
//	variable aa, startPnt
//	//
//	make/o/n=2 icpList = {0,dimsize(W_DIF,0)}
//	do
//		//
//		if( W_DIF[aa] >  threshold )
//			//
//			startPnt = aa
//			//
//			aa += 1
//			//
//			if( aa >= dimsize( W_DIF, 0 ) )
//				break
//			endif
//			//
//			do
//				//
//				if( W_DIF[aa] <  threshold )
//					//
//					insertpoints/m=0 0,2, icpList
//					icpList[0] = startPnt
//					icpList[1] = aa	
//					//
//					break
//					//
//				else
//					aa += 1
//				endif
//				//
//				if( aa >= dimsize( W_DIF, 0 ) )
//					//
//					insertpoints/m=0 0,1, icpList
//					icpList[0] = startPnt
//					//
//					break
//					//
//				endif
//				//
//			while(1)
//			//
//		elseif( W_DIF[aa] <  -1* threshold )
//			//
//			startPnt = aa
//			//
//			aa += 1
//			//
//			if( aa >= dimsize( W_DIF, 0 ) )
//				break
//			endif
//			//
//			do
//				//
//				if( W_DIF[aa] > -1* threshold )
//					//
//					insertpoints/m=0 0,2, icpList
//					icpList[0] = startPnt
//					icpList[1] = aa
//					//				
//					break
//					//
//				else
//					aa += 1
//				endif
//				//
//				if( aa >= dimsize( W_DIF, 0 ) )
//					//
//					insertpoints/m=0 0,1, icpList
//					icpList[0] = startPnt
//					//
//					break
//				endif
//				//
//			while(1)
//			//		
//		else
//			aa += 1
//		endif
//		//
//		if( aa >= dimsize( W_DIF, 0 ) )
//			break
//		endif
//		//
//	while(1)
//	//
//	sort icpList, icpList
//	//
//end
//// calculating bayesian factor based on Gaussian process. Multiple processors employed.
//function/s  BF_calculation_gaussDist_TA_MT( signal1 )
//	// 	input
//	wave signal1					// InputWave of intensity versus time trace
//	variable inverseToggle
//	//
//	variable hh, kk, pp, mm, normPower, normGround
//	string strOut
//	string localResult
//	//	local waves
//	make/o /d /n = ( dimSize( signal1, 0 ) ) duration1, duration2, Mean1, Mean2 , sDev1, sDev2 , numBayesPow
//	make/o /t /n = ( dimSize( signal1, 0 ) ) numBayesStr
//	// record statistics of piece of trajectory before ts and after it: mean, standard deviation, duration, mean^2
//	for( hh = 0 ; hh < dimSize( signal1, 0 )  ; hh += 1 )	// run through all the signal wave
//		// statistics of the part before ts - switching time
//		Mean1[ hh ] = mean( signal1, 0, hh )								// Average of intensity of piece of trajectory from 0 till ts
//		// SD of intensity of piece of trajectory from 0 till ts
//		if( numtype( sqrt( variance( signal1, 0, hh ) ) ) != 0 || sqrt( variance( signal1, 0, hh ) ) == 0 )
//			sDev1[ hh ] = 0.001
//		else
//			sDev1[ hh ] = sqrt( variance( signal1, 0, hh ) )	
//		endif
//		//
//		duration1[ hh ] = 1+ hh - 0	 									// duration of piece of trajectory from 0 till ts
//		//-**************************************************************
//		// statistics of the part after ts - switching time	
//		Mean2[ hh ] = mean( signal1, hh, dimsize( signal1, 0 ) - 1 )			// Average of intensity of piece of trajectory from ts till the end of signal
//		// SD of intensity of piece of trajectory from ts till the end of signal
//		if( numtype( sqrt( variance( signal1, hh, dimsize( signal1, 0 ) - 1 ) ) ) != 0 || sqrt( variance( signal1, hh, dimsize( signal1, 0 ) - 1 ) ) == 0 )
//			sDev2[ hh ] = 0.001
//		else
//			sDev2[ hh ] = sqrt( variance( signal1, hh, dimsize( signal1, 0 ) - 1 ) )		
//		endif
//		duration2[ hh ] = dimsize( signal1, 0 ) - hh			  				// duration of piece of trajectory from ts till the end of signal
//		//
//	endFor
//	//	calculating final expression and storing value to num bayes
//	numBayesStr[ ] = gaussBF_APMath_ICP_TA_MT( Mean1, Mean2, duration1, duration2, sDev1, sDev2, p, dimsize( numBayesStr, 0 ) )
//	//
//	numBayesPow[ ] =  str2num( stringfromlist( 1, numBayesStr[ p ], "E" ) )
//	for( hh = 0 ; hh < dimSize( numBayesStr, 0 ); hh += 1 )
//		//
//		if( numBayesPow[hh] > 300 )
//			numBayesPow[hh] = 300
//		elseif( numBayesPow[hh] < -300 )
//			numBayesPow[hh] = -300
//		endif
//		//
//	endfor
//	//
//	numBayesPow[] = str2num( stringfromlist( 0, numBayesStr[ p ], "E" ) ) ^ numBayesPow[p]
//	// average the result
//	for( hh = 0 ; hh < dimSize( numBayesStr, 0 ); hh += 1 )
//		//
//		if( itemsinlist( numBayesStr[ hh ], "E" ) <= 1 )
//			numBayesStr[ hh ] = numBayesStr[ hh ]+"E+1"
//		endif
//		//
//		if( hh == 0 )
//			localResult = numBayesStr[ hh ]
//		else
//			APMath/n = 5 destStr1 = localResult + numBayesStr[ hh ]
//			localResult = destStr1
//		endif
//		//
//	endfor
//	//	calculating probability of hypothesis 1: there is not any ICP in the trajectory
//	wavestats/q signal1
//	kk = V_npnts * V_sdev	
//	hh = -V_npnts;   hh /= 2;	hh += 0.5
//	pp = V_npnts/2 ; pp -= 1; pp -= 1
//	mm = abs( V_avg )
//	APMath /n = 5 strOut = ( mm * localResult ) / ( 7.87479 * pow( kk, hh ) * factorial( pp ) )
//	//
//	return strOut
//	//
//end
////************************************************************************************************************
//// APMath calculation of posterior probability based on Gaussian process.
//Function/S gaussBF_APMath_ICP_TA_MT( w1, w2, w3, w4, w5, w6, index , nPntsTotal )
//	// input waves
//	wave  w1, w2		// mean 1, mean2 of intensity
//	wave  w3, w4		// duration1, duration2
//	wave w5, w6		// SD1, SD2 of intensity
//	// input variables
//	variable index		// ts - index in the wave
//	variable nPntsTotal
//	// local variables
//	variable n1 = w3[ index ]	// duration
//	variable n2 = w4[ index ]
//	variable s1 = w5[ index ]	// sd
//	variable s2 = w6[ index ]
//	variable x1 = w1[ index ]	// mean
//	variable x2 = w2[ index ]
//	//
//	variable a11 = - n1 / 2 ; a11 += 0.5
//	variable a21 = - n1 / 2 ;	a21 += 1
//	variable a31 =   n1 / 2 ; a31 -= 1; a31 -= 1
//	//
//	variable a12 = - n2 / 2 ; a12 += 0.5
//	variable a22 = - n2 / 2 ;	 a22 += 1
//	variable a32 =   n2 / 2 ; a32 -= 1 ; a32 -= 1
//	//
//	variable s1s2 = s1 + s2
//	variable x12Px22 = x1^2 * x2^2
//	variable denum = s1s2 * x12Px22
//	//
//	APMath /n = 5 destStr = ( ( ( pow( n1, a11 ) * pow( s1 , a21 ) * factorial( a31 ) ) * ( pow( n2, a12 ) * pow( s2 , a22 ) * factorial( a32 ) ) ) / denum ) / nPntsTotal
//	//
//	return destStr
//	//
//end
////**********************************************************************************
//// Bayesian factor for a process defined by Poisson process
//function/s BF_calculation_PoissDist_TA_MT( signalIn )
//  	// input
//	wave  signalIn
//	// local variables and strings
//	variable bFactor = 0, hh =0, mm, var1, var2, var3m
//	string localResult = "0"
//	string strOut
// 	// make a wave for storing probabilibty density function values
//	make/o /d /n = ( dimSize( signalIn, 0 ) ) duration1, duration2, counts1, counts2
//	make/o /t /n = ( dimSize( signalIn, 0 ) ) numBayesStr
//	make/o /d /n = ( dimSize( signalIn, 0 ) ) numBayesPow
//	//*******************************************************************	
//	for( hh = 0 ; hh < dimSize( signalIn, 0 ); hh += 1 )
//		// statistics of the part before ts - switching time
//		counts1[ hh ] = sum( signalIn, 0, hh )						// Average of intensity of piece of trajectory from 0 till ts
//		duration1[ hh ] = 1+ hh 	 							// duration of piece of trajectory from 0 till ts
//		// statistics of the part after ts - switching time
//		counts2[ hh ] = sum( signalIn, hh, dimsize( signalIn, 0 ) - 1 )	// Average of intensity of piece of trajectory from ts till the end of signal
//		duration2[ hh ] = dimsize( signalIn, 0 ) - hh 					// duration of piece of trajectory from ts till the end of signal
//		//
//	endFor
//	// 	calculationg posteriour probaibity expression - probability of hypothesis 2: there is an ICP in the trajectory, using arbitrary percision math
//	numBayesStr[ ] = poissonBF_APMath_ICP_TA_MT( counts1, counts2, duration1, duration2, p , dimSize( signalIn, 0 ) )
//	//
//	numBayesPow[ ] =  str2num( stringfromlist( 1, numBayesStr[ p ], "E" ) )
//	for( hh = 0 ; hh < dimSize( numBayesStr, 0 ); hh += 1 )
//		//
//		if( numBayesPow[hh] > 300 )
//			numBayesPow[hh] = 300
//		elseif( numBayesPow[hh] < -300 )
//			numBayesPow[hh] = -300
//		endif
//		//
//	endfor
//	numBayesPow[] = str2num( stringfromlist( 0, numBayesStr[ p ], "E" ) ) ^ numBayesPow[p]
//	// integrate the result
//	for( hh = 0 ; hh < dimSize( numBayesStr, 0 ); hh += 1 )
//		//
//		if( itemsinlist( numBayesStr[ hh ], "E" ) <= 1 )
//			numBayesStr[ hh ] = numBayesStr[ hh ]+"E+1"
//		endif
//		//
//		if( hh == 0 )
//			localResult = numBayesStr[ hh ]
//		else
//			APMath/n=5 destStr1 = localResult + numBayesStr[ hh ]
//			localResult = destStr1
//		endif
//		//
//	endfor
//	//	calculating probability of hypothesis 1: there is not any ICP in the trajectory
//	wavestats/q signalIn
//	hh = 1 ; hh /= V_npnts - 1
//	APMath/n=5 strOut = ((  ( pow( V_npnts, V_sum ) / factorial( V_sum - 1 ) ) * hh * 0.63662 ) / V_npnts )  / localResult
//	//
//	return strOut
//	//
//end
////************************************************************************************************************
//// APMath calculation of posterior probability baed on poisson process.
//Function/S poissonBF_APMath_ICP_TA_MT( c1, c2, d1, d2, hh, nPntsTotal )
//	// input waves and variables
// 	wave c1, c2, d1, d2
// 	variable hh			// index
// 	variable nPntsTotal
// 	// local variables
// 	variable cd1 = c1[hh]/d1[hh];	cd1 = cd1^2
// 	variable cd2 = c2[hh]/d2[hh];	cd2 = cd2^2
// 	variable cd1cd2 = cd1+ cd2;	cd1cd2 = cd1cd2 ^-1
// 	//
// 	variable c1p1 = c1[hh]+1
// 	variable c2p1 = c2[hh]+1
//	//
//	APMath/n=5 destStr = ( ( ( factorial( c1[hh] ) * factorial( c2[hh] ) ) / ( pow( d1[hh], c1p1 ) * pow( d2[hh], c2p1 ) ) ) / cd1cd2 ) / nPntsTotal
//	//
//	return destStr
//	//
//end
//
//
////**********************************************************************************
//// Bayesian factor for a process defined by Poisson process
//function/d logProb_calc_PoissDist_TA_MT( signalIn )
//  	// input
//	wave  signalIn
//	// local variables and strings
//	variable hh, mm, sumPhotons, Vk 
// 	// make a wave for storing probabilibty density function values
//	make/o /d /n = ( dimSize( signalIn, 0 ) ) duration1, duration2, counts1, counts2
//	make/o /d /n = ( dimSize( signalIn, 0 ) ) numBayesPow = 0
//	//*******************************************************************	
//	for( hh = 0 ; hh < dimSize( signalIn, 0 ); hh += 1 )
//		// statistics of the part before ts - switching time
//		counts1[ hh ] = sum( signalIn, 0, hh )						// Average of intensity of piece of trajectory from 0 till ts
//		duration1[ hh ] = 1+ hh 	 							// duration of piece of trajectory from 0 till ts
//		// statistics of the part after ts - switching time
//		counts2[ hh ] = sum( signalIn, hh, dimsize( signalIn, 0 ) - 1 )	// Average of intensity of piece of trajectory from ts till the end of signal
//		duration2[ hh ] = dimsize( signalIn, 0 ) - hh 				// duration of piece of trajectory from ts till the end of signal
//		//
//	endFor
//	//
//	for( hh = 0 ; hh < dimSize( signalIn, 0 )-1; hh += 1 )
//		//
//		Vk = duration1[ hh ] / dimSize( signalIn, 0 )
//		mm = counts2[ hh ] ; mm /= 1 - Vk
//		sumPhotons = counts2[ hh ] + counts1[ hh ]
//		//
//		numBayesPow[ hh ] = 2 * counts1[ hh ] * ln( counts1[hh] / Vk )
//		numBayesPow[ hh ] += 2 * counts2[ hh ] * ln( mm )
//		numBayesPow[ hh ] -= 2 * sumPhotons * ln( sumPhotons )
//	endfor
//	//
//end

//**********************************************************************************************************************************
//		// check durations of states and amplitudes
//		//
//		do
//			//
//			make/o/n=0 durationW
//			removedCount = 0
//			for( currentIndex = 0 ; currentIndex < dimsize( icpList, 0 )-2 ; currentIndex += 1 )
//				insertpoints/m=0 removedCount,1, durationW
//				durationW[removedCount] = icpList[currentIndex+1] - icpList[currentIndex]
//				removedCount += 1
//			endfor
//			//
//			removedCount = 0
//			currentIndex = 0
//			do
//				if( durationW[currentIndex] < minDur )
//					deletepoints/m=0 currentIndex+1, 1, icpList
//					deletepoints/m=0 currentIndex, 1, durationW
//					removedCount += 1
//				else
//					currentIndex += 1
//				endif
//				//
//				if( currentIndex >= dimsize( durationW,0  ) )
//					break
//				endif
//				//
//			while(1)
//			//
//			currentIndex = 0
//			do
//				ampCurr = abs( mean( intensityWaveIn, icpList[ currentIndex+1 ], icpList[ currentIndex+2 ] ) - mean( intensityWaveIn, icpList[ currentIndex ], icpList[ currentIndex+1 ] ) )
//				if( ampCurr < minAmp )
//					deletepoints/m=0 currentIndex+1, 1, icpList
//					removedCount += 1
//				else
//					currentIndex += 1
//				endif
//				//
//				if( currentIndex >= dimsize( icpList,0  )-2 )
//					break
//				endif
//				//
//			while(1)
//			//
//			if( removedCount == 0 )
//				break
//			endif
//			//
//		while(1)


//	// make trace longer
//	make/o /d /n=(dimsize(intensityWave,0)*expandTraceBy) intensityWaveLong, intensityWaveLongOrg 
//	for( zz = 0 ; zz< dimsize(intensityWaveLong,0) ; zz += 1 )
//		intensityWavelong[zz] = intensityWave[floor(max(0,zz/expandTraceBy))]
//		intensityWaveLongOrg[zz] = intensityWaveInput[floor(max(0,zz/expandTraceBy))]
//	endFor
//	Smooth/B expandTraceBy*2, intensityWavelong

//	if( searchToggle == 1 )  // expanding box icp search
//		do
//			//
//			duplicate/o /r = [ currentIndex , currentIndex+durAnalysisCur ] intensityWave, cropTrace1;	setScale/p x, 0, 1,  cropTrace1
//			// 	calculated BF for this region of trajectory
//			if( methodToggle == 1 )
//				bFOut = BF_calculation_gaussDist_TA_MT( cropTrace1 );	wave numBayes
//			else
//				bFOut = BF_calculation_PoissDist_TA_MT( cropTrace1  );	wave numBayes
//			endif
//			//
//			if( bFOut > BFThreshold  )
//				//	adjust the x scale for posterior PDF 
//				setScale/p x, currentIndex, 1,  numBayes, cropTrace1
//				//  find maximum in posterior probability
//				icpLocOut = findPeak_BF_TA_MT( )
//				// check whether this ICP location has not been detected yet.
//				FindValue/V=(icpLocOut) /T=2 /Z icpList
//				if( V_value < 0 )
//					//
//					insertPoints/m=0 dimSize(icpList,0)-1,1, icpList
//					icpList[ dimsize(icpList,0)-2 ] = icpLocOut
//					//
//					currentIndex = icpLocOut
//					durAnalysisCur = durAnalysisOMain
//					//
//				else
//					durAnalysisCur += 1
//				endif
//				//
//			else
//				durAnalysisCur += 1
//			endif
//			//
//			if( currentIndex+durAnalysisCur >= endPoint )
//				break
//			endif
//			//
//		while(1)
//	else			 // original paper based icp search

// gaussian process log.

//	for( hh = 0; hh < dimSize( numBayes, 0 ); hh += 1 )
//		//
//		if( numtype( numBayes[ hh ] ) != 0 )
//			kk = 0
//			do
//				if( numtype( numBayes[ kk ] ) == 0 )
//					numBayes[ hh ] = numBayes[ kk ]
//					break
//				else
//					kk += 1
//				endif
//				//
//				if( kk >= dimsize( numBayes, 0 ) )
//					kk = 0
//				endif
//			while(1)
//			//
//		endif
//		//
//	endFor
//	// 	estimate Bayesian factor
//	vOut = charFullWave( signal1, numBayes )
//	// 	take BF estimate as a power of exponent and make sure that the value of BF is lower than 700, and higher than 0.
//	if( vOut > 700 )
//		vOut = exp( 700 )
//	elseif( vOut < - 700 )
//		vOut = exp( 700 )
//	else
//		vOut = exp( vOut )
//	endif
//	//
//	vOut *= 300
//	//
//	wavestats/q numBayes
//	if( V_max > 700 || abs( V_min ) > 700 )
//		numBayes /= abs( max( V_max, abs( V_min ) ) / 700 )
//	endif
//	numBayes[ ] = exp( numBayes[ p ] )



//	// check sDev
//	for( hh = 0; hh < dimSize( signal1, 0 ); hh += 1 )
//		//
//		if( numtype( sDev1[ hh ] ) != 0  || sDev1[ hh ] <= 0 )
//			kk = 0
//			do
//				if( numtype( sDev1[ kk ] ) == 0 || sDev1[ kk ] > 0 )
//					sDev1[ hh ] = sDev1[ kk ]
//					break
//				else
//					kk += 1
//				endif
//				//
//				if( kk >= dimsize( signal1, 0 ) )
//					kk = 0
//				endif
//			while(1)
//			//
//		endif
//		//
//		if( numtype( sDev2[ hh ] ) != 0  || sDev2[ hh ] <= 0 )
//			kk = 0
//			do
//				if( numtype( sDev2[ kk ] ) == 0  || sDev2[ kk ] > 0 )
//					sDev2[ hh ] = sDev2[ kk ]
//					break
//				else
//					kk += 1
//				endif
//				//
//				if( kk >= dimsize( signal1, 0 ) )
//					kk = 0
//				endif
//			while(1)
//			//
//		endif
//		//
//	endFor


// providing: w1 - trajectory segment, numBayes - probability for ICP location.
//FUNCTION/d  charFullWave( w1, numBayes )
//	wave w1, numBayes
//	// record statistics of the entire wave, which required to calculate 
//	// probability of the first hypothesis: there is not any ICP in the trajectory
//	waveStats/q w1
//	variable z1 = 0.5 * V_npnts ; z1 -= 1
//	variable z2 = 0.5; z2 -= V_npnts * 0.5
//	variable avg1 = ln( abs( V_avg ) )
//	variable nS = V_npnts * V_sdev
//	variable expressBottom = 2^0.5
//	expressBottom *= pi^(3/2)
//	expressBottom = ln(expressBottom)
//	expressBottom += z2 * ln( nS )
//	expressBottom += gammLn( z1 )
//	// take average of posterior probaiblity, multiply by average intensity of entire trajectory
//	waveStats/q numBayes
//	variable vOut = avg1 + V_avg;	vOut -= expressBottom
//	//
//	return vOut
//	//
//end

// function use multiple processors, original expression was modified by taking logarithm of entire expression
// because oriungal expression gives values which are way to large for a double precision variables
//threadSafe Function/d operation1Sub(  w1, w2, w3, w4, w5, w6, index )
//	// input waves
//	wave  w1, w2		// mean 1, mean2 of intensity
//	wave  w3, w4		// duration1, duration2
//	wave w5, w6		// SD1, SD2 of intensity
//	// input variables
//	variable index	// ts - index in the wave
//	variable n1 = w3[ index ]	// duration
//	variable n2 = w4[ index ]
//	variable s1 = w5[ index ]	// sd
//	variable s2 = w6[ index ]
//	variable x1 = w1[ index ]	// mean
//	variable x2 = w2[ index ]
//	// local variables
//	variable a11 = 0.5 ; a11 -= ( n1 * 0.5 )
//	variable a21 = 1; a21 -= ( n1 * 0.5 )
//	variable a31 = ( n1 * 0.5 ); a31 -= 1
//	//
//	variable a12 = 0.5 ; a12 -= ( n2 * 0.5 )
//	variable a22 = 1 ; a22 -= ( n2 * 0.5 )
//	variable a32 = ( n2 * 0.5 ) ;  a32 -= 1
//	// ckeck values of parameters
//	variable lnN1 =  ln( n1 )
//	variable lnS1 =  ln( s1 )
//	variable gLnA31 =  gammLn( a31 )
//	variable lnN2 =  ln( n2 )
//	variable lnS2 =  ln( s2 )
//	variable gLnA32 =  gammLn( a32 )
//	variable lnS1S2 = ln( s1 + s2 )
//	variable lnX1lnX2 = x1^2;	 lnX1lnX2 *= x2^2;		lnX1lnX2 = ln( lnX1lnX2 )
//	// calculate denuminator and numinator splited into two parts
//	variable express1 = a11 * lnN1; express1 += a21 * lnS1 ; express1 += gLnA31
//	variable express2 = a12 * lnN2; express2 += a22 * lnS2	; express2 += gLnA32
//	variable express3 = lnS1S2 + lnX1lnX2
//	//
//	variable bfLoc = express1 + express2
//	bfLoc -= express3
//	//
//	return bfLoc
//	//
//end


//Threadsafe function/d operationPoissSub( count1, count2, duration1, duration2, index )
// 	wave count1, count2, duration1, duration2
// 	variable index
//	// local variables
//	variable countsVar1 = count1[ index ]+1
//	variable countsVar2 = count2[ index ]+1
//	variable durVar1 = duration1[ index ]
//	variable durVar2 = duration2[ index ]	
//	variable countMean1 = ( countsVar1 / durVar1 );	countMean1 = countMean1 ^ 2
//	variable countMean2 = (  countsVar2 / durVar2 );	countMean2 = countMean2 ^ 2
//	variable countMeanSum = countMean1 + countMean2;	countMeanSum = 1 / countMeanSum
//	variable countsDur1 = (countsVar1)*ln(durVar1)
//	variable countsDur2 = (countsVar2)*ln(durVar2)
//	variable vOut
//	// expresssion of posterioir probability taken natural logarithm of it
// 	vOut = gammln(countsVar1) + gammln(countsVar2)
// 	vOut -= countsDur1 + countsDur2
// 	vOut += ln(countMeanSum)
// 	//
//	return vOut
//	//
// end
 
//******* idenify peak.
//	wavestats/q numBayes1
//	threshVal = V_min
//	do
//		//
//		if( numBayes1[ hh ] >= threshVal )
//			//
//			insertpoints/m=0 PeakCount, 1, crossPointsW
//			crossPointsW[PeakCount][0] = max( hh, 0 )		// start of the peak
//			crossPointsW[PeakCount][2] += numBayes1[ hh ]   // value at the cross point
//			crossPointsW[PeakCount][3] = numBayes1[ hh ]  	// value at the cross point
//			//
//			hh += 1
//			if( hh >= dimsize( numBayes1, 0 ) )
//				crossPointsW[PeakCount][1] = hh-1
//				break
//			endif
//			//	
//			do
//				//
//				if( numBayes1[ hh ] < crossPointsW[PeakCount][3] )
//					crossPointsW[PeakCount][1] = hh
//					break
//				else
//					crossPointsW[PeakCount][2] += numBayes1[ hh ]
//					crossPointsW[PeakCount][3] = numBayes1[ hh ]
//				endif
//				//
//				hh += 1
//				//
//				if( hh >= dimsize( numBayes1, 0 ) )
//					crossPointsW[PeakCount][1] = hh-1
//					break
//				endif
//				//
//			while(1)
//			//
//			PeakCount += 1 
//			//
//		endif
//		//
//		hh += 1
//		//	
//		if( hh >= dimsize( numBayes1, 0 ) )
//			break
//		endif
//		//
//	while(1)
//	//
//	make/o /n = ( dimsize( crossPointsW, 0 ) ) crossPointsW1 = crossPointsW[ p ][ 2 ]
//	//
//	if( dimsize( crossPointsW1, 0 ) >= 3 )
//		//
//		deletepoints/m=0 0,1, crossPointsW1, crossPointsW
//		deletepoints/m=0 dimsize(crossPointsW1, 0)-1 ,1, crossPointsW1, crossPointsW
//		//
//		wavestats/q crossPointsW1
//		wavestats/q /r = [ crossPointsW[V_maxRowLoc][0] , crossPointsW[V_maxRowLoc][1] ] numBayes1
//		//
//	else
//		wavestats/q numBayes1
//	endif


////
//function extendCrop_Main_TA_MT( nPntsExtendTrace, startPoint, endPoint, cropTrace1, intensityWave )
//	variable  nPntsExtendTrace, startPoint, endPoint
//	wave cropTrace1, intensityWave 
//	variable pp = 0
//	//
//	InsertPoints 0, nPntsExtendTrace, cropTrace1;	InsertPoints dimsize( cropTrace1, 0 ), nPntsExtendTrace, cropTrace1
//	for( pp = 0 ; pp < nPntsExtendTrace ; pp += 1 )
//		cropTrace1[ pp ] = mean( intensityWave,  startPoint, startPoint + nPntsExtendTrace )
//	endfor
//	for( pp = dimsize( cropTrace1, 0 ) - nPntsExtendTrace ; pp < dimsize( cropTrace1, 0 ) ; pp += 1 )
//		cropTrace1[ pp ] = mean( intensityWave,  abs( endPoint - nPntsExtendTrace ) , endPoint )
//	endfor
//	//
//	setScale/p x, 0, 1,  cropTrace1
//	//
//end

//	//	adjust the x scale for posterior PDF 
//	setScale/p x, startPoint, 1,  numBayes, cropTrace1
//	//  find maximum. in  post prob by identifying peak and check if max location is in the converging region.
//	icpLocOut = findPeak_BF_TA_MT( )
//	// check if there is simmilar point to this?
//	FindValue/V=(icpLocOut) /T=1.5 /Z icpList
//	//
//	 doupdate
//	 print bFOut, icpLocOut, V_value, ": BF, Icploc, V_value"
//	 prompt nICPAdded, "stop", popup ,"yes;no;"
//	 doprompt "aa" nICPAdded
//	 if( nICPAdded == 1 )
//	 	abort
//	 endif


//	// make trace longer
//	make/o /d /n=(dimsize(intensityWave,0)*expandBy) intensityWaveLong 
//	for( zz = 0 ; zz< dimsize(intensityWaveLong,0) ; zz += 1 )
//		intensityWaveLong[zz] = intensityWave[floor(max(0,zz/expandBy))]
//	endFor
//	// convert ICP location to correspond to the non expanded trace.
//	icpList /= expandBy

//	// input : in wave, in wave original, bayesian factor threshold, refinement toggle, method (1-gauss, else - poisson.)
//	if( detectionProcessType < 3 )
//		detectICP_BF_TA_MT( intensityWave1, BFThreshold, refinementToggle, detectionProcessType );	wave icpList