#pragma rtGlobals=3		// Use modern global access method and strict wave access.

//More info on the algorithm here: An adaptive non-local means filter for denoising live-cell images and improving particle detection.
//Lei Yang et al, Journal of Structural Biology, 2010.

function Hi_calculation( minS, iterS , inW, outwName )
	variable minS, iterS
	wave inW
	string outwName
	//
	variable HkiCurr
	variable deltaS = 1, currS
	variable x1, x2, y1, y2
	variable sum1, np1, sum2, np2
	variable xx, yy, aa
	//
	make/o /n = 3 HkiW
	duplicate/o inW, outW
	//
	for( xx = 0 ; xx < dimSize( inW, 0 ) ; xx += 1 )
		for( yy = 0 ; yy < dimsize( inW, 1 ) ; yy += 1 )
			// reset maximum wave
			HkiW = 0
			//	calculate Hki values for pixel xx, yy, square window
			for( aa = 0; aa < iterS; aa += 1 )
				// calculate current size of haar window
				if( aa == 0 )
					currS = minS
				else
					currS = ceil( currS + deltaS )
				endif
				//
				x1 = max( 0, xx - currS )
				x2 = min( xx + currS, dimsize( inW, 0 ) - 1 )
				y1 = max( 0, yy - currS )
				y2 = min( yy + currS, dimsize( inW, 1 ) - 1 )
				// statistics of piece of image V
				imagestats/q /m = 1 /g = { x1, x2, y1, y2 } inW
				sum1 = V_avg * V_npnts; 	np1 = V_npnts
				//
				x1 = max( 0, xx - currS + 1 )
				x2 = min( xx + currS - 1, dimsize( inW, 0 ) - 1 )
				y1 = max( 0, yy - currS + 1 )
				y2 = min( yy + currS - 1, dimsize( inW, 1 ) - 1 )
				// statistics of piece of image U
				imagestats/q /m = 1 /g = { x1 , x2, y1, y2 } inW
				sum2 = V_avg * V_npnts; np2 = v_npnts
				// Hki value
				HkiCurr = abs( sum2 / np2 ) - abs( abs( sum1 - sum2 ) / abs( np1 - np2 ) )
				// record Hki value
				if( HkiCurr > HkiW[ 0 ] )
					HkiW[ 0 ] = HkiCurr
				endif
				//	calculate Hki values for pixel xx, yy, vertical window
				x1 = max( 0, xx - currS + 2 )
				x2 = min( xx + currS - 2, dimsize( inW, 0 ) - 1 )
				y1 = max( 0, yy - currS )
				y2 = min( yy + currS, dimsize( inW, 1 ) - 1 )
				// statistics of piece of image V
				imagestats/q /m = 1 /g = { x1, x2, y1, y2 } inW
				sum2 = V_avg * V_npnts; 	np2 = V_npnts
				// Hki value
				HkiCurr = abs( sum2 / np2 ) - abs( abs( sum1 - sum2 ) / abs( np1 - np2 ) )
				// record Hki value
				if( HkiCurr > HkiW[ 1 ] )
					HkiW[ 1 ] = HkiCurr
				endif
				//	calculate Hki values for pixel xx, yy, vertical window
				x1 = max( 0, xx - currS )
				x2 = min( xx + currS, dimsize( inW, 0 ) - 1 )
				y1 = max( 0, yy - currS + 2 )
				y2 = min( yy + currS - 2, dimsize( inW, 1 ) - 1 )
				// statistics of piece of image V
				imagestats/q /m = 1 /g = { x1, x2, y1, y2 } inW
				sum2 = V_avg * V_npnts; 	np2 = V_npnts
				// Hki value
				HkiCurr = abs( sum2 / np2 ) - abs( abs( sum1 - sum2 ) / abs( np1 - np2 ) )
				// record Hki value
				if( HkiCurr > HkiW[ 2 ] )
					HkiW[ 2 ] = HkiCurr
				endif
				//
			endFor
			//
			outW[xx][yy] = abs( abs(8/10) * HkiW[ 0 ] ) + abs( abs(1/10) * HkiW[ 1 ] ) + abs( abs(1/10) * HkiW[ 2 ] )
			//
		endFor
	endFor
	//  clean the current data folder
	duplicate/o outw, $outwName
	killWaves/z outW, HkiW
	killVariables/z HkiCurr, deltaS, currS, x1, x2, y1, y2, sum1, np1, sum2, np2, xx, yy, aa
	//
end

function particleProb_image( inW, lambda, outwName )
	wave inW
	variable lambda
	string outwName
	//
	duplicate/o inW, outW
	//
	variable aa , bb
	for( aa = 0 ; aa < dimsize( outW, 0 ) ; aa += 1 )
		for( bb = 0 ; bb < dimsize( outW, 1 ) ; bb += 1 )
			if( outW[aa][bb] < lambda )
				outW[aa][bb] = 1	
			else
				outW[aa][bb] = 0
			endif
		endFor
	endFor
	//
	duplicate/o outW, $outwName
	killwaves/z outW
	killvariables/z aa, bb
	//
end

function partProb2_image( size, inW, outwName, pThresh )
	variable size, pThresh
	wave inW
	string outwName
	//
	redimension/b/u inw
	duplicate/o inw, outw
	outw = 0
	redimension/d outw
	//
	variable aa, bb
	variable x1, x2, y1, y2
	//
	for(aa = 0 ; aa < dimSize( inW, 0 ) ; aa += 1 )
		for( bb = 0 ; bb < dimsize( inW, 1 ) ; bb += 1 )
			//	calculate Hki values for pixel xx, yy, vertical window
			x1 = max( 0, aa - size )
			x2 = min( aa + size, dimsize( inW, 0 ) - 1 )
			y1 = max( 0, bb - size )
			y2 = min( bb + size, dimsize( inW, 1 ) - 1 )
			// crop piece of image
			duplicate/o /r = [ x1, x2 ][ y1, y2 ] inw, crop
			//
			ImageAnalyzeParticles /M = 0 /A = 0 /Q stats  crop	
			wave W_ImageObjArea
			//
			if( dimsize( W_ImageObjArea, 0 ) > 0 && inw[ aa ][ bb ] == 0 )
				wavestats/q W_ImageObjArea
				outw[ aa ][ bb ] = W_ImageObjArea[ V_maxLoc ] / abs( dimsize( crop, 0 ) * dimSIze( crop, 1 ) )
			endif
			//
		endFor
	endFor
	//
	duplicate/o outw, pProbImage
	//
	for(aa = 0 ; aa < dimSize( inW, 0 ) ; aa += 1 )
		for( bb = 0 ; bb < dimsize( inW, 1 ) ; bb += 1 )
			//
			if( outw[ aa ][ bb ] > pThresh )
				outw[ aa ][ bb ] = 0
			else
				outw[ aa ][ bb ] = 1
			endif
			//
		endFor
	endFor
	//
	redimension/b/u outw
	duplicate/o outw, $outwName
	//
	killwaves/z outw, crop
	killvariables/z aa, bb, x1, x2, y1, y2
	//
end