#pragma rtGlobals=1		// Use modern global access method.
//*********************************************************
//***		Source borrowed from ImageJ        		||**
//***		Modifyied by Marijonas T. 19/05.2012      	||**
//***		University of Copenhagen      		 	||**
//************************************************************************************************
//   Implements a rolling-ball algorithm for the removal of smooth continuous background
//   from a image.  It rolls the ball (actually a square patch on the top of a sphere).
//************************************************************************************************
Function subtractBackround1(  ballRadius )
	// input variable
	variable ballRadius
	print "Removing background from image by Rolling Ball algorithm"
	NewPath /C/M="Choose image path" /O/Q/Z pathName1
	NewPath /C/M="Choose Storing path" /O/Q/Z pathName2
	//
	string membraneName =  IndexedFile( pathName1, 0, ".tif"  )
	make/o/n = ( 1,1 ) ImageName
	killWaves/z ImageName 
	ImageLoad/Q/N=ImageName/O/T=TIFF/P=pathName1 membraneName
	// initiating globals  variables
	Variable/g arcTrimPer = 0 
	Variable/G patchwidth = 0
	Variable/G height = dimSize( ImageName, 0 )
	Variable/G width = dimSize( ImageName, 1 )
	variable aa , bb
	// making rolling ball
        RollingBall( ballRadius)
        wave ballImage  // output wave of rolling ball function
	// making backgound image by rolling ball algrorithm
	rollBall( ballImage , ImageName )
	wave backgroundImage
	//
	redimension/n = ( height, width ) backgroundImage
	matrixFilter/n=(3)/p=1 max, backgroundImage
	// correct image by background image
	for( aa = 0 ; aa < dimSize( ImageName,  0 ) ; aa += 1 )
		for( bb = 0 ; bb < dimSize( ImageName, 1 ); bb += 1 )
			if( ImageName[ aa ][ bb ] - backgroundImage[ aa ][ bb ] < 0 )
				ImageName[ aa ][ bb ] = 0
			else
				ImageName[ aa ][ bb ] -= backgroundImage[ aa ][ bb ]
			endif
		endFor
	endFor
	doupdate
	//
	ImageSave/F/T="TIFF"/p=pathName2 ImageName as "bckgSubtracted.tif"
	// show bckground corrected image
	killVariables/z aa, bb, arcTrimPer, patchwidth, height, width
	killWaves/z backgroundImage, ballImage
end // end of background subtraction function
Function/d subtractBackround( ImageName, ballRadius ) 
	wave ImageName
	// 	input variable
	variable ballRadius
	// 	initiating globals  variables
	Variable/G patchwidth = 0
	variable sFactor = 1
	if( ballradius <= 10 )
		sFactor = 1
	elseif( ballRadius > 10 && ballRadius <= 30 )
		sFactor = 2
	elseif( ballRadius > 30 && ballRadius <= 100 )
		sFactor = 4
	else
		sFactor = 8
	endif
	ballRadius = ROUND( ballRadius / sFactor )
	// make it to be double precision
	redimension/d ImageName
	// shrink image
	wave smallImage = shrinkImage_rollBall( ImageName, sFactor )
	// 	making rolling ball
       ballRadius = RollingBall( ballRadius )
       wave ballImage  			// output wave of rolling ball function
	// 	making backgound image by rolling ball algrorithm
	rollBall( ballImage , smallImage )
	wave backgroundImage;	duplicate/o backgroundImage, backgroundImage2
	// interpolate bg and then extrapolate
	Wave backgroundImage2 = enlargeImage_rollBall( backgroundImage2, sFactor, dimSize(ImageName,0), dimSize(ImageName,1) )
	duplicate/o backgroundImage2, backgroundImage
	//	filter background image by convolving it with Gaussian
	matrixFilter /n = (ballRadius) /p = 2 Gauss, backgroundImage
	//	subtract background image from raw image
	multithread ImageName[ ][ ] -= backgroundImage[ p ][ q ]
	wavestats/q ImageName;	ImageName += 0.001 + abs( V_min )	// make sure, that  none of the pixels has value < 0
	//	find average bckg level
	wavestats/q backgroundImage
	variable vOut = V_avg
	// show bckground corrected image
	killVariables/z patchwidth
	killWaves/z backgroundImage, ballImage
	//
	return vOut
	//
end // end of background subtraction function
//*******************************************************************************************************************************************************************
// Computes the location of each point on the rolling ball patch relative to the  center of the sphere containing it.  The patch is located in the top half 
// of this sphere.  The vertical axis of the sphere passes through the center of the patch.  The projection of the patch in the xy-plane below is a square.
//*******************************************************************************************************************************************************************
Function/d RollingBall( ballradius )
	// input variables
	variable ballradius
	// Global variables
	NVAR patchwidth
	// if ballRadius is less then 0
	if( ballRadius < 3 )
		ballRadius = 3
	endif
	// number should be uneven
	if( mod( ballradius, 2 ) == 0 )
		ballRadius += 1
	endif
        // *****     body of the fuction
	patchwidth = ballradius
	// making empty vector for ball
 	make/o /d /n = ( ballradius, ballradius ) ballImage = 0
 	// fit a sphere to the ball image
	make/o /n = 2 coeficients = { floor( ballradius * 0.5), floor( ballradius * 0.5 ) }
	make/o /n = ( ballradius ) xScale1, yScale1
	xScale1 = x; yScale1 = x
	variable V_fitError = 0
	FuncFitMD/w=2 /q /h="11" fitSphere, coeficients, ballImage / D = ballImage /X = xScale1 /Y = yScale1
	// normalize the intensity of ball
	wavestats/q ballImage; 	ballImage -= V_min; 	wavestats/q ballImage ; 	ballImage /= V_max  / ballradius
	wavestats/q ballImage; 	ballImage += abs( V_min ) + 0.1
   	// releasing local memory
   	killWaves/z coeficients, xScale1, yScale1
   	//
   	return ballradius
   	//
end
//
function fitSphere( w, x1, y1) : FitFunc
	WAVE w
	Variable x1, y1
	return - ( x1 - w[0] ) ^ 2 - ( y1 - w[1] ) ^ 2
end
//*************************************************************************************************************************************
//	'Rolls' a filtering object over an image in order to find the image's smooth continuous background.
//	For the purpose of explaining this algorithm, imagine that the 2D grayscale image has a third (height) dimension
//	defined by the intensity value at every point in the image. The center of the filtering object, a patch from the top of a
//	sphere having radius BallRadius, is moved along each scan line of the image so that the patch is tangent to the
//	image at one or more points with every other point on the patch below the corresponding (x,y) point of the image.
//	Any point either on or below the patch during this process is considered part of the background.  Shrinking the image
//	before running this procedure is advised due to the fourth-degree complexity of the algorithm. 
//*************************************************************************************************************************************                                                                                 
Function rollBall( ballImage, imageInput  ) 
	// input images
	wave ballImage, imageInput 
	// local variables
	variable xpt , ypt, xpt2, ypt2				// current coordinates in input image
	variable zCtr = 0, zMin = 2^16			// values controling level of bg
	variable count2 = 0, count1 = 0, pp, gg, zAdd
	variable x1, x2, y1,y2
       // 	make  backgroundImage matrix
       make/o /n = ( dimSIze( imageInput, 0 ), dimSIze( imageInput, 1 ) ) backgroundImage = 0
       // **********       body of the function, rolling ball throught an input image
 	for ( ypt = 0 ; ypt < dimSize( backgroundImage, 1 ) + dimsize( ballImage, 1 ) - 1 ; ypt += 1 )  // loop runs through rows ( including margins ) + patchwidth - 2 
 		//
		for ( xpt = 0 ; xpt < dimSIze( backgroundImage, 0 ) + dimsize( ballImage, 0 ) - 1 ; xpt += 1 ) // loop runs through columns ( including margins ) + patchwidth - 2
			//	setting minimal value
			zMin = 2^16
			//	define limits of image to be rolled with the ball on horizontal axis
			if( xpt >= dimSize( backgroundImage, 0 ) - 1 )	// margin of image: right end
				x1 = xpt - dimSize( ballImage, 0 ) + 1
				x2 = dimSize( backgroundImage, 0 ) - 1
			elseif( xpt < dimSize( ballImage, 0 ) - 1 )		// margin of image: left end
				x1 = 0
				x2 = xpt
			elseif( xpt >= dimSize( ballImage, 0 ) - 1 && xpt < dimSize( backgroundImage, 0 ) - 1 )	// part of image, where entire ball image fits to
				x1 = xpt - dimSize( ballImage, 0 ) + 1
				x2 = xpt
			endif
			//	define limits of image to be rolled with the ball on vertical axis
			if( ypt >= dimSize( backgroundImage, 1 ) - 1 )	// margin of image: right end
				y1 = ypt - dimSize( ballImage, 1 ) + 1
				y2 = dimSize( backgroundImage, 1 ) - 1
			elseif( ypt < dimSize( ballImage, 1 ) - 1 )		// margin of image: left end
				y1 = 0
				y2 = ypt
			elseif( ypt >= dimSize( ballImage, 1 ) - 1 && ypt < dimSize( backgroundImage, 1 ) - 1 )	// part of image, where entire ball image fits to
				y1 = ypt - dimSize( ballImage, 1 ) + 1
				y2 = ypt
			endif
			//	crop a piece of the ball, output of the function cropped image: ballImageCrop 
			cropBallImage( ballImage, backgroundImage, x1, x2, y1, y2 ); 	wave ballImageCrop
			//	crop overlapping region of raw image 
			duplicate/o /r = [ x1 , x2 ][ y1 , y2 ] imageInput, valueImage
			//	roll the ball through surface of image
			valueImage[ ][ ] = valueImage[ p ][ q ] - zCtr + ballImageCrop[ p ][ q ]
			//	checking minimal z value
			wavestats/q valueImage
			if( zMin > V_min )
				zMin = V_min
			endif
			//	move ball up or down if we find a new minimum
			zCtr += zMin
			//	fill the background image
			count2 = 0
			for( gg = y1 ; gg <= y2 ; gg += 1 )	// runs through x
				count1 = 0
				for( pp = x1 ; pp <= x2 ; pp += 1 )	// runs through y
					//
					zAdd = zCtr + ballImageCrop[ count1 ][ count2 ]  
					//
					if( zadd > backgroundImage[ pp ][ gg ] )
						backgroundImage[ pp ][ gg ] = zAdd	
					endif
					//
					count1 += 1
					//
				endFor
				count2 += 1
			endFor
			//
		endFor // for xpt
		//
	endFor // for ypt
	// releasing memory from local variables
	killVariables/z xpt , ypt, xpt2, ypt2, zCtr, zMin, count2, count1, pp, gg, zAdd, x1, x2, y1,y2
	killWaves/z valueImage, ballImageCrop
	//
end  // end of bckg removing function
//
function cropBallImage( ballImage, imageInput, x1, x2, y1, y2 )
	variable  x1, x2, y1, y2
	wave ballImage, imageInput
	// local variables
	variable yCrop1, yCrop2
	variable xCrop1, xCrop2
 	//	find y coordinates for ball image cropping
 	if( y2 - y1 != dimsize( ballImage, 1 ) - 1 )		// cropped image area smaller than the ball image
 		if( y2 < dimsize( ballImage, 1 ) - 1 )		// beginning of image, modify the yCrop1 index
 			yCrop1 = dimsize( ballImage, 1 ) - y2 - 1
 			yCrop2 = dimsize( ballImage, 1 ) - 1
 		else									// end of image, modify the yCrop2 index
 			yCrop1 = 0
 			yCrop2 = y2 - y1
 		endif
 	else										// cropped image area is equal to the ball image
		yCrop1 = 0
		yCrop2 = dimsize(ballImage,1) - 1
	endif
	//	find x coordinates for ball image cropping
 	if( x2 - x1 != dimsize( ballImage, 0 ) - 1 )		// cropped image area smaller than the ball image
 		if( x2 < dimsize( ballImage, 0 ) - 1 )		// beginning of image, modify the yCrop1 index
 			xCrop1 = dimsize( ballImage, 0 ) - x2 - 1
 			xCrop2 = dimsize( ballImage, 0 ) - 1
 		else								// end of image, modify the yCrop2 index
 			xCrop1 = 0
 			xCrop2 = x2 - x1
 		endif
 	else										// cropped image area is equal to the ball image
		xCrop1 = 0
		xCrop2 = dimsize( ballImage, 0 ) - 1
	endif
	//	crop ball image according to the defined coordinates
	duplicate/o /r = [ xCrop1, xCrop2 ][ yCrop1, yCrop2 ]  ballImage, ballImageCrop
	//
end
//
function/Wave shrinkImage_rollBall( inW, sFactor )
 	wave inW		// input image of full size
 	variable sFactor	// shrink factor
 	//
 	variable w = round( dimsize( inW, 0 ) / sFactor )
 	variable h = round( dimsize( inW, 1 ) / sFactor )
 	variable x1 , x2, y1, y2, aa, bb
 	//
 	make/o/n=(w,h) smallImage = 2^16
 	//
 	for( aa = 0 ; aa < dimsize( inW, 0 ) ; aa += 1 )
 		for( bb = 0 ; bb < dimsize( inW, 1 ) ; bb += 1 )
 			x1 = aa-sFactor/2
 			x2 = aa+sFactor/2
 			y1 = bb-sFactor/2
 			y2 = bb+sFactor/2
 			//
 			if(x1< 0)
 				x1 = 0
 			endif
 			if( x2 >= dimSize(inW,0) )
 				x2 = dimSize(inW,0) 
 			endif
  			if(y1< 0)
 				y1 = 0
 			endif
 			if( y2 >= dimSize(inW,1) )
 				y2 = dimSize(inW,1) 
 			endif
 			//
 			imagestats/g={x1,x2,y1,y2} inW
 			if( smallImage[ ceil( aa/sFactor ) ][ ceil( bb/sFactor ) ] > V_min )
	 			smallImage[ ceil( aa/sFactor ) ][ ceil( bb/sFactor ) ] = V_min
 			endif
 			// 
 		endfor
 	endfor
 	//
 	return smallImage
 	//
 end
  //
function/Wave enlargeImage_rollBall( inW, sFactor, w, h )
 	wave inW		// input image of low size
 	variable sFactor	// shrink factor
	variable w, h
	//
 	variable x1 , x2, y1, y2, aa, bb, cc, dd
 	//
 	make/o/n=(w,h) bigImage = 2^16
 	//
 	for( aa = 0 ; aa < w ; aa += 1 )
 		for( bb = 0 ; bb < h ; bb += 1 )
 			//
  			x1 =  ceil( aa/sFactor )-sFactor/2
 			x2 =  ceil( aa/sFactor )+sFactor/2
 			y1 =  ceil( bb/sFactor )-sFactor/2
 			y2 =  ceil( bb/sFactor )+sFactor/2
 			//
 			if(x1< 0)
 				x1 = 0
 			endif
 			if( x2 >= dimSize(inW,0) )
 				x2 = dimSize(inW,0) 
 			endif
  			if(y1< 0)
 				y1 = 0
 			endif
 			if( y2 >= dimSize(inW,1) )
 				y2 = dimSize(inW,1) 
 			endif
 			//
 			imagestats/g={x1,x2,y1,y2} inW
 			//
 			bigImage[aa][bb] = V_avg
 			// 
 		endfor
 	endfor
 	//
 	return bigImage
 	//
 end